
Workload management API

The workload management API consists of the following subroutines:

*  ll_cluster subroutine
*  ll_cluster_auth subroutine
*  ll_control subroutine
*  ll_modify subroutine
*  ll_move_job subroutine
*  ll_move_spool subroutine
*  ll_preempt subroutine
*  ll_preempt_jobs subroutine
*  ll_run_scheduler subroutine
*  ll_start_job subroutine
*  ll_start_job_ext subroutine
*  ll_terminate_job subroutine

The ll_control subroutine can be used to perform most of the LoadLeveler
control operations and is designed for general use.

The ll_cluster, ll_cluster_auth, and ll_move_job subroutines are for use
in the multicluster environment.

The ll_preempt subroutine was replaced with the ll_preempt_jobs
subroutine in LoadLeveler 3.3.

The ll_start_job_ext and ll_terminate_job subroutines are intended to be
used together with an external scheduler.

Note that the ll_start_job_ext and ll_terminate_job subroutines
automatically connect to an alternate central manager if they cannot
contact the primary central manager. You should use ll_start_job_ext and
ll_terminate_job in conjunction with the query API. The query API
collects information regarding which machines are available and which
jobs need to be scheduled. See the "Query API" in TWS LoadLeveler: Using
and Administering for more information. 

Note: The AIX Workload Manager (WLM) and the LoadLeveler workload
      management API are two distinct and unrelated components.



ll_cluster subroutine

Purpose

ll_cluster - Enables other APIs to operate on a remote cluster.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_cluster (int version, LL_element **errObj, 
                LL_cluster_param *param);

Parameters

version
   Input parameter that indicates the LoadLeveler API version (should
   have the same value as LL_API_VERSION in llapi.h).

errObj
   Provides the address of a pointer to LL_element that points to an
   error object if this function fails.

param
   Provides a pointer to an LL_cluster_param structure. 
    
   typedef enum LL_cluster_op {
           CLUSTER_SET, 
           CLUSTER_UNSET
   } ClusterOp_t;
   
   typedef struct {
           ClusterOp_t action;
           char **cluster_list;
   } 
   LL_cluster_param;
    
   In the enum LL_Cluster_op structure, valid values are:
    
   CLUSTER_SET
      Sets the multicluster environment to cluster_list.

   CLUSTER_UNSET
      Unsets the multicluster environment.
    
   In the LL_cluster_param structure, the fields are defined as follows:
    
   action
      Determines whether the cluster environment should be set or unset.
      The set action must have a corresponding cluster_list The unset
      action ignores the cluster_list data.

   cluster_list
      Is a NULL-terminated array of cluster stanza names. Only one
      cluster name is allowed. The reserved words any and all are not
      allowed.

Description

This API is called to enable other APIs to run on remote clusters in a
multicluster environment and can be invoked by all users. To issue an
API multiple times for different clusters, the ll_cluster and
corresponding APIs must be issued for each cluster.

Return Values

CLUSTER_SUCCESS
   Cluster name successfully set.

CLUSTER_SYSTEM_ERROR
   LoadLeveler internal system error.

CLUSTER_INVALID_CLUSTER_PARAM
   An input parameter that is not valid was specified. Possible causes
   are that the cluster_list parameter is NULL or that the reserved
   words any or all were specified.

CLUSTER_INVALID_ACTION_PARAM
   An action parameter that is not valid was specified. Valid values are
   CLUSTER_UNSET and CLUSTER_SET.

Related Information

Subroutines: ll_ckpt, ll_deallocate, ll_free_objs, ll_get_data,
ll_get_objs, ll_modify, ll_next_obj, ll_query, ll_reset_request,
ll_set_request, llsubmit



ll_cluster_auth subroutine

Purpose

ll_cluster_auth - Creates a public key, a private key, and a security
certificate.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_cluster_auth (int version, LL_cluster_auth_param **param);

Parameters

version
   Input parameter that indicates the LoadLeveler API version (should
   have the same value as LL_API_VERSION in llapi.h).

param
   Provides the address of a pointer to an array of pointers to
   LL_cluster_auth_param structures. The last element of the array must
   be NULL. 
    
   typedef enum LL_cluster_auth_op {      
           CLUSTER_AUTH_GENKEY
   } ClusterAuthOp_t;
   
   typedef struct {
         ClusterAuthOp_t type;
   } 
   LL_cluster_auth_param;
    
   In the enum LL_cluster_auth_op structure, valid values are:
    
   CLUSTER_AUTH_GENKEY
      Generates required keys.
    
   In the enum LL_cluster_auth_op structure, the fields are defined as
   follows:
    
   type
      Indicates the requested operation.

Description

The ll_cluster_auth( ) subroutine is the API for the llclusterauth
command. Refer to the llclusterauth command for information about other
available command options.

This function must be run from a process with root authority.

The ll_cluster_auth( ) subroutine creates a public key, a private key, a
security certificate, and a directory for authorized keys. The keys and
certificate are created in the /var/LoadL/ssl directory for AIX and in
the /var/opt/LoadL/ssl directory for Linux. 
*  The private key is stored in id_rsa
*  The public key is stored in id_rsa.pub
*  The security certificate is stored in id_rsa.cert
*  The authorized keys are stored in authorized_keys

In order for a connection to be accepted, the public key for the node
requesting the connection must be stored in the authorized keys file on
the node being connected to. Only a process with root authority can run
this subroutine.

Return Values

The following return values are defined in llapi.h:

API_OK   Request successfully sent to LoadLeveler.

API_INVALID_INPUT
         An input parameter that is not valid was specified.

API_CONFIG_ERR
         Errors encountered while processing configuration files.

API_CANT_AUTH
         Caller not authorized.

API_CANT_LISTEN
         API cannot create listen socket.

API_CANT_CONNECT
         Failed to connect to LoadLeveler.

API_TIMEOUT
         Timed out waiting for a response.

API_SSL_ERR
         Timed out waiting for a response.

API_STEP_NOT_IDLE
         Request failed, the job step is not in the IDLE state.

Related Information

Commands: llclusterauth



ll_control subroutine

Purpose

ll_control - Allows an application program to perform most of the
functions that are currently available through the standalone commands:
llctl, llfavorjob, llfavoruser, llhold, and llprio.

In LoadLeveler for Linux only, ll_control returns an error condition
when SEC_ENABLEMENT is CTSEC.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_control (int control_version, enum LL_control_op control_op, 
                char **host_list, char ** user_list, char **job_list, 
                char **class_list, int priority);

Parameters

int control_version
   An integer indicating the version of ll_control being used. This
   argument should be set to LL_CONTROL_VERSION.

enum LL_control_op
   The control operation to be performed. The enum LL_control_op is
   defined in llapi.h as: 

   enum LL_control_op {
   LL_CONTROL_RECYCLE, LL_CONTROL_RECONFIG, LL_CONTROL_START,
   LL_CONTROL_STOP, LL_CONTROL_DRAIN, LL_CONTROL_DRAIN_STARTD, 
   LL_CONTROL_DRAIN_SCHEDD, LL_CONTROL_PURGE_SCHEDD, LL_CONTROL_FLUSH, 
   LL_CONTROL_SUSPEND, LL_CONTROL_RESUME, LL_CONTROL_RESUME_STARTD, 
   LL_CONTROL_RESUME_SCHEDD, LL_CONTROL_FAVOR_JOB, 
   LL_CONTROL_UNFAVOR_JOB, LL_CONTROL_FAVOR_USER, 
   LL_CONTROL_UNFAVOR_USER, LL_CONTROL_HOLD_USER, 
   LL_CONTROL_HOLD_SYSTEM, LL_CONTROL_HOLD_RELEASE, LL_CONTROL_PRIO_ABS, 
   LL_CONTROL_PRIO_ADJ, LL_CONTROL_START_DRAINED, LL_CONTROL_DUMP_LOGS}; 

char **host_list
   A NULL-terminated array of host names.

char **user_list
   A NULL-terminated array of user names.

char **job_list
   A NULL-terminated array of job or step identifiers. When a job
   identifier is specified, the action of the API is taken for all steps
   of the job. At least one job or step identifier must be specified. 

   The format of a job identifier is host.jobid. The format of a step
   identifier is host.jobid.stepid.
    
   where:
    
   *  host is the name of the machine that assigned the job and step
      identifiers.
   *  jobid is the job number assigned to the job when it was submitted.
   *  stepid is the job step number assigned to the job step when it was
      submitted.
    
   The job or step identifier may be specified in an abbreviated form,
   jobid or jobid.stepid, when the API is invoked on the same machine
   that assigned the job and step identifiers. In this case, LoadLeveler
   will use the local machine's host name to construct the full job or
   step identifier.
    
   Note: For coscheduled jobs, even if all coscheduled job steps are not
         in the list of targeted job steps, the requested operation is
         performed on all coscheduled job steps only when holding or
         releasing jobs.

char **class_list
   A NULL-terminated array of class names.

int priority
   An integer representing the new absolute value of user priority or
   adjustment to the current user priority of job steps.

Description

The ll_control subroutine performs operations that are essentially
equivalent to those performed by the standalone commands: llctl,
llfavorjob, llfavoruser, llhold, and llprio. Because of this similarity,
descriptions of the ll_control operations are grouped according to the
standalone command they resemble.

llctl type of operations: These are the ll_control operations which
mirror operations performed by the llctl command. This summary includes
a brief description of each of the allowed llctl types of operations.
For more information, see the llctl command description in TWS
LoadLeveler: Using and Administering.

LL_CONTROL_START: 
   Starts the LoadLeveler daemons on the specified machines. The calling
   program must have rsh privileges to start LoadLeveler daemons on
   remote machines. 

   Note: LoadLeveler will fail to start if any value has been set for
         the MALLOCTYPE environment variable.

LL_CONTROL_START_DRAINED: 
   Starts the LoadLeveler in the drained state.

LL_CONTROL_STOP: 
   Stops the LoadLeveler daemons on the specified machines.

LL_CONTROL_RECYCLE:
   Stops, and then restarts, all of the LoadLeveler daemons on the
   specified machines.

LL_CONTROL_RECONFIG:
   Forces all of the LoadLeveler daemons on the specified machines to
   reread the configuration files.

LL_CONTROL_DRAIN:
   When this operation is selected, the following happens: (1) No
   LoadLeveler jobs can start running on the specified machines, and (2)
   No LoadLeveler jobs can be submitted to the specified machines.

LL_CONTROL_DRAIN_SCHEDD:
   No LoadLeveler jobs can be submitted to the specified machines.

LL_CONTROL_DRAIN_STARTD:
   Keeps LoadLeveler jobs from starting on the specified machines. If a
   class_list is specified, then the classes specified will be drained
   (made unavailable). The literal string "allclasses" can be used as an
   abbreviation for all of the classes.

LL_CONTROL_FLUSH:
   Terminates running jobs on the specified machines and send them back
   to the negotiator to await redispatch (if restart=yes).

LL_CONTROL_PURGE_SCHEDD:
   Purges the specified Schedd host's job queue; a host_list consisting
   of one host name must be specified.

LL_CONTROL_SUSPEND:
   Suspends all jobs on the specified machines. This operation is not
   supported for parallel jobs.

LL_CONTROL_RESUME:
   Resumes job submission to, and job execution on, the specified
   machines.

LL_CONTROL_RESUME_STARTD:
   Resumes job execution on the specified machines; if a class_list is
   specified, then execution of jobs associated with these classes is
   resumed.

LL_CONTROL_RESUME_SCHEDD:
   Resumes job submission to the specified machines.

LL_CONTROL_DUMP_LOGS:
   Allows the request to dump the logging buffer.

For these llctl type of operations, the user_list, job_list, and
priority arguments are not used and should be set to NULL or zero. The
class_list argument is meaningful only if the operation is
LL_CONTROL_DRAIN_STARTD, or LL_CONTROL_RESUME_STARTD. If class_list is
not being used, then it should be set to NULL. If host_list is NULL,
then the scope of the operation is all machines in the LoadLeveler
cluster. Unlike the standalone llctl command, where the scope of the
operation is either global or one host, ll_control operations allow the
user to specify a list of hosts (through the host_list argument). To
perform these operations, the calling program must have LoadLeveler
administrator authority. The only exception to this rule is the
LL_CONTROL_START operation.

llfavorjob type of operations: The llfavorjob type of control operations
are: LL_CONTROL_FAVOR_JOB, and LL_CONTROL_UNFAVOR_JOB. For these
operations, the user_list, host_list, class_list, and priority arguments
are not used and should be set to NULL or zero. LL_CONTROL_FAVOR_JOB is
used to set specified job steps to a higher system priority than all job
steps that are not favored. LL_CONTROL_UNFAVOR_JOB is used to unfavor
previously favored job steps, restoring the original priorities. The
calling program must have LoadLeveler administrator authority to perform
these operations.

llfavoruser type of operations: The llfavoruser type of control
operations are: LL_CONTROL_FAVOR_USER, and LL_CONTROL_UNFAVOR_USER. For
these operations, the host_list, job_list, class_list, and priority
arguments are not used and should be set to NULL or zero.
LL_CONTROL_FAVOR_USER sets jobs of one or more users to the highest
priority in the system, regardless of the current setting. Jobs already
running are not affected. LL_CONTROL_UNFAVOR_USER is used to unfavor
previously favored user's jobs, restoring the original priorities. The
calling program must have LoadLeveler administrator authority to perform
these operations.

llhold type of operations: The llhold type of control operations are:
LL_CONTROL_HOLD_USER, LL_CONTROL_HOLD_SYSTEM, and
LL_CONTROL_HOLD_RELEASE. For these operations, the class_list and
priority arguments are not used, and should be set to NULL or zero.
LL_CONTROL_HOLD_USER and LL_CONTROL_HOLD_SYSTEM place jobs in user hold
and system hold, respectively. LL_CONTROL_HOLD_RELEASE is used to
release jobs from both types of hold. The calling program must have
LoadLeveler administrator authority to put jobs into system hold, and to
release jobs from system hold. If a job is in both user and system holds
then the LL_CONTROL_HOLD_RELEASE operation must be performed twice to
release the job from both types of hold. If the user is not a
LoadLeveler administrator then the llhold types of operations have no
effect on jobs that do not belong to that user.

llprio type of operations: The llprio type of control operations are:
LL_CONTROL_PRIO_ABS, and LL_CONTROL_PRIO_ADJ. For these operations, the
user_list, host_list, and class_list arguments are not used, and should
be set to NULL. llprio type of operations change the user priority of
one or more job steps in the LoadLeveler queue. LL_CONTROL_PRIO_ABS
specifies a new absolute value of the user priority, and
LL_CONTROL_PRIO_ADJ specifies an adjustment to the current user
priority. The valid range of LoadLeveler user priorities is 0-100
(inclusive); 0 is the lowest possible priority, and 100 is the highest.
The llprio type of operations have no effect on a running job step
unless this job step returns to Idle state. If the user is not a
LoadLeveler administrator, then an llprio type of operation has no
effect on jobs that do not belong to that user.

Return Values

0        The specified command has been sent to the appropriate
         LoadLeveler daemon.
-2       The specified command cannot be sent to the central manager.
-3       The specified command cannot be sent to one of the LoadL_master
         daemons.
-4       ll_control encountered an error while processing the
         administration or configuration file.
-6       A data transmission failure has occurred.
-7       The calling program does not have LoadLeveler administrator
         authority.
-19      An incorrect ll_control version has been specified.
-20      A system error has occurred.
-21      The system cannot allocate memory.
-22      A control_op operation that is not valid has been specified.
-23      The job_list argument contains one or more errors.
-24      The host_list argument contains one or more errors.
-25      The user_list argument contains one or more errors.
-26      Incompatible arguments have been specified for HOLD operation.
-27      Incompatible arguments have been specified for PRIORITY
         operation.
-28      Incompatible arguments have been specified for FAVORJOB
         operation.
-29      Incompatible arguments have been specified for FAVORUSER
         operation.
-30      An error occurred while ll_control tried to start a child
         process.
-31      An error occurred while ll_control tried to start the
         LoadL_master daemon.
-32      An error occurred while ll_control tried to execute the
         llpurgeschedd command.
-33      The class_list argument contains incompatible information.
-34      ll_control cannot create a file in the /tmp directory.
-35      LoadLeveler has encountered miscellaneous incompatible input
         specifications.
-41      This release of LoadLeveler for Linux does not support CTSEC.

Related Information

Commands: llctl, llfavorjob, llfavoruser, llhold, llprio



ll_modify subroutine

Purpose

ll_modify - Modifies the attributes of a submitted job step.

In LoadLeveler for Linux only, ll_modify returns an error condition when
SEC_ENABLEMENT is CTSEC.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_modify (int version, void *errObj, LL_modify_param **param,
               char **steplist);

Parameters

version
   Input parameter that indicates the LoadLeveler API version (should
   have the same value as LL_API_VERSION in llapi.h).

errObj
   Provides the address of a pointer to LL_element that points to an
   error object if this function fails. 

   The caller must free the error object storage before reusing the
   pointer. You can also use the ll_error subroutine to display error
   messages stored in the error object. If you are going to do so, the
   pointer should be initialized to NULL to avoid a segmentation fault
   when the pointer is passed to the ll_error subroutine.

param
   Provides the address of an array of 2 pointers to the LL_modify_param
   structure defined in llapi.h. The first pointer should point to an
   LL_modify_param structure already filled out by the caller. The
   second pointer should be assigned NULL. 

   In the LL_modify_param structure:
    
   type     Describes the attribute to be modified.

   data     Is a pointer to the new attribute value.
    
   All job step attributes types that can be modified through 
   ll_modify( ) are listed in enum LL_modify_op in llapi.h.
    
   The LL_modify_op structure stores user inputs to the function, where:
    
   type     Is the type of the command option.

   data     Is a pointer to the data value associated with the command
            option.

   name     Is a NULL terminated array of job step names. Only a single
            job step is allowed in the current implementation.

steplist
   A NULL terminated array of job or step identifiers. When a job
   identifier is specified, the action of the API is taken for all steps
   of the job. At least one job or step identifier must be specified. 

   The format of a job identifier is host.jobid. The format of a step
   identifier is host.jobid.stepid.
    
   where:
    
   *  host is the name of the machine that assigned the job and step
      identifiers.
   *  jobid is the job number assigned to the job when it was submitted.
   *  stepid is the job step number assigned to the job step when it was
      submitted.
    
   The job or step identifier may be specified in an abbreviated form,
   jobid or jobid.stepid, when the API is invoked on the same machine
   that assigned the job and step identifiers. In this case, LoadLeveler
   will use the local machine's host name to construct the full job or
   step identifier.

Description

ll_modify( ) is the API for the llmodify command. Refer to the llmodify
command for information about other available command options.

In enum LL_modify_op: 
*  The system priority option will be ignored for any job step not in an
   idle state. The data field for the SYSPRIO option is an integer. The
   system priority for a job step set with the SYSPRIO option will not
   be changed when LoadLeveler recalculates system priorities.
*  The keyword value is to be used to specify a string in the form,
   keyword=value, where keyword is the attribute of the job step to
   modify and value is the new value for the attribute. For a list of
   supported keywords and their descriptions, see the llmodify command
   description in TWS LoadLeveler: Using and Administering.
*  The attributes that can be modified by the enums are described in
   the llmodify command in TWS LoadLeveler: Using and Administering.

Return Values

The following return values are defined in llapi.h: 

MODIFY_BAD_BG_CONNECTION
         The Blue Gene connection request was not recognized.

MODIFY_BAD_BG_SHAPE
         The Blue Gene partition shape is bad.

MODIFY_BAD_BG_SIZE
         The Blue Gene partition size request was not positive.

MODIFY__CANT_MODIFY
         The Blue Gene partition exists, but you cannot modify this
         value.

MODIFY__EMPTY_BG_PARTITION
         The Blue Gene requested partition name was blank.

MODIFY_SUCCESS
         Request successfully sent to LoadLeveler.

MODIFY_INVALID_PARAM
         An input parameter that is not valid was specified.

MODIFY_CONFIG_ERROR
         Errors encountered while processing config files.

MODIFY_NOT_IDLE
         Request failed, job step not in IDLE state.

MODIFY_WRONG_JOB_TYPE
         The modify operation is not valid for the job type.

MODIFY_WRONG_STATE
         Request failed, job step in wrong state.

MODIFY_NOT_AUTH
         Caller not authorized.

MODIFY_SYSTEM_ERROR
         LoadLeveler internal system error.

MODIFY_CANT_TRANSMIT
         Communication error while sending request.

MODIFY_CANT_CONNECT
         Failed to connect to LoadLeveler.

MODIFY_INVALID_PARAM
         The specified keyword is not supported.

MODIFY_NO_CTSEC_SUPPORT_ERR
         SEC_ENABLEMENT was set to CTSEC. LoadLeveler for Linux does not
         support CTSEC.

MODIFY_NO_PVM_SUPPORT_ERR
         pvm_root was specified. LoadLeveler for Linux does not support
         PVM.

MODIFY_OVERLAP_RESERVATION
         Request failed. The requested change would cause the job step
         to overlap with a reservation.

Related Information

Commands: llmodify

Subroutines: ll_cluster, ll_error

Examples

/* mymodify.c - make a job step non-preemptable */
#include <stdio.h>
#include <string.h>
#include "llapi.h"

int main(int argc, char *argv[])
{
   int rc, preempt = 0;
   LL_modify_param mycmd, *cmdp[2];
   char *step_list[2];
   LL_element *errObj = NULL;
	char *errmsg;

if (argc < 2) {
   printf("Usage:  exit(1);
}

step_list[0] = argv[1];
step_list[1] = NULL;
printf("\n*** Make Job Step %s non-preemptable ***\n\n",
        step_list[0]);

/* Initialize the LL_modify_param structure */
mycmd.type = STEP_PREEMPTABLE;
mycmd.data = &preempt;

cmdp[0] = &mycmd
cmdp[1] = NULL;

/* Modify job step to be non preemptable */
printf("Modify job step to be non-preemptable\n");;
rc = ll_modify(LL_API_VERSION, &errObj, cmdp, step_list);
if (rc) {
errmsg = ll_error(&errObj, 0);
printf("ll_modify() return code: 
free(errmsg);
      exit(1);
   }
   return 0;
}



ll_move_job subroutine

Purpose

ll_move_job - Moves an idle job from one cluster to another.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_move_job (int version, LL_element **errObj, 
                 LL_move_job_param **param);

Parameters

version
   Input parameter that indicates the LoadLeveler API version (should
   have the same value as LL_API_VERSION in llapi.h).

errObj
   Provides the address of a pointer to LL_element that points to an
   error object if this function fails.

param
   Provides the address of a pointer to an LL_move_job_param structure. 
    
   typedef struct {      
           char *cluster_name;
           char *job_id;      
   } 
   LL_move_job_param;
    
   In the LL_move_job_param structure, the fields are defined as
   follows:
    
   cluster_name
      The name of the cluster to which the job will be moved.

   job_id
      The job ID of the job to be moved.

Description

The ll_move_job( ) subroutine is the API for the llmovejob command.
Refer to the llmovejob command for information about other available
command options.

The ll_move_job API moves a single idle job from one cluster to another.
If any steps within the job are not idle, the transfer request is
rejected and the API returns API_STEP_NOT_IDLE. The remote job retains
the original job_ID from the local cluster. Upon transfer, the remote
cluster performs any user mapping and remote job filtering necessary for
the job.

Any changes made to the idle job in the local cluster by the llmodify
command will not be carried forward to the remote cluster. Any jobs
submitted when the local cluster was not configured as a part of a
multicluster cannot be moved if the cluster's configuration is changed
to a multicluster environment.

Only administrators can issue the ll_move_job( ) subroutine. In a mixed
operating multicluster environment, administrators must ensure the
binary compatibility of the job being transferred.

Return Values

The following return values are defined in llapi.h:

API_OK   Request successfully sent to LoadLeveler.

API_INVALID_INPUT
         An input parameter that is not valid was specified.

API_CONFIG_ERR
         Errors encountered while processing configuration files.

API_CANT_AUTH
         Caller not authorized.

API_CANT_LISTEN
         API cannot create listen socket.

API_CANT_CONNECT
         Failed to connect to LoadLeveler.

API_TIMEOUT
         Timed out waiting for a response.

API_STEP_NOT_IDLE
         Request failed, the job step is not in the IDLE state.

Related Information

Commands: llmovejob



ll_move_spool subroutine

Purpose

ll_move_spool - Moves the job records from the spool directory of one
managing Schedd to another managing Schedd in the local cluster.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_move_spool (int version, LL_move_spool_param ** param, 
                  int (*func) (char *jobid, 
                  int rc, LL_element **messageObj), 
                  LL_element **errObj);

Parameters

version
   Input parameter that indicates the LoadLeveler API version (should
   have the same value as LL_API_VERSION in llapi.h).

param
   Provides the address of a pointer to an LL_move_spool_param
   structure. 
    
   typedef struct {      
           char **schedd_host;   
           char *spool_directory;  
           SpoolData_t data;               
           } LL_move_spool_param;
           
           typedef enum move_spool_data {
                   LL_MOVE_SPOOL_JOBS
           } SpoolData_t;

(*func)(char *jobid, int rc, LL_element **messageObj)
   Specifies the user-supplied function to be called after every job is
   processed. The function must return an integer and must accept as
   input: 
   *  A char pointer representing the job ID processed
   *  An integer representing the return code of the job processing
   *  The address to a pointer of an LL_element data type representing
      any messages generated
    
   The LL_element data type is defined in the llapi.h file. If a
   callback is not desired, the function pointer should be set to NULL.

errObj
   Provides the address of a pointer to LL_element that points to an
   error object if this subroutine returns an unsuccessful return code.

Description

The ll_move_spool( ) subroutine is the API for the llmovespool command.

The ll_move_spool subroutine is intended for recovery purposes only.
This subroutine moves the job records from the spool_directory of one
managing schedd_host to another managing schedd_host in the local
cluster. The ll_move_spool subroutine must be run from a machine that
has read and write access to the specified spool_directory containing
the job records being moved. This machine must also have network
connectivity to the machine running the Schedd daemon that will receive
the job records. Jobs to be moved can be in any state.

The schedd_host that created the job records to be moved must not be
running during the move operation. Jobs within the job queue database
will be unrecoverable if the job queue is updated during the move by any
process other than the ll_move_spool subroutine. The schedd_host that
created the job records to be moved must have the schedd_fenced machine
stanza keyword set to true prior to the ll_move_spool subroutine being
issued.

All moved jobs retain their original job identifiers. The ll_move_spool
subroutine invokes the function specified by the (*func) parameter after
each job is processed. When the job records for a job are successfully
transferred, the schedd_host of the job is updated to represent the new
managing schedd_host and the job records in the specified
spool_directory are deleted. If the transfer for any step within a job
fails, the job records for that step remain in the specified
spool_directory. If for some reason a job fails, the ll_move_spool
subroutine should be reissued against the specified spool_directory to
reprocess the job.

The user-supplied function enables messages to be displayed as each job
is processed without having to wait for all of the jobs to be completed.
If a callback is not desired, the function pointer should be set to
NULL. The callback function must call the ll_error API passing in the
messageObj in order to free the memory allocated to it.

The ll_move_spool subroutine does not move the reservation queue or fair
share scheduling data found within the specified spool_directory.

Only administrators can issue the ll_move_spool subroutine.

A sample is available in:

{$RELEASEDIR}/samples/llmovespool

Return Values

The following return values are defined in llapi.h and can be returned
by the ll_move_spool API:

API_OK   Request successfully sent to LoadLeveler.

API_INPUT_NOT_VALID
         An input parameter that is not valid was specified.

API_CONFIG_ERR
         Errors encountered while processing configuration files.

API_CANT_AUTH
         Caller not authorized.

API_CANT_LISTEN
         API cannot create listen socket.

API_CANT_CONNECT
         Failed to connect to LoadLeveler.

API_TIMEOUT
         Timed out waiting for a response.

API_JOBQ_ERR
         Error occurred reading source job queue or writing to
         destination job queue.

API_SCHEDD_DOWN
         The schedd_host is not accepting jobs.

API_SCHEDD_NOT_FENCED
         The original Schedd machine stanza does not have the
         schedd_fenced keyword set to true.

The following return values are defined in llapi.h and can be passed to
the user-specified function:

API_CANT_TRANSMIT
         schedd_host encountered an error while processing the
         executable or job command file job records.

API_OK   Request successfully sent to LoadLeveler.

API_CANT_CONNECT
         Failed to connect to LoadLeveler.

API_TIMEOUT
         Timed out waiting for a response.

API_JOBQ_ERR
         Error occurred reading source job queue or writing to
         destination job queue.

API_JOB_NOT_FOUND
         schedd_host encountered an error while processing the received
         job.

Related Information

Commands: llmovespool



ll_preempt subroutine

Purpose

ll_preempt - Enables you to preempt a running job step or to resume a
job step that has already been preempted through the llpreempt command
or the ll_preempt subroutine (user-initiated). The ll_preempt subroutine
cannot resume a job step preempted through PREEMPT_CLASS rules
(system-initiated).

The ll_preempt subroutine is not available in LoadLeveler for Linux.

For LoadLeveler 3.3, the ll_preempt subroutine was replaced with the
ll_preempt_jobs subroutine.

Library

LoadLeveler API library, libllapi.a

Syntax

#include "llapi.h"

int ll_preempt (int version, LL_element **errObj, char *job_step, 
                enum LL_preempt_op type);

Parameters

version
   Input parameter that indicates the LoadLeveler API version (should
   have the same value as LL_API_VERSION in llapi.h).

errObj
   Provides the address of a pointer to LL_element that points to an
   error object if this function fails. 

   The caller must free the error object storage before reusing the
   pointer. You can also use the ll_error subroutine to display error
   messages stored in the error object. If you are going to do so, the
   pointer should be initialized to NULL to avoid a segmentation fault
   when the pointer is passed to the ll_error subroutine.

jobstep
   A string used to specify the name of a job step.

type
    
   *  Preempts job step if type equals PREEMPT_STEP
   *  Resumes job step if type equals RESUME_STEP



Description

ll_preempt( ) is the API for the llpreempt command. 
*  This function is for external schedulers
*   Only LoadLeveler administrators have authority to use this function

Return Values

API_OK   Request successfully sent to LoadLeveler.

API_INVALID_INPUT
         An input parameter that is not valid was specified.

API_CONFIG_ERR
         Errors encountered while processing configuration files.

API_CANT_AUTH
         Caller not authorized.

API_CANT_CONNECT
         Failed to connect to LoadLeveler.



ll_preempt_jobs subroutine

Purpose

ll_preempt_jobs - Preempts a set of running job steps using the
specified preempt method or resumes job steps that have already been
preempted with the preempt method of suspend through the llpreempt
command or the ll_preempt_jobs subroutine. The ll_preempt_jobs
subroutine cannot resume a job step that was preempted through the
PREEMPT_CLASS rules or a job step that was preempted with a preempt
method other than suspend.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_preempt_jobs (int version, void *errObj, 
                     LL_preempt_param **param);

Parameters

version
   Is an input parameter that indicates the LoadLeveler API version
   (this should be the same value as LL_API_VERSION in llapi.h).

errObj
   Provides the address of a pointer to an LL_element that points to an
   error object if this function fails.

param
   Is a pointer to an array of structures. The structure specifies the
   parameters for a preempt operation. 
   typedef struct LL_preempt_param {
        enum LL_preempt_op type;
        enum LL_preempt_method method;
        char ** user_list;
        char ** host_list;
        char ** jobstep_list;
   } LL_preempt_param;
   
   enum LL_preempt_op {PREEMPT_STEP, RESUME_STEP};
   
   enum LL_preempt_method {LL_PREEMPT_SUSPEND, LL_PREEMPT_VACATE,
        LL_PREEMPT_REMOVE, LL_PREEMPT_SYS_HOLD, LL_PREEMPT_USER_HOLD}
    
   In the LL_preempt_param structure, the fields are defined as follows:
    
   type     Is the type of operation on the job steps, preempt or
            resume.

   method   Is the method to be used to preempt the specified job steps.
            This argument is ignored if the type argument is not set to
            PREEMPT_STEP. Valid values for this argument are: 
            *  LL_PREEMPT_SUSPEND
            *  LL_PREEMPT_VACATE
            *  LL_PREEMPT_REMOVE
            *  LL_PREEMPT_SYS_HOLD
            *  LL_PREEMPT_USER_HOLD
    
   In the enum LL_preempt_op structure, valid values are: 
   *  PREEMPT_STEP
   *  RESUME_STEP
    
   In the enum LL_preempt_method structure, valid values are:
   *  LL_PREEMPT_SUSPEND
   *  LL_PREEMPT_VACATE
   *  LL_PREEMPT_REMOVE
   *  LL_PREEMPT_SYS_HOLD
   *  LL_PREEMPT_USER_HOLD
    
   user_list
            Is a pointer to a NULL-terminated array of pointers to
            strings containing user names. All running job steps
            belonging to all users in the list and monitored by the
            machine the subroutine is running on will be preempted or
            resumed. If a host_list is also specified, only the user's
            job steps monitored on the specified hosts will be preempted
            or resumed.

   host_list
            Is a pointer to a NULL-terminated array of pointers to
            strings containing host names. All job steps monitored by
            the hosts will be preempted or resumed. If a user_list is
            also provided, only the running job steps monitored by the
            hosts and owned by the specified users will be preempted or
            resumed.

   jobstep_list
            Is a pointer to a NULL-terminated array of job or step
            identifiers. When a job identifier is specified, the action
            of the API is taken for all steps of the job. At least one
            job or step identifier must be specified. 

            The format of a job identifier is host.jobid. The format of
            a step identifier is host.jobid.stepid.
             
            where:
             
            *  host is the name of the machine that assigned the job and
               step identifiers.
            *  jobid is the job number assigned to the job when it was
               submitted.
            *  stepid is the job step number assigned to the job step
               when it was submitted.
             
            The job or step identifier may be specified in an
            abbreviated form, jobid or jobid.stepid, when the API is
            invoked on the same machine that assigned the job and step
            identifiers. In this case, LoadLeveler will use the local
            machine's host name to construct the full job or step
            identifier.
             
            Note: For coscheduled jobs, even if all coscheduled job
                  steps are not in the list of targeted job steps, the
                  requested operation is performed on all coscheduled
                  job steps.

Description

The ll_preempt_jobs( ) subroutine is the API for the llpreempt command.
See the llpreempt command for information about the available command
options. In order to provide source code compatibility for applications
using the current version of the preempt function, the ll_preempt()
subroutine will not be modified to support the new preemption options.
The ll_preempt() subroutine will continue to be supported as is.

Return Values

0        Request successfully sent to the central manager.
-1       An LL_preempt_op that is not valid was specified.
-2       Cannot send request to central manager.
-3       An incorrect version was specified.
-4       Errors encountered while processing the LoadLeveler
         administration or configuration files.
-5       A system error occurred.
-6       A data transmission failure occurred.
-7       The calling program does not have LoadLeveler administrator
         authority.



ll_run_scheduler subroutine

Purpose

ll_run_scheduler - Sends a request to the central manager to run the
scheduling algorithm. It is used when the internal scheduling interval
has been disabled so that an external program can control when the
central manager attempts to schedule job steps.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_run_scheduler (int version);

Parameters

version
   Is an input parameter that indicates the LoadLeveler API version
   (this should be the same value as LL_API_VERSION in llapi.h).

Description

The ll_run_scheduler( ) subroutine sends a request to the central
manager to run the LoadLeveler scheduling algorithm. The central
manager's scheduling algorithm will run only once each time the
llrunscheduler command is invoked. Each time the scheduling algorithm
runs, the central manager will schedule as many job steps as the current
available resources allow. The LoadLeveler scheduling interval must be
disabled, that is the configuration keyword NEGOTIATOR_INTERVAL must be
set to zero in order to use this algorithm. Only LoadLeveler
administrators have authority to use this algorithm.

Return Values

RUN_SCHED_SUCCESS
         Request successfully sent to the central manager.

RUN_SCHED_CONFIG_ERROR
         Errors were encountered while processing configuration files.

RUN_SCHED_NOT_AUTH
         Calling program does not have LoadLeveler administrator
         authority.

RUN_SCHED_NOT_AUTH
         An internal system error occurred.

RUN_SCHED_CANT_TRANSMIT
         A data transmission failure occurred.

RUN_SCHED_CANT_CONNECT
         The Schedd cannot connect to the central manager.



ll_start_job subroutine

Purpose

ll_start_job - Tells the LoadLeveler negotiator to start a job on the
specified nodes.

In LoadLeveler for Linux only, ll_start_job returns an error condition
when SEC_ENABLEMENT is CTSEC.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax
  
#include "llapi.h"

int ll_start_job (LL_start_job_info *ptr);

Parameters

ptr
   Specifies the pointer to the LL_start_job_info structure that was
   allocated by the caller. The LL_start_job_info members are: 

   int version_num
      Represents the version number of the LL_start_job_info structure.
      Should be set to LL_PROC_VERSION.

   LL_STEP_ID StepId
      Represents the step ID of the job step to be started.

   char **nodeList
      Is a pointer to an array of node names where the job will be
      started. The first member of the array is the parallel master
      node. The array must be ended with a NULL.

Description

This subroutine does not allow you to specify adapter usage information.
Use the ll_start_job_ext subroutine instead.

You must set SCHEDULER_TYPE = API in the global configuration file to
use this subroutine.

Only jobs steps currently in the Idle state are started.

Only processes having the LoadLeveler administrator user ID can invoke
this subroutine.

An external scheduler uses this subroutine to start jobs that are in
idle state. The list of jobs that are currently in the system is
retrieved with the ll_get_objs API function, passing in a query element
with type JOBS. The list of machines available to run jobs on is
obtained with the ll_get_objs and a query element with type MACHINES.
Additional data about both jobs and machines is obtained with the
ll_get_data function call.

When this function is used to start a step, adapter resources are
assigned to the step according to job command file network statements,
if they are present. Adapter resources are assigned in the same manner
as the BACKFILL scheduler assigns adapter resources, except that the
Communication Level on the network statement is ignored and a value of
AVERAGE is used. It is the responsibility of the external scheduler to
ensure the machines to which the step is dispatched have sufficient
adapter resources to run the step. Otherwise the step will not be
started.

Return Values

This subroutine returns a value of zero to indicate the start job
request was accepted by the negotiator. However, a return code of zero
does not necessarily imply the job started. You can use the llq command
to verify the job started. Otherwise, this subroutine returns an integer
value defined in the llapi.h file.

Error Values

-1       There is an error in the input parameter.
-2       The subroutine cannot connect to the central manager.
-4       An error occurred reading parameters from the administration or
         the configuration file.
-5       The negotiator cannot find the specified StepId in the
         negotiator job queue.
-6       A data transmission failure occurred.
-7       The subroutine cannot authorize the action because you are not
         a LoadLeveler administrator.
-8       The job object version number is incorrect.
-9       The StepId is not in the Idle state.
-10      One of the nodes specified is not available to run the job.
-11      One of the nodes specified does not have an available initiator
         for the class of the job.
-12      For one of the nodes specified, the requirements statement does
         not satisfy the job requirements.
-13      The number of nodes specified was less than the minimum or more
         than the maximum requested by the job.
-14      The LoadLeveler default scheduler is enabled.
-15      The same node was specified twice in ll_start_job nodelist.

Examples

Makefiles and examples which use this subroutine are located in the
samples/llsch subdirectory of the release directory. The examples
include the executable sch_api, which invokes the query API and the job
control API to start the second job in the list received from
ll_get_jobs on two nodes. You should submit at least two jobs prior to
running the sample. To compile sch_api, copy the sample to a writeable
directory and update the RELEASE_DIR field to represent the current
LoadLeveler release directory.

Related Information

Subroutines: ll_get_jobs, ll_get_nodes, ll_start_job_ext,
ll_terminate_job



ll_start_job_ext subroutine

Purpose

ll_start_job_ext - Tells the LoadLeveler negotiator to start a job on
the specified nodes, indicating which adapter and adapter resources to
use.

In LoadLeveler for Linux only, ll_start_job_ext returns an error
condition when SEC_ENABLEMENT is CTSEC.

An external scheduler uses this subroutine to start jobs that are in
idle state. The list of jobs that are currently in the system is
retrieved with the ll_get_objs API function, passing in a query element
with type JOBS. The list of machines available to run jobs on is
obtained with the ll_get_objs and a query element with type MACHINES.
Additional data about both jobs and machines is obtained with the
ll_get_data function call.

When this function is used to start a step, the external scheduler
specifies the adapter resources that are assigned to the step and
network statements in the job command file, if they are present, are
ignored. It is the responsibility of the external scheduler to manage
the availability of adapter resources and LoadLeveler does not prevent
or detect the over commitment of adapter resources.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax
  
#include "llapi.h"

int ll_start_job_ext (LL_start_job_info_ext *ptr);

Parameters

ptr
   Specifies the pointer to the LL_start_job_info_ext structure that was
   allocated and populated by the caller. The LL_start_job_info_ext
   members are: 

   int version_num
      Represents the version number of the LL_start_job_info_ext
      structure. Should be set to LL_PROC_VERSION.

   LL_STEP_ID StepId
      Represents the step ID of the job step to be started.

   char ** nodelist
      A pointer to an array of node names where the job will be started.
      The first member of the array is the parallel master node. The
      array must be ended with a NULL.

   int adapterUsageCount
      This is the size of the adapterUsage list. To determine what this
      number should be, add all the adapter usages for all protocols
      needed by one task and multiply the result by the number of tasks
      in the job.

   LL_ADAPTER_USAGE * adapterUsage
      This is a list of adapter information. The size of this list is
      given by adapterUsageCount. The members of this structure are: 

      char * dev_name
         The device name of the adapter to be used.

      char * protocol
         A character string representing the communication protocol this
         usage supports. Valid values are MPI, LAPI, and MPI_LAPI.

      char * subsystem
         The communication subsystem this usage supports. Valid values
         are IP or US.

      int wid
         For US subsystem usages, this indicates which adapter window ID
         to use. For IP subsystem usages, this field is ignored.

      uint64_t mem
         For US subsystem usages, this is the amount of adapter memory
         to dedicate to the adapter usage. For IP subsystem usages, this
         field is ignored.

      uint64_t api_rcxtblocks
         For US subsystem usages, this is the number of user rCxt blocks
         to allocate for each adapter window. For IP subsystem usages,
         this field is ignored. 

         Note: 
               1. This field should only be used on systems which
                  contain Switch_Network_Interface_For_HPS adapters.
                  When using this field, the mem field should not be
                  used.
               2. Previously existing applications which use
                  ll_start_job_ext can be used unchanged to start jobs
                  on systems with Switch_Network_Interface_For_HPS
                  adapters, the value previously specified for the
                  memory request will be ignored.

Each element in the adapterUsage list represents one communication
channel for a task. If the subsystem is US (User Space), a communication
channel will require a switch adapter window. Adapter windows, and User
Space usages, must be specified on actual switch adapters that are only
accessible if AGGREGATE_ADAPTERS=False is specified in the configuration
file.

Description

You must set SCHEDULER_TYPE = API in the global configuration file to
use this subroutine. In order to have access to the physical switch
adapters in the LoadLeveler cluster (as opposed to virtual adapters
representing all of the adapters on a network or adapters striping
across multiple networks) you must specify AGGREGATE_ADAPTERS = False in
the global configuration file.

Only jobs steps currently in the Idle state are started.

Only processes having the LoadLeveler administrator user ID can invoke
this subroutine.

An external scheduler uses this subroutine in conjunction with the
ll_query and ll_get_data subroutines of the query API. The query API
returns information about which machines are available for scheduling
and which jobs are currently in the job queue waiting to be scheduled.

The node list that is passed to the external scheduler API specifies the
node on which each task of the job being started is to run. The
distribution of tasks to nodes in the node list must be consistent with
the node allocation specified by the job command file of the job being
started. If it is not, the results are undefined and the job may fail to
start or may start with incorrect node assignments. Except when BLOCKING
is specified, the entries for tasks that are running on the same node
must all be specified sequentially in the node list. The following table 
describes how nodes should be arranged in the node list for the possible
combinations of node and task specification in the job command file. In
the table, '/' denotes integer division and (N mod M) is the remainder
of the integer division of N by M.

How nodes should be arranged in the node list
+-----------------------------+---------------------------------------+
| Job command file            | Required nodelist structure           |
| specification               |                                       |
+-----------------------------+---------------------------------------+
|                             | There must be N different machine     |
| node=N                      | names specified, each specified T     |
| tasks_per_node=T            | times.                                |
+-----------------------------+---------------------------------------+
|                             | There must be between N and M         |
| node=N,M                    | different machine names specified,    |
| tasks_per_node=T            | each specified T times.               |
+-----------------------------+---------------------------------------+
|                             | There must be N different machine     |
| node=N                      | names specified, each specified TT/N  |
| total_tasks=TT              | times.                                |
| TT evenly divisible by N    |                                       |
+-----------------------------+---------------------------------------+
|                             | There must be N different machine     |
| node=N                      | names specified. The first (TT mod N) |
| total_tasks=TT              | unique machine names must each be     |
| TT not evenly divisible by  | specified (TT/N +1) times and the     |
| N                           | remaining machine names are each      |
|                             | specified TT/N times.                 |
+-----------------------------+---------------------------------------+
|                             | There must be TT/B sets of machine    |
| total_tasks=TT              | names specified, each set specifies a |
| BLOCKING=B                  | machine name B times. It is           |
|                             | permissible for a machine name to be  |
| TT evenly divisible by B    | specified in more than one set.       |
+-----------------------------+---------------------------------------+
|                             | There must be TT/B+1 sets of machine  |
| total_tasks=TT              | names specified. The first TT/B sets  |
| BLOCKING=B                  | specify a machine name B times. The   |
| TT not evenly divisible by  | last set specifies a machine name (TT |
| B                           | mod B) times. It is permissible for a |
|                             | machine name to be specified in more  |
|                             | than one set.                         |
+-----------------------------+---------------------------------------+
|                             | There must be TT entries in the node  |
| total_tasks=TT              | list. It is permissible for a machine |
| BLOCKING=UNLIMITED          | name to be specified in the list more |
|                             | than once and it is not required that |
|                             | the specifications be contiguous.     |
+-----------------------------+---------------------------------------+
|                             | There is a 1:1 correspondence between |
| task_geometry               | entries in the nodelist and task ids  |
|                             | specified in the task geometry        |
|                             | statement. Entries in the node list   |
|                             | that correspond to task IDs in the    |
|                             | same set must specify the same        |
|                             | machine. Entries in the node list     |
|                             | that correspond to task IDs in        |
|                             | different sets must specify different |
|                             | machines.                             |
+-----------------------------+---------------------------------------+

Return Values

This routine returns a nonzero value to indicate the start request was
not delivered to the negotiator. These values are defined in the llapi.h
file and explained in "Error values." A return code of zero indicates
the request was successfully delivered to the negotiator, but
constraints on the negotiator may stop the job from starting. You can
use the llq command to verify the job started.

Error Values

-1       There is an error in the input parameter.
-2       The subroutine cannot connect to the central manager.
-4       An error occurred reading parameters from the administration or
         the configuration file.
-5       The negotiator cannot find the specified StepId in the
         negotiator job queue.
-6       A data transmission failure occurred.
-7       The subroutine cannot authorize the action because you are not
         a LoadLeveler administrator.
-8       The job object version number is incorrect.
-9       The StepId is not in the Idle state.
-10      One of the nodes specified is not available to run the job.
-11      One of the nodes specified does not have an available initiator
         for the class of the job.
-12      For one of the nodes specified, the requirements statement does
         not satisfy the job requirements.
-13      The number of nodes specified was less than the minimum or more
         than the maximum requested by the job.
-14      The LoadLeveler default scheduler is enabled.
-15      The same node was specified twice in the ll_start_job nodelist.
-20      Adapter usage information does not match job structure.
-21      Adapter usage requested an adapter not on the machine.
-22      Wrong number of entries on adapter usage list.
-23      The adapter usage information did not specify the same protocol
         usage on each task.
-24      An invalid protocol string was specified on an adapter usage.
-25      The adapter usages specified incompatible protocols
-26      An adapter usage specified a communication subsystem that was
         not IP or US

Examples

Makefiles and examples which use this subroutine are located in the
samples/llsch subdirectory of the release directory. The examples
include the executable sch_api_ext, which invokes the query API and the
job control API to start the first job in the list received from
ll_query on one node and to cancel the second job in the list. To
compile sch_api_ext, copy the sample to a writeable directory and update
the RELEASE_DIR field to represent the current LoadLeveler release
directory.

Related Information

Subroutines: ll_get_data, ll_query, ll_start_job, ll_terminate_job



ll_terminate_job subroutine

Purpose

ll_terminate_job - Tells the negotiator to cancel the specified job
step.

In LoadLeveler for Linux only, ll_terminate_job returns an error
condition when SEC_ENABLEMENT is CTSEC.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax
  
#include "llapi.h"

int ll_terminate_job (LL_terminate_job_info *ptr);

Parameters

ptr
   Specifies the pointer to the LL_terminate_info structure that was
   allocated by the caller. The LL_terminate_job_info members are: 

   int version_num
      Represents the version number of the LL_terminate_job_info
      structure. Should be set to LL_PROC_VERSION.

   LL_STEP_ID StepId
      Represents the step ID of the job step to be terminated. 

      Note: For coscheduled jobs, even if all coscheduled job steps are
            not in the list of targeted job steps, the requested
            operation is performed on all coscheduled job steps.

   char *msg
      A pointer to a null terminated array of characters. If this
      pointer is null or points to a null string, a default message is
      used. This message will be available through ll_get_data to tell
      the process why a program was terminated.

Description

Only processes having the LoadLeveler administrator user ID can invoke
this subroutine.

An external scheduler uses this subroutine in conjunction with the
ll_query and ll_get_data subroutines of the query API. The external
scheduler must use this subroutine to terminate interactive parallel
jobs that cannot be run.

Return Values

This subroutine returns a value of zero when successful, to indicate the
terminate job request was accepted by the negotiator. However, a return
code of zero does not necessarily imply the negotiator canceled the job.
Use the llq command to verify the job was canceled. Otherwise, this
subroutine returns an integer value defined in the llapi.h file.

Error Values

-1       There is an error in the input parameter.
-4       An error occurred reading parameters from the administration or
         the configuration file.
-6       A data transmission failure occurred.
-7       The subroutine cannot authorize the action because you are not
         a LoadLeveler administrator or you are not the user who
         submitted the job.
-8       The job object version number is incorrect.

Examples

Makefiles and examples which use this subroutine are located in the
samples/llsch subdirectory of the release directory. The examples
include the executable sch_api, which invokes the query API and the job
control API to terminate the first job reported by the ll_get_jobs
subroutine. You should submit at least two jobs prior to running the
sample. To compile sch_api, copy the sample to a writeable directory and
update the RELEASE_DIR field to represent the current LoadLeveler
release directory.

Related Information

Subroutines: ll_get_jobs, ll_get_nodes, ll_start_job
