
Reservation API

This API allows you to make, change, and remove reservations. In
addition, it provides the ability to bind job steps to a reservation and
unbind job steps from a reservation. General users should see "Working
with reservations" in TWS LoadLeveler: Using and Administering for
additional information. Additional information for LoadLeveler
administrators is in "Configuring LoadLeveler to support reservations"
in TWS LoadLeveler: Using and Administering.

This API consists of the following subroutines:

*  ll_bind subroutine
*  ll_change_reservation subroutine
*  ll_init_reservation_param subroutine
*  ll_make_reservation subroutine
*  ll_remove_reservation subroutine



ll_bind subroutine

Purpose

ll_bind - Enables you to bind job steps to a reservation. The ll_bind
subroutine can also be used to unbind a list of job steps from the
reservations to which they are currently bound to, or whichever
reservation they have requested to bind to in the event that the bind
has not yet occurred.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_bind (int version, LL_element **errOBJ, LL_bind_param **param);

Parameters

version
   Is an input parameter that indicates the LoadLeveler API version
   (this should be the same value as LL_API_VERSION in llapi.h).

errObj
   Provides the address of a pointer to an LL_element that points to an
   error object if this function fails. 

   The caller must free the error object storage before reusing the
   pointer. You can also use the ll_error subroutine to display error
   messages stored in the error object. If you are going to use the
   ll_error subroutine, the pointer must be initialized to NULL to
   ensure that a valid pointer is passed to the ll_error subroutine.

param
   Provides the address of a pointer to a LL_bind_param structure as
   defined in llapi.h. 

   In the LL_bind_param structure, the fields are defined as follows:
    
   char **jobsteplist
            A NULL-terminated array of job or step identifiers. When a
            job identifier is specified, the action of the API is taken
            for all steps of the job. At least one job or step
            identifier must be specified. 

            The format of a job identifier is host.jobid. The format of
            a step identifier is host.jobid.stepid.
             
            where:
             
            *  host is the name of the machine that assigned the job and
               step identifiers.
            *  jobid is the job number assigned to the job when it was
               submitted.
            *  stepid is the job step number assigned to the job step
               when it was submitted.
           
            The job or step identifier may be specified in an
            abbreviated form, jobid or jobid.stepid, when the API is
            invoked on the same machine that assigned the job and step
            identifiers. In this case, LoadLeveler will use the local
            machine's hostname to construct the full job or step
            identifier.
             
            Note: For coscheduled jobs, even if all coscheduled job
                  steps are not in the list of targeted job steps, the
                  requested operation is performed on all coscheduled
                  job steps.

   char *ID The reservation identifier. The format of a full LoadLeveler
            reservation identifier is [host.]rid[.r]. 

            where:
             
            *  host is the name of the machine that assigned the
               reservation identifier.
            *  rid is the number assigned to the reservation when it was
               created. An rid is required.
            *  r indicates that this is a reservation ID (r is
               optional).
             
            The reservation identifier may be specified in an
            abbreviated form, rid[.r], when the API is invoked on the
            same machine that assigned the reservation identifier. In
            this case, LoadLeveler will use the local machine's host
            name to construct the full reservation identifier.

   int unbind
            Indicates that a value of 1 means that the job steps in
            jobsteplist are to be unbound from the reservations to which
            they are currently bound. A value of 0 indicates that the
            job steps in the job step list are to be bound to the
            reservation specified by the ID.

Description

The ll_bind( ) subroutine is the API for the llbind command.

This function is for the BACKFILL scheduler only and only jobs in an
idle-like state can be bound to a reservation.

LoadLeveler administrators can bind any job step to a reservation. If a
job step is already bound to a reservation, it will first be unbound
from the current reservation before being bound to the requested
reservation. Nonadministrators must be the owner of the job steps to be
bound or unbound, and either be the owner of the reservation or one of
the users specified by the owner as having permission to use the
reservation.

Return Values

RESERVATION_OK
         Request successfully sent to LoadLeveler.
RESERVATION_REQUEST_DATA_NOT_VALID
         Input is not valid.
RESERVATION_CONFIG_ERR
         Errors were encountered while processing configuration files.
RESERVATION_NO_STORAGE
         The system cannot allocate memory.
RESERVATION_CANT_TRANSMIT
         A data transmission failure occurred.
RESERVATION_API_CANT_CONNECT
         The subroutine cannot connect to the Schedd or central manager.
RESERVATION_NOT_SUPPORTED
         The scheduler in use does not support reservations.
RESERVATION_NOT_EXIST
         The reservation does not exist.
RESERVATION_NO_PERMISSION
         Permission cannot be granted.
RESERVATION_WRONG_STATE
         The reservation is not in the correct state.

Related Information

Commands: llbind

Subroutines: ll_error, ll_make_reservation



ll_change_reservation subroutine

Purpose

ll_change_reservation - Enables you to change the attributes of a
reservation.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_change_reservation (int version, LL_element **errOBJ, char **ID, 
                           LL_reservation_change_param **param);

Parameters

version
   Is an input parameter that indicates the LoadLeveler API version
   (this should be the same value as LL_API_VERSION in llapi.h).

errObj
   Provides the address of a pointer to an LL_element that points to an
   error object if this function fails. 

   The caller must free the error object storage before reusing the
   pointer. You can also use the ll_error subroutine to display error
   messages stored in the error object. If you are going to use the
   ll_error subroutine, the pointer must be initialized to NULL to
   ensure that a valid pointer is passed to the ll_error subroutine.
    
   When using a job command file to change a reservation once the job is
   successfully submitted, an informational message will be returned in
   errObj that contains the name of the job.

ID 
   Provides the reservation identifier. The format of a full LoadLeveler
   reservation identifier is [host.]rid[.r]. 

   where:
    
   *  host is the name of the machine that assigned the reservation
      identifier.
   *  rid is the number assigned to the reservation when it was created.
      An rid is required.
   *  r indicates that this is a reservation ID (r is optional).
    
   The reservation identifier may be specified in an abbreviated form,
   rid[.r], when the API is invoked on the same machine that assigned
   the reservation identifier. In this case, LoadLeveler will use the
   local machine's host name to construct the full reservation
   identifier.

param
   Provides the address of a pointer to a NULL-terminated array of
   LL_reservation_change_param structures as defined in llapi.h. The
   caller must allocate and free storage for the LL_reservation_change
   structures. 

   In the LL_reservation_change_param structure, the fields are defined
   as follows:
    
   enum LL_reservation_data type
            Contains the type of the data to modify. 

enum LL_reservation_data type
+-----------------+----------------------------------+----------------+
| To modify       | Specify                          | Type of new    |
|                 |                                  | data           |
+-----------------+----------------------------------+----------------+
| duration        | RESERVATION_ADD_DURATION         | int *          |
+-----------------+----------------------------------+----------------+
| duration        | RESERVATION_DURATION             | int *          |
+-----------------+----------------------------------+----------------+
| group           | RESERVATION_GROUP                | char *         |
+-----------------+----------------------------------+----------------+
| grouplist       | RESERVATION_ADD_GROUPS           | char **, NULL  |
|                 |                                  | terminated     |
+-----------------+----------------------------------+----------------+
| grouplist       | RESERVATION_DEL_GROUPS           | char **, NULL  |
|                 |                                  | terminated     |
+-----------------+----------------------------------+----------------+
| grouplist       | RESERVATION_GROUPLIST            | char **, NULL  |
|                 |                                  | terminated     |
+-----------------+----------------------------------+----------------+
| hostfile        | RESERVATION_BY_HOSTFILE          | char *         |
+-----------------+----------------------------------+----------------+
| hostlist        | RESERVATION_ADD_HOSTS            | char **, NULL  |
|                 |                                  | terminated     |
+-----------------+----------------------------------+----------------+
| hostlist        | RESERVATION_BY_HOSTLIST          | char **, NULL  |
|                 |                                  | terminated     |
+-----------------+----------------------------------+----------------+
| hostlist        | RESERVATION_DEL_HOSTS            | char **, NULL  |
|                 |                                  | terminated     |
+-----------------+----------------------------------+----------------+
| job_command_fil | RESERVATION_BY_JCF               | char *         |
| e               |                                  |                |
+-----------------+----------------------------------+----------------+
| jobstep         | RESERVATION_BY_JOBSTEP           | char *         |
+-----------------+----------------------------------+----------------+
| number_of_bg_cn | RESERVATION_BY_BG_CNODE          | int *          |
| odes            |                                  |                |
+-----------------+----------------------------------+----------------+
| number_of_nodes | RESERVATION_ADD_NUM_NODE         | int *          |
+-----------------+----------------------------------+----------------+
| number_of_nodes | RESERVATION_BY_NODE              | int *          |
+-----------------+----------------------------------+----------------+
| owner           | RESERVATION_OWNER                | char *         |
+-----------------+----------------------------------+----------------+
| remove on idle  | RESERVATION_MODE_REMOVE_ON_IDLE  | int *; *data = |
| mode            |                                  | 0: Do not      |
|                 |                                  | remove on Idle |
|                 |                                  | *data = 1:     |
|                 |                                  | Remove on Idle |
+-----------------+----------------------------------+----------------+
| shared mode     | RESERVATION_MODE_SHARED          | int *; *data = |
|                 |                                  | 0: Not Shared  |
|                 |                                  | *data = 1:     |
|                 |                                  | Share          |
+-----------------+----------------------------------+----------------+
| start_time      | RESERVATION_ADD_START_TIME       | int *          |
+-----------------+----------------------------------+----------------+
| start_time      | RESERVATION_START_TIME           | char *         |
+-----------------+----------------------------------+----------------+
| userlist        | RESERVATION_ADD_USERS            | char **, NULL  |
|                 |                                  | terminated     |
+-----------------+----------------------------------+----------------+
| userlist        | RESERVATION_DEL_USERS            | char **, NULL  |
|                 |                                  | terminated     |
+-----------------+----------------------------------+----------------+
| userlist        | RESERVATION_USERLIST             | char **, NULL  |
|                 |                                  | terminated     |
+-----------------+----------------------------------+----------------+
            
            If several options are available to modify the same type of
            data, only one is allowed. For example, RESERVATION_DURATION
            and RESERVATION_ADD_DURATION are mutually exclusive.
            number_of_nodes, hostlist, jobstep, job_command_file,
            number_bg_cnodes, and host_file are all used to modify the
            reserved nodes and, therefore, the associated enums are all
            mutually exclusive.
             
            The duration of a reservation can be decreased
            (corresponding to the -d -nn option on llchres) by
            specifying the data type RESERVATION_ADD_DURATION and
            providing a negative value. The same is true for
            RESERVATION_ADD_NUM_NODE and RESERVATION_ADD_START_TIME.

   void *data
            Specifies the new data for the modification corresponding to
            type.

Description

The ll_change_reservation( ) subroutine is the API for the llchres
command. The "Notes on changing a reservation" listed in the llchres
command also apply to the ll_change_reservation subroutine.

More than one attribute of a reservation can be changed with a single
call. Either all of the changes can and will be made, or none of the
changes will be made. If the changes cannot be made, errObj will contain
a message indicating a reason for the failure. The message may not
contain all of the reasons the request cannot be satisfied.

A coscheduled job step cannot be used for changing a reservation.

This function is for the BACKFILL scheduler only.

Only LoadLeveler administrators and the owner of the reservation can use
this function.

Return Values

RESERVATION_OK
         Request successfully sent to LoadLeveler.
RESERVATION_TOO_CLOSE
         Reservation is being made within the minimum advance time.
RESERVATION_NO_STORAGE
         The system cannot allocate memory.
RESERVATION_CONFIG_ERR
         Errors were encountered while processing configuration files.
RESERVATION_USER_LIMIT_EXCEEDED
         Exceeds the maximum number of reservations for the user.
RESERVATION_GROUP_LIMIT_EXCEEDED
         Exceeds the maximum number of reservations for the group.
RESERVATION_NO_PERMISSION
         Permission cannot be granted.
RESERVATION_WRONG_STATE
         The reservation is not in the correct state.
RESERVATION_API_CANT_CONNECT
         The subroutine cannot connect to the Schedd or central manager.
RESERVATION_JOB_SUBMIT_FAILED
         Submit of the job command file failed.
RESERVATION_NO_MACHINE
         One or more machines in the host list are not in the
         LoadLeveler cluster.
RESERVATION_WRONG_MACHINE
         Reservations are not permitted on one or more machines in the
         host list.
RESERVATION_NO_RESOURCE
         Insufficient resources in the LoadLeveler cluster.
RESERVATION_NO_JOBSTEP
         The job step used for node selection does not exist.
RESERVATION_WRONG_JOBSTEP
         The job step used for node selection is not in the right state.
RESERVATION_NOT_SUPPORTED
         The scheduler in use does not support reservations.
RESERVATION_NOT_EXIST
         The reservation does not exist.
RESERVATION_REQUEST_DATA_NOT_VALID
         Input is not valid.
RESERVATION_CANT_TRANSMIT
         A data transmission failure occurred.
RESERVATION_TOO_LONG
         The duration exceeds the maximum reservation duration.
RESERVATION_HOSTFILE_ERR
         Errors were encountered while processing the host file.

Related Information

Commands: llchres

Subroutines: ll_error, ll_make_reservation



ll_init_reservation_param subroutine

Purpose

ll_init_reservation_param - Initializes the optional fields in the
LL_reservation_param structure to default values prior to passing that
structure to the ll_make_reservation subroutine.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_init_reservation_param (int version, LL_element **errOBJ, 
                               LL_reservation_param **param);

Parameters

version
   Is an input parameter that indicates the LoadLeveler API version
   (this should be the same value as LL_API_VERSION in llapi.h).

errObj
   Provides the address of a pointer to an LL_element that points to an
   error object if this function fails. 

   The caller must free the error object storage before reusing the
   pointer. You can also use the ll_error subroutine to display error
   messages stored in the error object. If you are going to use the
   ll_error subroutine, the pointer must be initialized to NULL to
   ensure that a valid pointer is passed to the ll_error subroutine.

param
   Provides the address of a pointer to a LL_reservation_param
   structure. The LL_reservation_param structure will be initialized.

Description

The ll_init_reservation_param( ) subroutine is used in conjunction with
the ll_make_reservation subroutine. A program using this function would
only have to set the required fields and any optional fields where the
default value is not applicable.

Return Values

This subroutine returns a zero to indicate success.

Related Information

Subroutines: ll_make_reservation



ll_make_reservation subroutine

Purpose

ll_make_reservation - Enables you to create a LoadLeveler reservation.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_make_reservation (int version, LL_element **errOBJ, 
                         LL_reservation_param **param);

Parameters

version
   Is an input parameter that indicates the LoadLeveler API version
   (this should be LL_API_VERSION).

errObj
   Provides the address of a pointer to an LL_element that points to an
   error object if this function fails. 

   The caller must free the error object storage before reusing the
   pointer. You can also use the ll_error subroutine to display error
   messages stored in the error object. If you are going to use the
   ll_error subroutine, the pointer must be initialized to NULL to
   ensure that a valid pointer is passed to the ll_error subroutine.
    
   If a job command file is used to create a reservation and the job is
   successfully submitted, an informational message will be returned.

param
   Provides the address of a pointer to a LL_reservation_param structure
   defined in llapi.h. The caller must allocate and free storage for
   this structure. It is suggested that the caller use the
   ll_init_reservation_param call to initialize the structure. 

   In the LL_reservation_param structure, the fields are defined as
   follows:
    
   char **ID
            Contains the address where the reservation ID is to be
            returned.

   char *start_time
            Contains a string specifying the start time of a reservation
            in the format of "[mm/dd[/[cc]yy] ]HH:MM".

   int duration
            Specifies how long the reservation lasts in the unit of
            minutes.

   enum LL_reservation_data data_type
            Indicates how the nodes should be reserved. The valid values
            are: 
            RESERVATION_BY_NODE            by number of nodes
            RESERVATION_BY_HOSTLIST        by specifying a hostlist
            RESERVATION_BY_JOBSTEP         by specifying a jobstep
            RESERVATION_BY_JCF             by job command file
            RESERVATION_BY_BG_CNODE        by number of Blue Gene 
                                           c-nodes
            RESERVATION_BY_HOSTFILE        by specifying a host file

   void *data
            Contains the pointer to the actual data specifying what
            nodes to reserve: 
            data_type                      data is a pointer of the type
            RESERVATION_BY_NODE            int *
            RESERVATION_BY_HOSTLIST        char **, a NULL terminated 
                                           array of machine names
            RESERVATION_BY_JOBSTEP         char *, a jobstep name in the 
                                           format of host.jobid.stepid
            RESERVATION_BY_JCF             char *, the full pathname 
                                           to a LoadLeveler Job Command 
                                           File
            RESERVATION_BY_BG_CNODE        int * for number of Blue Gene 
                                           c-nodes
            RESERVATION_BY_HOSTFILE        char *, name of a file 
                                           containing a list of machine 
                                           names

   int options
            Specifies options that control characteristics of the
            reservation. The follow values can be OR'ed together to set
            this parameter: 

            RESERVATION_SHARED
                     Selects the SHARED option for the reservation. For
                     a SHARED reservation, after all bound job steps
                     which can run on the reserved nodes are scheduled
                     to run, the remaining resources can be used to run
                     job steps not bound to the reservation. Only bound
                     job steps can be scheduled to run on a reservation
                     that is not shared.

            RESERVATION_REMOVE_ON_IDLE
                     Selects the REMOVE_ON_IDLE option for the
                     reservation. For a REMOVE_ON_IDLE reservation, if
                     all bound job steps are finished or if all bound
                     job steps are Idle and none can run on the reserved
                     nodes, the reservation will be removed (canceled)
                     automatically by LoadLeveler. If this option is not
                     set, the reservation will remain, regardless of
                     being used or not.

   char **users
            Contains the list of users who can use the reservation. This
            pointer should be set to NULL so only the reservation owner
            and the LoadLeveler administrator can use the reservation.

   char **groups
            Contains the list of LoadLeveler groups whose users can use
            the reservation. This pointer should be set to NULL so only
            the list of LoadLeveler groups and the LoadLeveler
            administrator can use the reservation.

   char *group
            Contains a string of a LoadLeveler group that will own the
            reservation.

Description

The ll_make_reservation( ) subroutine is the API for the llmkres command
used to create a new reservation.

The ll_init_reservation_param subroutine can be used to initialize the
LL_reservation_param structure.

A coscheduled job step cannot be used for making a reservation.

This function is for the BACKFILL scheduler only.

The LL_init_reservation_param subroutine is a convenience function that
can be used to initialize the LL_reservation_param structure. You must
set the ID, start_time, duration, data_type, and data fields of the
LL_reservation_param structure. If any of these fields are NULL or 0 (as
appropriate), the call will fail.

Only users authorized by LoadLeveler administrators to make reservations
can use this function.

Return Values
 
RESERVATION_OK
         Request successfully sent to LoadLeveler.
RESERVATION_LIMIT_EXCEEDED
         Exceeds the maximum number of reservations allowed for the
         cluster.
RESERVATION_TOO_CLOSE
         Reservation is being made within the minimum advance time.
RESERVATION_NO_STORAGE
         The system cannot allocate memory.
RESERVATION_CONFIG_ERR
         Errors were encountered while processing configuration files.
RESERVATION_USER_LIMIT_EXCEEDED
         Exceeds the maximum number of reservations for the user.
RESERVATION_GROUP_LIMIT_EXCEEDED
         Exceeds the maximum number of reservations for the group.
RESERVATION_NO_PERMISSION
         Permission cannot be granted.
RESERVATION_SCHEDD_CANT_CONNECT
         The Schedd cannot connect to the central manager.
RESERVATION_API_CANT_CONNECT
         The subroutine cannot connect to the Schedd or central manager.
RESERVATION_JOB_SUBMIT_FAILED
         Submit of the job command file failed.
RESERVATION_NO_MACHINE
         One or more machines in the host list are not in the
         LoadLeveler cluster.
RESERVATION_WRONG_MACHINE
         Reservations are not permitted on one or more machines in the
         host list.
RESERVATION_NO_RESOURCE
         Insufficient resources in the LoadLeveler cluster.
RESERVATION_NO_JOBSTEP
         The job step used for node selection does not exist.
RESERVATION_WRONG_JOBSTEP
         The job step used for node selection is not in the right state.
RESERVATION_NOT_SUPPORTED
         The scheduler in use does not support reservations.
RESERVATION_REQUEST_DATA_NOT_VALID
         Input is not valid.
RESERVATION_CANT_TRANSMIT
         A data transmission failure occurred.
RESERVATION_TOO_LONG
         The duration exceeds the maximum reservation duration.
RESERVATION_HOSTFILE_ERR
         Errors were encountered while processing the host file.

Related Information

Commands: llmkres

Subroutines: ll_error

A sample program called res.c is provided in the samples/llres
subdirectory of the release directory.



ll_remove_reservation subroutine

Purpose

ll_remove_reservation - Enables you to cancel one or more reservations.

Library

LoadLeveler API library libllapi.a (AIX) or libllapi.so (Linux)

Syntax

#include "llapi.h"

int ll_remove_reservation (int version, LL_element **errOBJ, char **IDs,
                           char **user_list, char **host_list, 
			   char **group_list, 
			   char **base_partition_list = NULL);

Parameters

version
   Is an input parameter that indicates the LoadLeveler API version
   (this should be the same value as LL_API_VERSION in llapi.h).

errObj
   Provides the address of a pointer to an LL_element that points to an
   error object if this function fails. 

   The caller must free the error object storage before reusing the
   pointer. You can also use the ll_error subroutine to display error
   messages stored in the error object. If you are going to use the
   ll_error subroutine, the pointer must be initialized to NULL to
   ensure that a valid pointer is passed to the ll_error subroutine.

IDs
   Specifies a NULL-terminated array of reservation identifiers. The
   format of a full LoadLeveler reservation identifier is
   [host.]rid[.r]. 

   where:
    
   *  host is the name of the machine that assigned the reservation
      identifier.
   *  rid is the number assigned to the reservation when it was created.
      An rid is required.
   *  r indicates that this is a reservation ID (r is optional).
    
   The reservation identifier may be specified in an abbreviated form,
   rid[.r], when the API is invoked on the same machine that assigned
   the reservation identifier. In this case, LoadLeveler will use the
   local machine's host name to construct the full reservation
   identifier.

user_list
   Specifies a NULL-terminated array of user IDs that own reservations.

host_list
   Specifies a NULL-terminated array of machine names. One member of all
   indicates all Blue Gene base partitions.

group_list
   Specifies a NULL-terminated array of LoadLeveler groups.

base_partition_list
   Specifies a NULL-terminated array of Blue Gene base partitions. One
   member of all indicates all Blue Gene base partitions.

Description

The ll_remove_reservation( ) subroutine is the API for the llrmres
command.

A list of reservation IDs cannot be specified when user_list, host_list,
base_partition_list, or group_list is specified. If reservation IDs is
non-NULL when user_list, host_list, base_partition_list, or group_list
is also non-NULL, the return value will be
RESERVATION_REQUEST_DATA_NOT_VALID. Input for the user_list, host_list,
group_list, or base_partition_list parameters can be provided in any
combination. The host_list and base_partition_list parameters are
mutually exclusive.

This function is for the BACKFILL scheduler only.

Only LoadLeveler administrators and the owner of the reservation can use
this function.

Return Values

RESERVATION_OK
         Request successfully sent to LoadLeveler.
RESERVATION_REQUEST_DATA_NOT_VALID
         Input is not valid.
RESERVATION_CONFIG_ERR
         Errors were encountered while processing configuration files.
RESERVATION_NO_STORAGE
         The system cannot allocate memory.
RESERVATION_CANT_TRANSMIT
         A data transmission failure occurred.
RESERVATION_API_CANT_CONNECT
         The subroutine cannot connect to the Schedd or central manager.
RESERVATION_NOT_SUPPORTED
         The scheduler in use does not support reservations.

Related Information

Commands: llrmres

Subroutines: ll_error, ll_make_reservation
