
Submit API

This API allows you to submit jobs to LoadLeveler. The submit API
consists of the following subroutines and a user exit for monitoring
programs:

*  llfree_job_info subroutine
*  llsubmit subroutine
*  monitor_program user exit

In LoadLeveler for Linux only, llsubmit returns an error value of -1 and
writes the error messages to stderr when SEC_ENABLEMENT is CTSEC.



llfree_job_info subroutine

Purpose

llfree_job_info - Frees space for the array and the job step information
used by llsubmit.

Syntax
 
void llfree_job_info (LL_job *job_info, int job_version);

Parameters

job_info
   Is a pointer to a LL_job structure. Upon return, the space pointed to
   by the step_list variable and the space associated with the LL_job
   step structures pointed to by the step_list array are freed. All
   fields in the LL_job structure are set to zero.

job_version
   Is an integer indicating the version of llfree_job_info being used.
   This argument should be set to LL_JOB_VERSION which is defined in the
   llapi.h header file.



llsubmit subroutine

Purpose

llsubmit - Submits jobs to LoadLeveler for scheduling. It is both the
name of a LoadLeveler command used to submit jobs as well as the
subroutine described here.

Syntax
  
int llsubmit (char *job_cmd_file, char *monitor_program, 
              char *monitor_arg, LL_job *job_info, int job_version);

Parameters

job_cmd_file
   Is a pointer to a string containing the name of the job command file.

monitor_program
   Is a pointer to a string containing the name of the monitor program
   to be invoked when the state of the job is changed. Set to NULL if a
   monitoring program is not provided.

monitor_arg
   Is a pointer to a string which is stored in the job object and is
   passed to the monitor program. The maximum length of the string is
   1023 bytes. If the length exceeds this value, it is truncated to 1023
   bytes. Set to NULL if an argument is not provided.

job_info
   Is a pointer to a structure defined in the llapi.h header file. No
   fields are required to be filled in. Upon return, the structure will
   contain the number of job steps in the job command file and a pointer
   to an array of pointers to information about each job step. Space for
   the array and the job step information is allocated by llsubmit. The
   caller should free this space using the llfree_job_info subroutine.

job_version
   Is an integer indicating the version of llsubmit being used. This
   argument should be set to LL_JOB_VERSION which is defined in the
   llapi.h include file.

Description

LoadLeveler must be installed and configured correctly on the machine on
which the submit application is run.

The uid and gid in effect when llsubmit is invoked are the uid and gid
used when the job is run.

To submit a job to a remote cluster, call the ll_cluster API to define
the cluster prior to calling the llsubmit API. If the job being
submitted has the cluster_list keyword defined in the job command file,
the cluster specified by the ll_cluster API takes precedence over the
cluster_list keyword.

Return Values

0       The job was submitted successfully.

Error Values

-1       Error, error messages written to stderr.

Related Information

Subroutines: ll_cluster



monitor_program user exit

Purpose

Using the monitor_program user exit, you can create a program that
monitors jobs submitted using the llsubmit subroutine. The Schedd daemon
invokes this monitor program if the monitor_program argument to llsubmit
is not null. The monitor program is invoked each time a job step changes
state. This means that the monitor program will be informed when the job
step is started, completed, vacated, removed, or rejected. If you
suspect the monitor program encountered problems or did not run, you
should check the listing in the Schedd log. In the event of a monitor
program failure, the job is still run.

Syntax

monitor_program job_id user_arg state exit_status

Parameters

monitor_program
   Is the name of the program supplied in the monitor_program argument
   passed to the llsubmit function.

job_id
   Is the full ID for the job step.

user_arg
   The string supplied to the monitor_arg argument that is passed to the
   llsubmit function.

state
   Is the current state of the job step. Possible values for the state
   are: 

   JOB_STARTED
      The job step has started.

   JOB_COMPLETED
      The job step has completed.

   JOB_VACATED
      The job step has been vacated. The job step will be rescheduled if
      the job step is restartable or if it is checkpointable.

   JOB_REJECTED
      A startd daemon has rejected the job. The job will be rescheduled
      to another machine if possible.

   JOB_REMOVED
      The job step was canceled or could not be started.

   JOB_NOTRUN
      The job step cannot be run because a dependency cannot be met.

exit_status
   Is the exit status from the job step. The argument is meaningful only
   if the state is JOB_COMPLETED.
