
llbind - Bind job steps to a reservation

Purpose

llbind - Binds job steps to a reservation in LoadLeveler, or unbinds job
steps from the reservations to which they currently belong. The bound
job steps will only be scheduled to run on the nodes reserved by the
reservation.  

Syntax

llbind { -? | -H | -v | [-q] { -r | -R reservation_ID } job_step_list }

Flags

-?       Provides a short usage message.

-H       Provides extended help information.

-v       Displays the name of the command, release number, service
         level, service level date, and lowest level of the operating
         system to run this release.

-q       Specifies quiet mode: print no messages other than error
         messages.

-r       Specifies an unbind operation. LoadLeveler eliminates any
         association between the job steps and a reservation.

-R reservation_ID
         Specifies a reservation identifier to which the job steps will
         be bound. The format of a full LoadLeveler reservation
         identifier is [host.]rid[.r]. 

         where:
          
         *  host is the name of the machine that assigned the
            reservation identifier.
         *  rid is the number assigned to the reservation when it was
            created. An rid is required.
         *  r indicates that this is a reservation ID (r is optional).
         
         The reservation identifier may be specified in an abbreviated
         form, rid[.r], when the command is invoked on the same machine
         that assigned the reservation identifier. In this case,
         LoadLeveler will use the local machine's hostname to construct
         the full reservation identifier.

job_step_list
         Is a blank-delimited list of job steps to be bound to the
         reservation or unbound from their respective reservations. The
         name of each job step should be in the form
         [host].jobid[.stepid]. 

         where:
          
         *  host is the name of the machine that assigned the job and
            step identifiers.
         *  jobid is the job number assigned to the job when it was
            submitted.
         *  stepid is the job step number assigned to the job step when
            it was submitted.

         The job or step identifier may be specified in an abbreviated
         form, jobid or jobid.stepid, when the command is invoked on the
         same machine that assigned the job and step identifiers. In
         this case, LoadLeveler will use the local machine's hostname to
         construct the full job or step identifier.
          
         Note: For coscheduled job steps, even if all coscheduled job
               steps are not in the list of targeted job steps, the
               requested command is run on all coscheduled job steps.

Description

The llbind command is for LoadLeveler administrators and owner or users
of a reservation. Regular users can only bind their own job steps to a
reservation that they are allowed to use, while a LoadLeveler
administrator can bind any job steps to any reservation.

Only job steps in an idle-like state can be bound to a reservation. A
job step that is in an idle-like state that is already bound to a
reservation can be bound to a new reservation using the llbind command.
The command will first unbind the job step from the reservation it is
currently bound to and then bind it to the requested reservation.

A Blue Gene job step can only be bound to a reservation with Blue Gene
resources. A non-Blue Gene job step can only be bound to a reservation
with non-Blue Gene resources.

The following conditions will cause the bind or unbind request for a job
step to be ignored: 

*  The job step does not exist.
*  The user is not the owner of the job step or a LoadLeveler
   administrator.
*  The job step is requested to be bound to the reservation it is
   currently bound to.
*  The job step is not associated with any reservation for a unbind
   request.
*  Binding a Blue Gene job step to a reservation without Blue Gene
   resources.
*  Binding a non-Blue Gene job step to a reservation with Blue Gene
   resources.

Note: A bind or unbind request for a coscheduled job step applies to all
      of the coscheduled job steps. If any of the coscheduled job steps
      meet one of these conditions, the requested operation will fail.
      The llq -l command can be used to check whether the request is
      successful (see the llq command in TWS LoadLeveler: Using and
      Administering for more information).

Bound job steps will be scheduled to run only on the reserved resources.
The only exception is that the front end node (FEN) needed by a Blue
Gene job step will be satisfied from outside of the reservation. A
reservation for Blue Gene resource does not reserve resources for a FEN.
The launch program mpirun needs to run on a front end node.

Only existing idle, or idle-like, job steps can be bound to a
reservation through this command. The LL_RES_ID environment variable or
the ll_res_id job command file keyword is used to bind an interactive
POE job to a reservation or cause llsubmit to both submit and bind a
batch job to a reservation. For additional information about setting the
LL_RES_ID environment variable or the ll_res_id job command file keyword
to bind an interactive POE job to a reservation, see the "Building and
submitting jobs" topic in TWS LoadLeveler: Using and Administering. The
llqres command can be used to view the list of job steps bound to the
reservation.

This command is for the BACKFILL scheduler only.

Examples

1. To request to bind the job step c188f2n01.6.0 to reservation
   c188f1n03.2.r, issue: 

   llbind -R c188f1n03.2.r c188f2n01.6.0

   You should receive a response similar to the following: 

   Request to bind job steps to reservation c188f1n03.2.r has been sent 
   to LoadLeveler

2. To request to unbind the job step c188f2n01.6.0 from the reservation
   to which it is currently bound, issue: 

   llbind -r c188f2n01.6.0

   You should receive a response similar to the following: 
   Request to unbind job steps from their respective reservations has 
   been sent to LoadLeveler.

Security

LoadLeveler administrators and users can issue this command.
