
llcancel - Cancel a submitted job

Purpose

llcancel - Cancels one or more jobs from the LoadLeveler queue.

Syntax

llcancel { -? | -H | -v | -f hostlist | [-q] [-X cluster_name]
         [-u userlist] [-h hostlist] [joblist] }

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-f hostlist
   Forces all jobs that are running on the machines in the hostlist to
   be vacated. Those machines in the hostlist are then marked as "Down"
   in the LoadLeveler cluster. The hostlist for the -f option should
   only specify machines that have gone down and should only be used for
   those machines that still have jobs displayed in the LoadLeveler
   queue. 

   The -f option is intended to be used by administrators for cleanup
   and recovery after a machine has permanently crashed or was
   inadvertently removed from the cluster before all activity has
   quiesced. If you need to return the machine to the cluster later, you
   must clear all files from the spool and execute directory of the
   machines in the hostlist.

-q 
   Specifies quiet mode: print no messages other than error messages.

-X cluster_name
   Specifies the name of a single cluster where the command is to run.

-u userlist
   Is a blank-delimited list of users. When used with the -h option,
   only the user's jobs monitored on the machines in the hostlist are
   canceled. When used alone, only the user's jobs monitored by the
   machine issuing the command are canceled.

-h hostlist
   Is a blank-delimited list of machine names. All jobs monitored on
   machines in this list are canceled. When issued with the -u option,
   the userlist is used to further select jobs for cancellation.

joblist
   Is a blank-delimited list of job and step identifiers. When a job
   identifier is specified, the command action is taken for all steps of
   the job. At least one job or step identifier must be specified. 

   The format of a job identifier is host.jobid. The format of a step
   identifier is host.jobid.stepid.

   where:
    
   *  host is the name of the machine that assigned the job and step
      identifiers.
   *  jobid is the job number assigned to the job when it was submitted.
   *  stepid is the job step number assigned to the job step when it was
      submitted.
 
   The job or step identifier may be specified in an abbreviated form,
   jobid or jobid.stepid, when the command is invoked on the same
   machine that assigned the job and step identifiers. In this case,
   LoadLeveler will use the local machine's hostname to construct the
   full job or step identifier.
  
   Note: For coscheduled jobs, even if all coscheduled job steps are not
         in the list of targeted job steps, the requested operation is
         performed on all coscheduled job steps.

The -u or -h flags override the joblist parameter.

When the -h flag is specified by a non-administrator, all jobs submitted
from the machines in hostlist by the user issuing the command are
canceled.

When the -h flag is specified by an administrator, all jobs submitted by
the administrator are canceled, unless the -u is also specified, in
which case all jobs both submitted by users in userlist and monitored on
machines in hostlist are canceled.

Group administrators and class administrators are considered normal
users unless they are also LoadLeveler administrators.

Description

When you issue llcancel, the command is sent to the negotiator. You
should then use the llq command to verify your job was canceled. A job
state of CA (Canceled) indicates the job was canceled. A job state of RP
(Remove Pending) indicates the job is in the process of being canceled.

When cancelling a job from a submit-only machine, you must specify the
machine name that scheduled the job. For example, if you submitted the
job from machine A, a submit-only machine, and machine B, a scheduling
machine, scheduled the job to run, you must specify machine B's name in
the cancel command. If machine A and B are in different sub-domains, you
must specify the fully qualified name of the job in the cancel command.
You can use the llq -l command to determine the fully qualified name of
the job.

Examples

1. This example cancels the job step 3 that is part of the job 18 that
   is scheduled by the machine named bronze: 

   llcancel bronze.18.3

2. This example cancels all the job steps that are a part of job 8 that
   are scheduled by the machine named gold: 

   llcancel gold.8

3. This example cancels the job steps that are a part of job 5 that is
   scheduled to run in cluster1: 

   llcancel -X cluster1 silver.5 

Results

1. The following shows a sample system response for the llcancel gold.8
   command: 

   llcancel: Cancel command has been sent to the central manager.

2. The following shows a sample system response for the llcancel -X
   cluster1 silver.5 command. The remote command has been sent to the
   central manager in cluster1: 

   llcancel: Cancel command has been sent to the central manager.

Security

LoadLeveler administrators and users can issue this command.
