
llclass - Query class information

Purpose

llclass - Returns information about classes.

Syntax

llclass [-?] [-H] [-v] [-W] [-l] [-X {cluster_list | all}] 
        [-c classlist | classlist]

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-W 
   Specifies that the width of columns in tabular output will be
   increased to fit the widest entry.

-l 
   Specifies that a long listing be generated for each class for which
   status is requested. If -l is not specified, then the standard
   listing is generated.

-X {cluster_list | all}
   Indicates that you can specify the -X flag with either: 

   cluster_list
            Is a blank-delimited list of clusters where the command is
            to run.

   all      Is the reserved word indicating that the command is to run
            in all accessible clusters.

-c classlist | classlist
   Is a blank-delimited list of classes for which you are requesting
   status. The -c classlist flag is used to distinguish a classlist when
   specified in combination with the -X flag. If a classlist is not
   specified, all classes are queried.

If you have more than a few classes configured for LoadLeveler, consider
redirecting the output to a file when you use the -l flag.

Description

The llclass command queries information about job classes. The output of
this command displays the number of defined classes and usage
information.

Examples

1. To generate a standard listing for class Parallel, issue: 

   llclass Parallel    

   This example generates the standard listing where there are 24
   initiators of class Parallel configured in the cluster, with one job
   step of class Parallel using 6 initiators currently running. You
   should receive output similar to the following:    

   Name        MaxJobCPU     MaxProcCPU   Free    Max    Description
               d+hh:mm:ss    d+hh:mm:ss   Slots   Slots
   
   Parallel    2+02:45:00    05:30:00     18      24     Parallel job 
                                                         class

   The standard listing includes the following fields: 

   Description
            Lists the information provided in the class_comment keyword
            for the specified class. The class_comment keyword is
            defined in the class stanza of the LoadLeveler
            administration file.

   Free Slots
            The number of initiators (slots) available for the specified
            class in the LoadLeveler cluster. A serial job step uses one
            initiator at run time. A parallel job step with N tasks uses
            N initiators at run time.

   MaxJobCPU
            The hard job CPU limit of job steps for the specified class.
            For a description of the job CPU limit for serial and
            parallel job steps, see the description of the job command
            keyword job_cpu_limit in TWS LoadLeveler: Using and
            Administering.

   MaxProcCPU
            The hard CPU limit for the processes of the job steps of the
            specified class.

   Max Slots
            The number of configured initiators (slots) for the
            specified class in the LoadLeveler cluster.

   Name     The name of the class.

2. To generate a long listing for classes named silver and gold, issue: 

   llclass -l silver gold 

   The long listing includes the following fields: 

   Admin    The list of administrators for the specified class.

   As_limit The hard and soft address space limits of processes of job
            steps of the specified class.

   Ckpt_limit
            Hard and soft checkpoint limits of a job step of the
            specified class.

   Class_ckpt_dir
            The name of the directory containing the checkpointing files
            of job steps of the specified class.

   Class_comment
            Lists the information provided in the class_comment keyword
            for the specified class. The class_comment keyword is
            defined in the class stanza of the LoadLeveler
            administration file.

   Core_limit
            The hard and soft core size limits of processes of job steps
            of the specified class.

   Cpu_limit
            The hard and soft CPU limits of processes of job steps of
            the specified class.

   Data_limit
            The hard and soft data area limits of processes of job steps
            of the specified class.

   Def_wall_clock_limit
            The default wall clock limit to those jobs that have no wall
            clock limit specified in their job command files.

   Exclude_Bg
            Blue Gene base partitions that cannot be used by job steps
            of the specified class.

   Exclude_Groups
            Groups who are not allowed to submit jobs of the specified
            class.

   Exclude_Users
            Users who are not permitted to submit jobs of the specified
            class.

   Free_slots
            The number of available initiators (slots) for the specified
            class in the LoadLeveler cluster. A serial job step uses one
            initiator of the appropriate class at run time. A parallel
            job step with N tasks uses N initiators at run time.

   File_limit
            The hard and soft file size limits of processes of job steps
            of the specified class.

   Include_Bg
            Blue Gene base partitions that can be used by job steps of
            the specified class.

   Include_Groups
            Groups having permission to submit jobs of the specified
            class.

   Include_Users
            Users who are permitted to submit jobs of the specified
            class.

   Job_cpu_limit
            The hard and soft job CPU limits of job steps of the
            specified class. For a description of the job CPU limit for
            serial and parallel job steps, see the description of the
            job command keyword job_cpu_limit in TWS LoadLeveler: Using
            and Administering.

   Locks_limit
            The hard and soft lock limits of processes of job steps of
            the specified class.

   Maximum_slots
            The total number of configured initiators (slots) for the
            specified class in the LoadLeveler cluster.

   Maxjobs  The maximum number of job steps of the specified class that
            can run at any time in the LoadLeveler cluster.

   Max_processors
            The maximum number of processors than can be used for a
            parallel job step of the specified class.

   Max_total_tasks
            Used for BACKFILL scheduling only. Max_total_tasks sets the
            maximum number of tasks allowed to run at any given time for
            job steps of the specified class in the LoadLeveler cluster.

   Max_proto_instances
            The maximum number of protocol instances allowed for a job
            step of the specified class.

   Memlock_limit
            The hard and soft address memory limits of processes of job
            steps of the specified class.

   Name     The name of the class

   Nice     The nice value of jobs of the specified class.

   Node Resource Req.
            The default consumable resource requirement for each node
            for job steps of the specified class.

   Nofile_limit
            The hard and soft limits on the number of open files of
            processes of job steps of the specified class.

   Nproc_limit
            The hard and soft limits on the number of processes that can
            be created for the real user ID of the submitted job. These
            limits count processes owned by the owner of the job steps
            of the specified classes.

   Preempt_class
            Used for BACKFILL scheduling only, Preempt_class sets the
            preemption rule for job steps of the specified class.

   Priority The system priority of the specified class relative to other
            classes.

   Resource_requirement
            The default consumable resource requirement for each task
            for job steps of the specified class.

   Rss_limit
            The hard and soft rss size limits of processes of job steps
            of the specified class.

   Stack_limit
            The hard and soft stack size limits of processes of job
            steps of the specified class.

   Start_class
            Used for BACKFILL scheduling only, Start_class sets the
            starting rule for job steps of the specified class.

   Wall_clock_limit
            The hard and soft wall clock (elapsed time) limits of job
            steps of the specified class.    

   See the "Sample command output" topic for sample output of long
   listings in TWS LoadLeveler: Using and Administering.

3. This example generates the standard listing for all accessible
   clusters including the local cluster in a multicluster environment:
   
   llclass -X all     

   The output representing a cluster is delineated with a cluster header
   similar to the following:    

   =================== Cluster c556_Cluster1 ==========================
   
   Name       MaxJobCPU    MaxProcCPU  Free   Max    Description
              d+hh:mm:ss   d+hh:mm:ss  Slots  Slots
   --------   ----------   ----------  -----  -----  -----------
   mpich      3+08:00:00   12:30:00    100    132    MPICH Jobs
   parallel     23:59:00   01:00:00     32    256    POE Parallel Jobs
   No_Class     01:00:00   00:30:00    120    512    Default Class
   large      2+08:00:00   18:30:00     50    128    Large Serial Jobs
   medium       12:00:00   02:30:00     60    128    Medium Serial Jobs
   small        01:00:00   00:30:00     12    128    Small Serial Jobs
   
   =================== Cluster c556_Cluster2 ==========================
   
   Name       MaxJobCPU    MaxProcCPU  Free   Max    Description
              d+hh:mm:ss   d+hh:mm:ss  Slots  Slots
   --------   ----------   ----------  -----  -----  -----------
   mpich      3+08:00:00   12:30:00    110    132    MPICH Jobs
   parallel     23:59:00   01:00:00     48    256    POE Parallel Jobs
   No_Class     01:00:00   00:30:00    128    512    Default Class
   large      2+08:00:00   18:30:00     74    128    Large Serial Jobs
   ESSL         23:00:00   12:30:00     55    128    ESSL Jobs
   OSL          12:00:00   06:00:00     33    128    OSL Jobs

Related Information

Each machine periodically updates the central manager with a snapshot of
its environment. Since the information returned by llclass is a
collection of these snapshots, all taken at varying times, the total
picture may not be completely consistent.

Security

LoadLeveler administrators and users can issue this command.
