
llctl - Control LoadLeveler daemons

Purpose

llctl - Controls LoadLeveler daemons on all members of the LoadLeveler
cluster.

Syntax

llctl [-?] [-H] [-v] [-q] [-g | -h hostname] keyword

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-q 
   Specifies quiet mode: print no messages other than error messages.

-g 
   Indicates that the command applies globally to all machines, except
   submit-only machines, that are listed in the administration file.

-h host
   Indicates that the command applies to only the host machine in the
   LoadLeveler cluster. If neither -h nor -g is specified, the default
   is the machine on which the llctl command is issued.

keyword
   Must be specified after all flags and can be the following: 

   capture eventname
      Captures accounting data for all jobs running on the designated
      machines. eventname is the name you associate with the data, and
      must be a character string containing no blanks. For more
      information, see the discussion of collecting job resource data
      based on events in TWS LoadLeveler: Using and Administering.

   drain [schedd|startd [classlist |allclasses]]
      When you issue drain with no options, the following happens: (1)
      no more LoadLeveler jobs can begin running on this machine, and
      (2) no more LoadLeveler jobs can be submitted through this
      machine. When you issue drain schedd, the following happens: (1)
      the Schedd machine accepts no more LoadLeveler jobs for
      submission, (2) job steps in the Starting or Running state in the
      Schedd queue are allowed to continue running, and (3) job steps in
      the Idle state in the Schedd queue are drained, meaning they will
      not get dispatched. When you issue drain startd, the following
      happens: (1) the startd machine accepts no more LoadLeveler jobs
      to be run, and (2) job steps already running on the startd machine
      are allowed to complete. When you issue drain startd classlist,
      the classes you specify which are available on the startd machine
      are drained (made unavailable). When you issue drain startd
      allclasses, all available classes on the startd machine are
      drained.

   dumplogs
      When the logging buffer is enabled, llctl dumplogs will cause the
      log messages in the logging buffer to be written to the related
      log file. For more information, see the "Configuration file
      keyword descriptions" topic in TWS LoadLeveler: Using and
      Administering.

   flush
      Terminates running jobs on this machine and sends them back, in
      the Idle state, to the negotiator to await redispatch (provided
      restart=yes in the job command file). No new jobs are sent to this
      machine until resume is issued. Forces a checkpoint if jobs are
      enabled for checkpointing. However, the checkpoint gets canceled
      if it does not complete within the time period specified in the
      ckpt_time_limit keyword in the job command file.

   purgeschedd
      Requests that all jobs scheduled by the specified host machine be
      purged (removed). This keyword will invoke the llpurgeschedd
      binary, which is shipped as a setuid program. llpurgeschedd must
      run as root in order to switch the identity to the LoadLeveler
      user to perform the transactions necessary to remove jobs from the
      specified Schedd. 

      To use this keyword, you must first specify schedd_fenced=true in
      the machine stanza for this host. The -g option cannot be
      specified with this keyword. For more information, see the "How do
      I recover resources allocated by a Schedd machine" topic in TWS
      LoadLeveler: Using and Administering.

   reconfig
      Forces all daemons to reread the administration and configuration
      files.

   recycle
      Stops all LoadLeveler daemons and restarts them.

   resume [schedd|startd [classlist |allclasses]]
      When you issue resume with no options, job submission and job
      execution on this machine is resumed. When you issue resume
      schedd, the Schedd machine resumes the submission of jobs. When
      you issue resume startd, the startd machine resumes the execution
      of jobs. When you issue resume startd classlist, the startd
      machine resumes the execution of those job classes you specify
      which are also configured (defined on the machine). When you issue
      resume startd allclasses, the startd machine resumes the execution
      of all configured classes.

   start [drained]
      When you issue start with no options it starts the LoadLeveler
      daemons on the machine or machines designated, either explicitly
      or implicitly. When you issue start without the -g or -h flag the
      LoadLeveler daemons are started on the same machine that issued
      the command. When you issue llctl start with either the -g or -h
      flag, the command specified by the LL_RSH_COMMAND configuration
      file keyword is used to run the command on all machines specified
      in the administration file. If LL_RSH_COMMAND is not specified,
      remote shell (rsh) is used and you must have rsh privileges in
      order to use llctl start with either the -g or -h flag. 

      When you issue start with the drained option the LoadLeveler
      daemons are started, but the startd daemon is started in the
      drained state.
       
      LoadLeveler commands that run rshell include llctl version and
      llctl start.

   stop
      Stops the LoadLeveler daemons on the specified machine.

   suspend
      Suspends all jobs on this machine. This is not supported for
      parallel jobs.

   version
      Displays release number, service level, service level date, and
      operating system information for every LoadLeveler executable. 

      When you issue llctl version with either the -g or -h flag, the
      command specified by the LL_RSH_COMMAND configuration file keyword
      is used to run the command on all machines specified in the
      administration file. If LL_RSH_COMMAND is not specified, remote
      shell (rsh) is used and you must have rsh privileges in order to
      use llctl version with either the -g or -h flag.
       
      LoadLeveler commands that run rshell include llctl version and
      llctl start.

Description

This command sends a message to the master daemon on the target machine
requesting that action be taken on the members of the LoadLeveler
cluster. Note the following when using this command: 

*  To perform the control operations of the llctl command, you must be a
   LoadLeveler administrator. The only exception to this rule is the
   "start" operation.

*  LoadLeveler will fail to start if any value has been set for the
   MALLOCTYPE environment variable.

*  After you make changes to the administration and configuration files
   for a running cluster, be sure to issue llctl reconfig. This command
   causes the LoadLeveler daemons to reread these files, and prevents
   problems that can occur when the LoadLeveler commands are using a new
   configuration while the daemons are using an old configuration. 

   Note: Changes to SCHEDULER_TYPE will not take effect at
         reconfiguration. The administrator must stop and restart or
         recycle LoadLeveler when changing SCHEDULER_TYPE.

*  The llctl drain startd classlist command drains classes on the startd
   machine, and the startd daemon remains operational. If you
   reconfigure the daemon, the draining of classes remains in effect.
   However, if the startd goes down and is brought up again (either by
   the master daemon or by a LoadLeveler administrator), the startd
   daemon is configured according to the global or local configuration
   file in effect, and therefore the draining of classes is lost. 

   Draining all the classes on a startd machine is not equivalent to
   draining the startd machine. When you drain all the classes, the
   startd enters the Idle state. When you drain the startd, the startd
   enters the Drained state. Similarly, resuming all the classes on a
   startd machine is not equivalent to resuming the startd machine.

*  If a job step is running on a machine that receives the llctl recycle
   command, or the llctl stop and llctl start commands, the running job
   step is terminated. If the restart option in the job command file was
   set to yes, then the job step will be restarted when LoadLeveler is
   restarted. If the job step is checkpointable, it will be restarted
   from the last valid checkpoint file when LoadLeveler is restarted.

*  If you find that the llctl -g command (even if it is specified with
   additional options) is taking a long time to complete, you should
   consider using the AIX command dsh to send llctl commands (omitting
   the -g flag) to multiple nodes in a parallel fashion.

*  When a node running a Schedd daemon fails, resources that have been
   allocated to any of the jobs scheduled by that Schedd are unavailable
   until the Schedd is restarted. Administrators can, however, recover
   these resources by using the llctl command's purgeschedd keyword to
   purge (remove) all of the jobs scheduled by the Schedd on the down
   node. The purgeschedd keyword can only work in conjunction with the
   schedd_fenced keyword, in the administration file, which causes the
   central manager to ignore (fence) the Schedd daemon running on the
   target node. You must reconfigure the central manager so it can
   recognize this fence. To use the purgeschedd keyword: 

   1. Recognize that a node running a Schedd daemon is down, and that
      the node will be down long enough to necessitate that you recover
      the resources allocated to jobs scheduled by that Schedd.

   2. Add the statement "schedd_fenced = true" to the failed node's
      administration file machine stanza.

   3. Reconfigure the central manager node so that the central manager
      recognizes the fenced Schedd daemon.

   4. Invoke "llctl -h host purgeschedd" to purge all of the jobs
      scheduled by the Schedd on the failed node.

   5. Once the failed node is working again, remove all of the files in
      the LoadLeveler spool directory. Remove the "schedd_fenced = true"
      statement from the administration file, then reconfigure the
      central manager node before starting Schedd on the machine.

Examples

1. This example stops LoadLeveler on the machine named iron: 

   llctl -h iron stop

2. This example starts the LoadLeveler daemons on all members of the
   LoadLeveler cluster (with the exception of the submit-only machines),
   starting with the central manager, as defined in the machine stanzas
   of the administration file: 

   llctl -g start

3. This example causes the LoadLeveler daemons on machine iron to
   re-read the administration and configuration files, which may contain
   new configuration information for the iron machine: 

   llctl -h iron reconfig

4. This example drains the classes medium and large on the machine named
   iron. 

   llctl -h iron drain startd medium large

5. This example drains the classes medium and large on all machines. 

   llctl -g drain startd medium large

6. This example stops all the jobs on the system, then allows only jobs
   of a certain class (medium) to run. 

   llctl -g drain startd allclasses
   llctl -g flush
   llctl -g resume
   llctl -g resume startd medium

7. This example resumes the classes medium and large on the machine
   named iron. 

   llctl -h iron resume startd medium large

8. This example illustrates how to capture accounting information on a
   work shift called day on the machine iron: 

   llctl -h iron capture day

   You can capture accounting information on all the machines in the
   LoadLeveler cluster by using the -g option, or you can collect
   accounting information on the local machine by simply issuing the
   following: 

   llctl capture day
   
   Capturing information on the local machine is the default. For more
   information, see the "Collecting job resource data based on events"
   topic in TWS LoadLeveler: Using and Administering.

Security

LoadLeveler administrators can issue this command.
