
llextRPD - Extract data from an RSCT peer domain

Purpose

llextRPD - Extracts the necessary data from a Reliable Scalable Cluster
Technology (RSCT) peer domain (or local node if there is no active
domain) to set up the administration file.

Syntax

llextRPD [ -? | -H |  -v | [-m] [-a adapter_name] [-h hostlist] ]

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-m 
   Specifies that only machine stanzas are to be generated. The adapter
   stanzas (and the corresponding adapter_stanzas statement of the
   machine stanza) will be suppressed in the final output. This option
   is for Dynamic Adapter Configuration support for peer domains with
   AIX RSCT. 

   LoadLeveler will dynamically detect and handle adapters and adapter
   changes for any machine in these domains which do not specify an
   adapter stanza in the administration file.

-a adapter_name
   Specifies that the interface name of the given adapter_name on each
   node is used as the label (machine stanza name) of the generated
   machine stanza. 

   If you do not specify an adapter (or if an adapter is specified but
   does not exist on a particular node) then the label used for that
   machine is the Name field from the RSCT IBM.PeerNode class for the
   machine in the cluster. 

   Note: If an administrator wants to configure LoadLeveler to
         communicate using the Switch Network Interface for High
         Performance Switch (HPS) adapters in a peer domain they should
         use the -a flag with  ml0 specified as the adapter_name. ml0 is
         guaranteed to be present on every node that contains an HPS
         adapter. 

         It is recommended that you do not specify sn as the adapter
         name. If you do, the machine will be named with the IP name of
         the sn adapter. If that IP name becomes unavailable because the
         adapter changes, LoadLeveler will not be able to contact any
         daemons on that machine.

-h hostlist
   Specifies one or more host match terms. If multiple host match terms
   are used, they must be blank delimited and the list must be enclosed
   in quotes. Each host match term is either a regular expression that
   specifies a set of machine names, or the name of a file that contains
   one or more host match terms with each term on a separate line. 

   Each machine name that is returned by RSCT is compared to all of the
   regular expressions that were found by processing the host match
   terms. If the machine name matches at least one of the regular
   expressions, the machine information is included in the output of the
   llextRPD command. If the -h flag is not used, all of the machines
   returned by RSCT are included in the llextRPD command output.

Description

This command extracts data for LoadLeveler to set up the administration
file. If you plan to use the llextRPD command to construct machine and
adapter stanzas for the LoadLeveler administration file, RSCT is
required.

The llextRPD command must be run on one of the nodes in an active RSCT
peer domain to obtain the RSCT peer nodes and network interface data
from that cluster. If you are not running the command in an active RSCT
peer domain you will just get information from the local machine.
Adapter stanza names for HPS adapters are not included in the machine
stanza alias. If you run an application which requires LoadLeveler to
recognize a node by the interface name of a HPS adapter, you must
manually add the adapter stanza name for the HPS adapter as an alias in
the machine stanza.

Examples

1. The following example extracts the data from an RSCT peer domain: 

   llextRPD -a ml0

   Results: 

   #llextRPD: Cluster = "llcluster" ID = "0Jt9zGF7nbDWwWjjTDrxjG" on 
              Mon Feb 18 15:24:13 2008
   
   c121san10.ppd.pok.ibm.com: type = machine adapter_stanzas = 
      c121s0n10.ppd.pok.ibm.com c121s1n10.ppd.pok.ibm.com 
      c121san10.ppd.pok.ibm.com c121f2rp02.ppd.pok.ibm.com
      alias = c121f2rp02.ppd.pok.ibm.com
   
   c121s0n10.ppd.pok.ibm.com: type = adapter
      adapter_name = sn0
      network_type = switch
      interface_address = 192.168.0.10
      interface_name = c121s0n10.ppd.pok.ibm.com
      multilink_address = 10.10.10.10
      logical_id = 2
      adapter_type = Switch_Network_Interface_For_HPS
      device_driver_name = sni0
      network_id = 1
   
   c121s1n10.ppd.pok.ibm.com: type = adapter
      adapter_name = sn1
      network_type = switch
      interface_address = 192.168.1.10
      interface_name = c121s1n10.ppd.pok.ibm.com
      multilink_address = 10.10.10.10
      logical_id = 0
      adapter_type = Switch_Network_Interface_For_HPS
      device_driver_name = sni1
      network_id = 1
   
   c121san10.ppd.pok.ibm.com: type = adapter
      adapter_name = ml0
      network_type = multilink
      interface_address = 10.10.10.10
      interface_name = c121san10.ppd.pok.ibm.com
      multilink_list = sn0,sn1
   
   c121f2rp02.ppd.pok.ibm.com: type = adapter
      adapter_name = en0
      network_type = ethernet
      interface_address = 9.114.66.74
      interface_name = c121f2rp02.ppd.pok.ibm.com
      device_driver_name = ent0
   
   c121san04.ppd.pok.ibm.com: type = machine adapter_stanzas = 
      c121s0n04.ppd.pok.ibm.com c121s1n04.ppd.pok.ibm.com 
      c121san04.ppd.pok.ibm.com c121f1rp04.ppd.pok.ibm.com
      alias = c121f1rp04.ppd.pok.ibm.com
   
   c121s0n04.ppd.pok.ibm.com: type = adapter
      adapter_name = sn0
      network_type = switch
      interface_address = 192.168.0.4
      interface_name = c121s0n04.ppd.pok.ibm.com
      multilink_address = 10.10.10.4
      logical_id = 11
      adapter_type = Switch_Network_Interface_For_HPS
      device_driver_name = sni0
      network_id = 1
   
   c121s1n04.ppd.pok.ibm.com: type = adapter
      adapter_name = sn1
      network_type = switch
      interface_address = 192.168.1.4
      interface_name = c121s1n04.ppd.pok.ibm.com
      multilink_address = 10.10.10.4
      logical_id = 9 
      adapter_type = Switch_Network_Interface_For_HPS
      device_driver_name = sni1
      network_id = 1
   
   c121san04.ppd.pok.ibm.com: type = adapter
      adapter_name = ml0
      network_type = multilink
      interface_address = 10.10.10.4
      interface_name = c121san04.ppd.pok.ibm.com
      multilink_list = sn0,sn1
   
   c121f1rp04.ppd.pok.ibm.com: type = adapter
      adapter_name = en0
      network_type = ethernet
      interface_address = 9.114.66.68
      interface_name = c121f1rp04.ppd.pok.ibm.com
      device_driver_name = ent0

2. The following example extracts the data from an RSCT peer domain for
   a dynamic adapter configuration: 

   llextRPD -m -a ml0
  
   Results: 

   #llextRPD: Cluster = "acc97" ID = "28jek7RdrHdGwr5C6zQwWm" on 
              Mon Feb 18 14:37:33 2008
   
   c97ml0n13.ppd.pok.ibm.com: type = machine
       alias = c97n13.ppd.pok.ibm.com
   
   c97ml0n09.ppd.pok.ibm.com: type = machine
       alias = c97n09.ppd.pok.ibm.com
   
   c97ml0n01.ppd.pok.ibm.com: type = machine
       alias = c97n01.ppd.pok.ibm.com
   
   c97ml0n05.ppd.pok.ibm.com: type = machine
       alias = c97n05.ppd.pok.ibm.com

3. The following example shows an adapter stanza: 

   .
   .
   .
   c197blade2b11.ppd.pok.ibm.com: type = adapter
           adapter_name = eth0
           network_type = ethernet
           interface_address = 9.114.198.43
           interface_name = c197blade2b11.ppd.pok.ibm.com    
   .
   .
   .

4. The following example would only include information for all the
   nodes in the RSCT peer domain with names that included work1, work02,
   work03, and work05: 

   llextRPD -h "work1.* nodelist1.txt"

   if nodelist1.txt is in the current directory and contains the two
   lines: 
   work02.* 
   /home/steve/nodelist2.txt

   and /home/steve/nodelist2.txt contains the single line: 
   work0[35].*    

   To further explain this example: 
   *  The pattern work1.* is on the command line, which is the string
      work1 followed by any character (the dot) zero or more times (the
      asterisk).
   *  The pattern work02.* is in nodelist1.txt, which is the string
      work02 followed by any character (the dot) zero or more times (the
      asterisk).
   *  The pattern work0[35].* is in nodelist2.txt, which is the string
      work0 followed by a 3 or a 5 followed by any character (the dot)
      zero or more times (the asterisk).
 
   Therefore, any pattern that has work1, work02, work03, or work05 in
   it will be displayed by the llextRPD command.

Security

LoadLeveler administrators and users can issue this command.
