
llfs - Fair share scheduling queries and operations

Purpose

llfs - Returns information about fair share scheduling in LoadLeveler or
operates on fair share scheduling.  

Syntax

llfs [ -? | -H | -v | -s savedir | -r [saved_file] | [-u user_list]  
     [-g group_list] ]

Flags 

-?       Provides a short usage message.

-H       Provides extended help information.

-v       Displays the name of the command, release number, service
         level, service level date, and lowest level of the operating
         system to run this release.

-s savedir
         Saves a snapshot of the historic fair share data in the
         specified directory. The central manager must be able to write
         to the savedir directory. The directory does not need to be
         accessible on the node where the command is issued.

-r [saved_file]
         Resets fair share scheduling by either clearing all historic
         fair share data, or restoring fair share scheduling to a state
         corresponding to a file previously saved by the llfs -s
         command. The saved_file file must be readable by the central
         manager. A full path name should be specified for the file. The
         file does not need to be accessible on the node where the
         command is issued.

-u user_list
         Is a blank-delimited list of users. Fair share allocation and
         utilization information for these users will be displayed.

-g group_list
         Is a blank-delimited list of LoadLeveler groups. Fair share
         allocation and utilization information for these groups will be
         displayed.

Description

The llfs command can be used either as a query command or as a control
command.

As a query command, llfs with no options displays current fair share
scheduling information for all users and groups who have jobs completed
in the LoadLeveler cluster. With the -u or -g options, information for
the users or groups requested is displayed.

The llfs command displays the following information as a query command:

*  The time the information is obtained
*  The total number of shares that both the cluster CPU and Blue Gene
   resources are divided into (for example, if there are 100 shares,
   then there are 100 CPU shares and 100 Blue Gene shares).
*  The time interval in which most of the used shares are consumed
*  The number of shares allocated and used for each user and group 

   Note: Used shares are for the cluster CPU resources and the Blue Gene
         used shares are for the Blue Gene resources. Blue Gene shares
         are only displayed when Blue Gene is enabled.

The share usage affects the job scheduling priority according to the
SYSPRIO expression used in the global configuration file.

As a control command, you can use the llfs to reset fair share
scheduling or save historic fair share data to a file. The -s option
saves a snapshot of all historic fair share data in the LoadLeveler
cluster. If the value of FAIR_SHARE_INTERVAL is large (for example, an
entire year) and if there are concerns about losing a lot of historic
data, this option can be used on a regular basis to save a snapshot of
the historic fair share data to a file. The saved file can be used by
the llfs -r option to restore fair share scheduling to the state
corresponding to the saved file. Without a saved file, the llfs -r
option will discard all previous historic fair share data and restarts
fair share scheduling again.

This command is for LoadLeveler administrators and the BACKFILL
scheduler only.

Examples

When BG_ENABLED is set to false in the configuration file, the following
examples apply.

1. To display current fair share information without any options, issue:
   
   llfs    

   You should receive output similar to the following:    

   Current Time: Fri Jan 25 13:45:55 EST 2008
   FAIR_SHARE_TOTAL_SHARES = 100
   FAIR_SHARE_INTERVAL = 180 hours
   
   Name                 Type   Allocated Shares  Used Shares
   -------------------  -----  ----------------  -----------
   uno                  user                 50           20
   zhong                user                 10           10
   loadl                user                  0            4
   systest              group                 0           30
   loadl                group                 0            4

2. To sort fair share information according to used shares in descending
   order, issue: 

   llfs > /tmp/out; head -6 /tmp/out;  tail +7 /tmp/out |sort -rn +3     
   
   You should receive output similar to the following:
    
   Current Time: Fri Jan 25 13:45:55 EST 2008
   FAIR_SHARE_TOTAL_SHARES = 100
   FAIR_SHARE_INTERVAL = 180 hours
   
   Name                 Type   Allocated Shares  Used Shares
   -------------------  -----  ----------------  -----------
   systest              group                 0           30
   uno                  user                 50           20
   zhong                user                 10           10
   loadl                user                  0            4
   loadl                group                 0            4

3. To display current fair share information for user uno and group
   systest, issue: 

   llfs -u uno -g systest
   
   You should receive output similar to the following:
    
   Name                 Type   Allocated Shares  Used Shares
   -------------------  -----  ----------------  -----------
   uno                  user                 50           20
   systest              group                 0           30

4. To reset fair share scheduling by discarding all previous historic
   data, issue: 

   llfs -r
   
   You should receive a response similar to the following:
    
   llfs: request has been sent to LoadLeveler.

5. To save a snapshot of the historic data to the /shared/save
   directory, issue: 

   llfs -s /shared/save
    
   You should receive a response similar to the following:
    
   llfs: /shared/save/fair_share_data.200801251345 has been created.

6. To restart fair share scheduling from previously saved data, issue: 

   llfs -r /shared/save/fair_share_data.200801251345
    
   You should receive a response similar to the following:
    
   llfs: request has been sent to LoadLeveler.

When BG_ENABLED is set to true in the configuration file, the following
examples apply. 

1. To display current fair share information without any options, issue:
   
   llfs
   
   You should receive output similar to the following: 

   Current Time: Tue 15 Jan 2008 06:35:24 PM CDT
   FAIR_SHARE_TOTAL_SHARES = 100000
   FAIR_SHARE_INTERVAL = 1 hours
   
   Name                Type  Allocated Shares Used Shares BG Used Shares
   ------------------- ----- ---------------- ----------- --------------
   varella             user                 0           0              0
   No_Group            group                0          16            595
   ezhong              user                 0          16            595

2. To sort fair share information according to the used shares of the
   cluster CPU resources in descending order, issue: 

   llfs>/tmp/out; head -6 /tmp/out;tail +7 /tmp/out|sort -rn +4
    
   You should receive output similar to the following: 

   Current Time: Tue 15 Jan 2008 06:38:03 PM CDT
   FAIR_SHARE_TOTAL_SHARES = 100000
   FAIR_SHARE_INTERVAL = 1 hours
   
   Name                Type  Allocated Shares Used Shares BG Used Shares
   ------------------- ----- ---------------- ----------- --------------
   No_Group            group                0          14            521
   ezhong              user                 0          14            521
   varella             user                 0           0              0

3. To display current fair share information for user ezhong and group
   group, issue: 

   llfs -u ezhong -g group
    
   You should receive output similar to the following:
    
   Current Time: Tue 15 Jan 2008 06:39:34 PM CDT
   FAIR_SHARE_TOTAL_SHARES = 100000
   FAIR_SHARE_INTERVAL = 1 hours
   
   Name                Type  Allocated Shares Used Shares BG Used Shares
   ------------------- ----- ---------------- ----------- --------------
   ezhong              user                 0          13            483
   group               group                0           0              0

Security

LoadLeveler administrators can issue this command.
