
llhold - Hold or release a submitted job

Purpose

llhold - Places jobs in user hold or system hold and releases jobs from
both types of hold. Users can only move their own jobs into and out of
user hold. Only LoadLeveler administrators can move jobs into and
release them from system hold.

Syntax
 
llhold   [-?] [-H] [-v] [-q] [-s] [-r] [-X cluster_name]
         [-u userlist] [-h hostlist] [joblist]

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-q 
   Specifies quiet mode: print no messages other than error messages.

-s 
   Puts jobs in system hold. Only a LoadLeveler administrator can use
   this option. 

   If neither -s nor -r is specified, LoadLeveler puts the jobs in user
   hold.

-r 
   Releases a job from hold. A job step in user hold can be released by
   the owner or a LoadLeveler administrator. A job step in system hold
   can only be released by a LoadLeveler administrator. If a job step
   that is in both system hold and user hold is released by a
   LoadLeveler administrator, the job step will be released from system
   hold but remains in user hold. If the owner releases a job step that
   is in both system hold and user hold, the job step is released from
   user hold but remains in system hold. 

   The -r flag can be used to restart jobs that were put on user hold by
   the llckpt -u command.    

   If neither -s nor -r is specified, LoadLeveler puts the jobs in user
   hold.

-X cluster_name
   Specifies the name of a single cluster where the command is to run.

-u userlist
   Is a blank-delimited list of users. When used with the -h option,
   only the user's jobs monitored on the machines in the hostlist are
   held or released. When used alone, only the user's jobs monitored on
   the Schedd machine are held or released.

-h hostlist
   Is a blank-delimited list of machine names. All jobs monitored on
   machines in this list are held or released. When issued with the -u
   option, the userlist is used to further select jobs for holding or
   releasing. 

   When issued by a non-administrator, this option only acts upon jobs
   that user has submitted to the machines in hostlist.
    
   When issued by an administrator, all jobs monitored on the machines
   are acted upon unless the -u option is also used. In that case, the
   userlist is also part of the selection process, and only jobs both
   submitted by users in userlist and monitored on the machines in the
   hostlist are acted upon.

joblist
   Is a blank-delimited list of job and step identifiers. When a job
   identifier is specified, the command action is taken for all steps of
   the job. At least one job or step identifier must be specified. 

   The format of a job identifier is host.jobid. The format of a step
   identifier is host.jobid.stepid.
    
   where:
    
   *  host is the name of the machine that assigned the job and step
      identifiers.
   *  jobid is the job number assigned to the job when it was submitted.
   *  stepid is the job step number assigned to the job step when it was
      submitted.
    
   The job or step identifier may be specified in an abbreviated form,
   jobid or jobid.stepid, when the command is invoked on the same
   machine that assigned the job and step identifiers. In this case,
   LoadLeveler will use the local machine's hostname to construct the
   full job or step identifier.
    
   Note: For coscheduled jobs, even if all coscheduled job steps are not
         in the list of targeted job steps, the requested operation is
         performed on all coscheduled job steps.

Description

This command does not affect a job step that is running unless the job
step attempts to enter the Idle state. At this point, the job step is
placed in the Hold state.

To ensure a job is released from both system hold and user hold, the
administrator must issue the command with -r specified to release it
from system hold. The administrator or the submitting user can reissue
the command to release the job from user hold.

This command will fail if: 

*  A nonadministrator attempts to move a job into or out of system hold.
*  A nonadministrator attempts to move a job submitted by someone else
   into or out of user hold.

Examples

1. This example places job 23, job step 0 and job 19, job step 1 on
   hold: 

   llhold 23.0 19.1

2. This example releases job 23, job step 0, job 19, job step 1, and job
   20, job step 3 from a hold state: 

   llhold -r 23.0 19.1 20.3

3. This example places all jobs from users abe, barbara, and carol2 in
   system hold: 

   llhold -s -u abe barbara carol2

4. This example releases from a hold state all jobs on machines bronze,
   iron, and steel: 

   llhold -r -h bronze iron steel

5. This example releases from a hold state all jobs on machines bronze,
   iron, and steel that smith submitted: 

   llhold -r -u smith -h bronze iron steel

Results

The following shows a sample system response for the llhold -r -h bronze
command: 

llhold: Hold command has been sent to the central manager.

Security

LoadLeveler administrators and users can issue this command.
