
llinit - Initialize machines in the LoadLeveler cluster

Purpose

llinit - Initializes a new machine as a member of the LoadLeveler
cluster

Syntax

llinit   [-?] [-H] [-q] [-prompt] [-local pathname] [-release pathname]
         [-cm machine] [-debug]

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-q 
   Specifies quiet mode: print no messages other than error messages.

-prompt
   Prompts or leads you through a set of questions that help you to
   complete the llinit command.

-local pathname
   pathname is the local directory in which the spool, execute, and log
   subdirectories will be created. The default, if this flag is not
   used, is the home directory. 

   There must be a unique local directory for each LoadLeveler cluster
   member.

-release pathname
   pathname is the release directory, where the LoadLeveler bin, lib,
   man, include, and samples subdirectories are located. The default, if
   this flag is not used, is the /usr/lpp/LoadL/full directory on AIX or
   the /opt/ibmll/LoadL/full directory on Linux.

-cm machine
   machine is the central manager machine, where the negotiator daemon
   runs.

-debug
   Displays debug messages during the execution of llinit.

Description

This command runs once on each machine during the installation process.
It must be run by the user ID you have defined as the LoadLeveler user
ID. The log, spool, and execute directories are created with the correct
modes and ownerships. The LoadLeveler configuration and administration
files, LoadL_config and LoadL_admin, respectively, are copied from
LoadLeveler's release directory to LoadLeveler's home directory. The
local configuration file, LoadL_config.local, is copied from
LoadLeveler's release directory to LoadLeveler's local directory.

llinit initializes a new machine as a member of the LoadLeveler cluster
by doing the following: 

*  Creates the following LoadLeveler subdirectories with the given
   permissions: 
   *  spool subdirectory, with permissions set to 700.
   *  execute subdirectory, with permissions set to 1777.
   *  log subdirectory, with permissions set to 775.

*  Copies the LoadL_config and LoadL_admin files from the release
   directory samples subdirectory into the home directory of the
   LoadLeveler user ID.

*  Copies the LoadL_config.local file from the release directory samples
   subdirectory into the local directory.

*  Creates symbolic links from the loadl home directory to the spool,
   execute, and log subdirectories and the LoadL_config.local file in
   the local directory (if home and local directories are not
   identical).

*  Creates symbolic links from the home directory to the bin, lib, man,
   samples, and include subdirectories in the release directory.

*  Updates the LoadL_config with the release directory name.

*  Updates the LoadL_admin with the central manager machine name.

Before running llinit ensure that your HOME environment variable is set
to LoadLeveler's home directory. To run llinit, you must have: 

*  Write privileges in the LoadLeveler home directory
*  Write privileges in the LoadLeveler release directory
*  Write privileges in the LoadLeveler local directory.

Examples

The following example initializes a machine, assigning /var/loadl as the
local directory, /usr/lpp/LoadL/full as the release directory, and the
machine named bronze as the central manager. 

llinit -local /var/loadl -release /usr/lpp/LoadL/full -cm bronze

Ensure that the local directory exists before running the preceding
command.

Results

The command: 

llinit -local /home/ll_admin -release /usr/lpp/LoadL/full -cm mars

will yield the following output:

llinit: creating directory "/home/ll_admin/spool"
llinit: creating directory "/home/ll_admin/log"
llinit: creating directory "/home/ll_admin/execute"
llinit: set permission "700" on "/home/ll_admin/spool"
llinit: set permission "775" on "/home/ll_admin/log"
llinit: set permission "1777" on "/home/ll_admin/execute"
llinit: creating file "/home/ll_admin/LoadL_admin"
llinit: creating file "/home/ll_admin/LoadL_config"
llinit: creating file "/home/ll_admin/LoadL_config.local"
llinit: editing file /home/ll_admin/LoadL_config
llinit: editing file /home/ll_admin/LoadL_admin
llinit: creating symbolic link "/home/ll_admin/bin -> \ 
        /usr/lpp/LoadL/full/bin"
llinit: creating symbolic link "/home/ll_admin/lib -> \ 
        /usr/lpp/LoadL/full/lib"
llinit: creating symbolic link "/home/ll_admin/man -> \ 
        /usr/lpp/LoadL/full/man"
llinit: creating symbolic link "/home/ll_admin/samples -> \ 
        /usr/lpp/LoadL/full/samples"
llinit: creating symbolic link "/home/ll_admin/include -> \ 
        /usr/lpp/LoadL/full/include"
llinit: program complete.

Security

LoadLeveler administrators can issue this command.
