
llq - Query job status

Purpose

llq - Queries information about jobs in the LoadLeveler queues.

Syntax

llq      [-?] [-H] [-v] [-W] [-x [-d]] [-s] [-l] [-b] [-w] 
         [-X {cluster_list | all} ] [-j joblist | joblist] [-u userlist] 
	 [-h hostlist] [-c classlist] [-R reservation_list] 
	 [-f category_list] [-r category_list]

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-W 
   Specifies that the width of columns in tabular output will be
   increased to fit the widest entry.

-x 
   Provides extended information about the selected job. If the -x flag
   is used with the -r, -s, or -f flag, an error message is generated. 

   CPU usage and other resource consumption information on active jobs
   can only be reported using the -x flag if the LoadLeveler
   administrator has enabled it by specifying A_ON and A_DETAIL for the
   ACCT keyword in the LoadLeveler configuration file.
    
   Normally, llq connects with the central manager to obtain job
   information. When you specify -x, llq connects to the Schedd machine
   that received the specified job to get extended job information.
   However, some statistics, including those corresponding to System
   Priority and q_sysprio, are available only from the central manager.
   Do not use the -x option if you need these statistics.
    
   When specified without -l, CPU usage for active jobs is reported in
   the short format. 

   Note: Using both the -l and -x options without a joblist
         specification can produce a very long report and excessive
         network traffic.

-d 
   Displays the user-specified unfiltered job command file keyword
   statements. Information is available only on jobs submitted in a
   multicluster environment. You must specify the -d flag in combination
   with the -x flag.

-s 
   Provides information on why a selected list of jobs remain in the
   NotQueued, Idle, or Deferred state. Along with this flag, users must
   specify a list of jobs. The user can also optionally supply a list of
   machines to be considered when determining why the jobs cannot run.
   If a list of machines is not provided, the default is the list of
   machines in the LoadLeveler cluster. For each job, llq determines why
   the job remains in one of the given states instead of Running.

-l 
   Specifies that a long listing be generated for each job for which
   status is requested.

-b 
   Shows Blue Gene jobs in short form. This is the Blue Gene equivalent
   of the llq standard listing. Using this flag will display the
   following fields: 

   BG       The state of the job on the Blue Gene system.

   Id       The LoadLeveler job step ID.

   LL       The LoadLeveler state of the job step.

   Owner    The user ID of the job's owner.

   Partition
            The name of the Blue Gene partition assigned to the job.

   PT       The state of the Blue Gene partition assigned to the job.

   Size     The number of Blue Gene compute nodes allocated for the job.

   Submitted
            The time the job step was submitted to LoadLeveler.

-w 
   Provides AIX Workload Manager (WLM) CPU and real memory statistics
   for jobs in the running state. This flag can be used with a joblist,
   steplist, or a single stepid. All other flags except -h will result
   in an error message. 

   When the -w flag is augmented with a single stepid, the -h flag can
   be used in conjunction with -w to specify a single hostname.
    
   This flag can only be used when ENFORCE_RESOURCE_USAGE is enabled in
   the configuration file. Otherwise, an error message is produced.
    
   The following statistics are displayed for every node the job is
   running on: 

   *  Current CPU resource consumption as a percentage of the total
      resources available
   *  Total CPU time consumed in milliseconds
   *  Current real memory consumption as a percentage of the total
      resources available
   *  The highest number of resident memory pages used

-X {cluster_list | all}
   Indicates that you can specify the -X flag with either: 

   cluster_list
            Is a blank-delimited list of clusters where the command is
            to run.

   all      Is the reserved word indicating that the command is to run
            in all accessible clusters.

-j joblist |joblist
   Is a blank-delimited list of job and step identifiers. When a job
   identifier is specified, the command action is taken for all steps of
   the job. At least one job or step identifier must be specified. 

   The format of a job identifier is host.jobid. The format of a step
   identifier is host.jobid.stepid.
    
   where:
    
   *  host is the name of the machine that assigned the job and step
      identifiers.
   *  jobid is the job number assigned to the job when it was submitted.
   *  stepid is the job step number assigned to the job step when it was
      submitted.
    
   The job or step identifier may be specified in an abbreviated form,
   jobid or jobid.stepid, when the command is invoked on the same
   machine that assigned the job and step identifiers. In this case,
   LoadLeveler will use the local machine's hostname to construct the
   full job or step identifier.
    
   The -j joblist flag is used to distinguish a joblist when specified
   in combination with the any flag that supports a list.
    
   If the -X flag is specified in combination with a joblist, the -j
   flag must be specified. For example: 

   llq -X my_cluster1 my_cluster2 -j c94n13.2.1 c94n13.25.0

-u userlist
   Is a blank-delimited list of users. Only job steps belonging to users
   in this list are queried.

-h hostlist
   Is a blank-delimited list of machines. If the -s flag is not
   specified, only job steps managed by the Schedd on machines in this
   list are queried. If the -s flag is specified, the list of machines
   is considered when determining why a job remains in the Idle state. 

   When the -h flag is used with the -w flag, only a single machine name
   can be specified to obtain the WLM statistics for that machine.

-c classlist
   Is a blank-delimited list of classes. Only job steps belonging to
   classes in this list are queried.

-f category_list
   Is a blank-delimited list of categories you want to query. Each
   category you specify must be preceded by a percent sign. The
   category_list cannot contain duplicate entries. This flag allows you
   to create a customized version of the standard llq listing. You
   cannot use this flag with the -l flag. The output fields produced by
   this flag all have a fixed length. The output is displayed in the
   order in which you specify the categories. category_list can be one
   or more of the following: 

   %a       Account number
   %BB      Name of the Blue Gene block/partition assigned to the job
   %BG      State of the job on the Blue Gene system
   %BS      Number of compute nodes in the Blue Gene partition assigned
            to the job
   %c       Class
   %cc      Completion code
   %dc      Completion date
   %dd      Dispatch Date
   %dh      Hold date
   %dq      Queue date ("Submitted" date of "standard" llq output)
   %fj      Favored Job
   %gl      LoadLeveler group
   %gu      UNIX group
   %h       Hostname (first hostname if more than one machine is
            allocated to the job step)
   %id      Step ID
   %is      Virtual image size
   %jn      Job name
   %jt      Job type
   %nh      Number of hosts allocated to the job step
   %o       Job owner
   %p       User priority
   %PT      State of the Blue Gene partition assigned to the job
   %R       Reservation ID
   %sn      Step name
   %st      Status
   %X       Cluster name where the job is to be scheduled
   %Xf      Cluster name from where the job was sent
   %Xk      Cluster name the user requested
   %Xs      Cluster name from where the job was submitted
   %Xu      User name of the original submission

-r category_list
   Is a blank-delimited list of formats (categories) you want to query.
   Each category you specify must be preceded by a percent sign. The
   category_list cannot contain duplicate entries. This flag allows you
   to create a customized version of the standard llq listing. You
   cannot use this flag with the -l flag. The output produced by this
   flag is considered raw, in that the fields can be variable in length.
   Output fields are separated by an exclamation point (!). The output
   is displayed in the order in which you specify the formats.
   category_list can be one or more of the formats listed under the -f
   flag.

-R reservation_list
   Is a blank-delimited list of reservation identifiers. Only job steps
   bound to reservations in this list are queried. The format of a full
   LoadLeveler reservation identifier is [host.]rid[.r]. 

   where:
    
   *  host is the name of the machine that assigned the reservation
      identifier.
   *  rid is the number assigned to the reservation when it was created.
      An rid is required.
   *  r indicates that this is a reservation ID (r is optional).
    
   The reservation identifier may be specified in an abbreviated form,
   rid[.r], when the command is invoked on the same machine that
   assigned the reservation identifier. In this case, LoadLeveler will
   use the local machine's host name to construct the full reservation
   identifier.

If a job step is not specified and if -u, -h, -c, or -R is not
specified, all jobs are queried.

If a job step is specified, you cannot specify -u, -h, -c, or -R, except
in the cases of -w and -s, for which the -h flag has special meaning.

When -u, -h, -c, or -R are used in combination, the result is the
intersection of the job steps selected by each flag.

The -b flag can be used alone or with the -u flag and the joblist
argument. If used in conjunction with any other flag, an error will
occur.

You cannot specify -d, -x, or -w in combination with the -X flag.

Description

The llq command queries information about jobs in the LoadLeveler
queues.

Examples

1. This example generates the standard listing where the machine mars
   has two jobs running and one job waiting: 

   Id                 Owner      Submitted   ST PRI Class     Running On
   ----------------   ---------- ----------- -- --- --------  ----------
   mars.498.0         brownap     5/20 11:31 R  100 silver    mars
   mars.499.0         brownap     5/20 11:31 R  50  No_Class  mars
   mars.501.0         brownap     5/20 11:31 I  50  silver
    
   3 job step(s) in query, 1 waiting, 0 pending, 2 running, 0 held, 
                           0 preempted
   
   The standard listing includes the following fields:
    
   Class    Job class.

   Id       The format of a full LoadLeveler step identifier is
            host.jobid.stepid. If the llq command returns information
            about a job owned by a Schedd in the same domain, then the
            domain of the hostname will not appear in the output.
            However, when the llq command reports information about a
            job owned by a Schedd in a different domain, the fully
            qualified hostname is always included. Due to space
            limitations, the domain of the host may be truncated to fit
            in the space allocated to the Id field. If the domain is
            truncated, a dash (-) will appear at the end to indicate
            that characters have been left out. To see the full job ID,
            run llq with the -l flag.

   Owner    User ID that the job will be run under.

   PRI      User priority of the job step, where the values are defined
            with the user_priority keyword in the job command file or
            changed by the llprio command, which is described in TWS
            LoadLeveler: Using and Administering.

   Running On
            If running, the name of the machine the job step is running
            on. This is blank when the job is not running. For a
            parallel job step, only the first machine is shown.

   ST       For more information, see the "LoadLeveler job states"
            topic in TWS LoadLeveler: Using and Administering.

   Submitted
            Date and time of job submission. 

2. This example generates the long listing. The long listing is
   generated when you specify the -x -l flags with the llq command: 

   llq -l -x c271f2rp01.ppd.pok.ibm.com.16.0
  
   The long listing includes the following fields. See the "Sample
   command output" topic for sample output of long listings in TWS
   LoadLeveler: Using and Administering.
    
   Account  The account number specified in the job command file.

   Adapter Requirement
            Reflects the settings of the network keyword in the job
            command file. 

            For more information on the network keyword statement, see
            the "Job command file keyword descriptions" topic in TWS
            LoadLeveler: Using and Administering.

   Allocated Hosts
            The machines that have been allocated for this job step.

   Args     Arguments that were passed to the executable.

   Blocking Reflects the settings for the blocking keyword in the job
            command file.

   Blue Gene Job ID
            The ID of the Blue Gene job in the Blue Gene DB2(R)
            database. This field is displayed for Blue Gene jobs only.

   Blue Gene Status
            The state of the Blue Gene job in the Blue Gene DB2
            database. This field is displayed for Blue Gene jobs only.

   BG Requirements
            The job step requirements on Blue Gene resources as
            specified at job submission. This field is displayed for
            Blue Gene jobs only.

   Bulk Transfer
            Indicates that the value will be Yes or No depending on
            whether the application requested that the communication
            subsystem use bulk transfer by specifying bulkxfer=yes in
            the job command file.

   Checkpoint Directory
            Value of the ckpt_dir keyword.

   Checkpoint File
            For AIX checkpointable job steps, the file name to be used
            for checkpoint data.

   Checkpointable
            Indicates if LoadLeveler considers the job step
            checkpointable (yes, no, or interval).

   Ckpt Accum Time
            Accumulated time, in seconds, the job step has spent
            checkpointing.

   Ckpt Elapse Time
            Amount of time taken to perform the last successful
            checkpoint.

   Ckpt Execute Dir
            The directory where the job step's executable will be saved
            for checkpointable jobs.

   Ckpt Hard Limit
            Checkpoint hard limit as specified at job step submission.

   Ckpt Soft Limit
            Checkpoint soft limit as specified at job step submission.

   Ckpt Start Time
            The start time of the current checkpoint in progress. Blank
            if no checkpoint running.

   Class    The class of the job step as specified at job submission.

   class_sysprio
            The class priority of the job step, where the value is
            defined in the administration file.

   Cluster input file
            The information format is local_pathname, remote_pathname. 

            where:
             
            local_pathname
                     Is the full pathname of the file to be copied from
                     the local cluster.
            remote_pathname
                     Is the full pathname of the file that will be
                     copied into the remote cluster.

   Cluster output file
            The information format is local_pathname, remote_pathname. 

            where:
             
            local_pathname
                     Is the full pathname of the file that will be
                     copied into the local cluster.
            remote_pathname
                     Is the full pathname of the file to be copied from
                     the remote cluster.

   Cmd      The name of the executable associated with the executable
            keyword (if specified) or the name of the job command file.

   Comment  The comment specified by the comment keyword in the job
            command file.

   Completion Code
            The status returned by the wait3 UNIX system call.

   Completion Date
            Date and time job completed or exited.

   Core Hard Limit
            Core hard limit as specified at job submission.

   Core Soft Limit
            Core soft limit as specified at job submission.

   Coschedule
            Indicates whether the job step is required to be coscheduled
            (yes or no).

   Cpu Hard Limit
            CPU hard limit as specified at job submission.

   Cpu Soft Limit
            CPU soft limit as specified at job submission.

   Cpus Per Core
            The CPUs per processor core requested by the job.

   Data Hard Limit
            Data hard limit as specified at job submission.

   Data Soft Limit
            Data soft limit as specified at job submission.

   Dependency
            Job step dependencies as specified at job submission.

   Dispatch Time
            The time that the job was dispatched.

   Env      Environment variables to be set before executable runs.
            Appears only when the -x option is specified.

   Err      The file to be used for stderr.

   Error Text
            The error text in the Blue Gene job record from the Blue
            Gene DB2 database. This field is displayed for Blue Gene
            jobs only.

   Fail Ckpt Time/Date
            Time and date stamp of the last failed checkpoint.

   File Hard Limit
            File hard limits as specified at job submission.

   File Soft Limit
            File soft limit as specified at job submission.

   Favored Job
            Indicates whether the job has been specified to have a
            higher system priority than all jobs that are not favored
            (yes or no).

   Good Ckpt Time/Date
            Time and date stamp of the last successful checkpoint.

   group_sysprio
            The group priority of the job step, where the value is
            defined in the administration file.

   high water
            The highest number of resident memory pages used. Real
            Memory resource only.

   Hold Job Until
            Job step is deferred until this date and time.

   In       The file to be used for stdin.

   Initial Working Dir
            The directory from which the job step is run. The relative
            directory from which the stdio files are accessed, if
            appropriate.

   Job Accounting Key
            The Job Accounting Key is a unique identifier for a
            LoadLeveler job step. The accounting key is stored in the
            AIX accounting record for each process associated with a
            LoadLeveler job step. This field can be used to correlate
            AIX accounting records with LoadLeveler accounting records.
            The Job Accounting Key is stored in the history file and can
            be displayed using the llsummary -l command. 

            This keyword is not applicable on LoadLeveler for Linux
            platforms.
             
            For more information on the Job Accounting Key, see the
            "Correlating AIX and LoadLeveler accounting records" topic
            in TWS LoadLeveler: Using and Administering.

   Job Name The name of the job.

   Job Step ID
            The job step identifier.

   Large Page
            Indicates whether Large Page memory should be used to run
            this job step. Can be Y (use Large Page memory if
            available), N (No), or M (Mandatory).

   LoadLeveler Group
            The LoadLeveler group associated with the job step.

   Machine Speed
            For a serial job step, the value associated with the speed
            keyword of the machine that is running this job step. For a
            parallel job step, the value associated with the speed
            keyword of the first machine that has been allocated for
            this job step.

   Max Processors
            The maximum number of processors that can be used for this
            job step.

   McmAffinityOptions
            The MCM affinity options for the job.

   Min Processors
            The minimum number of processors needed for this job step.

   Negotiator Messages
            Informational messages for the job step if it is in the Idle
            or NotQueued state.

   (Node) Allocated Hosts
             
            *  The machines of this Node type that have been allocated
               for this job step. The format is: 
               hostname:task status:adapter usage, ... ,adapter usage, \
                        cpu usage, ... ,cpu usage + ... +, 
               hostname:task status:adapter usage, ... ,adapter usage, \
                        cpu usage, ... ,cpu usage 

            *  The adapter usage information has the format: 
               adapter name(adapter window ID, network protocol, mode, \
                            adapter window memory)
                
               For information on the units used to report window
               memory, see the description of the "Adapter" field in the
               llstatus command in TWS LoadLeveler: Using and
               Administering.

            *  The CPU usage information has one of the following
               formats: 
               				
               CPU <cpulist> 
               MCMnumber:CPU <cpulist>
                
               The cpulist is a blank-delimited list of individual CPU
               IDs or CPU ranges, or a combination of both CPU IDs and
               CPU ranges. The CPU range is specified as the starting
               CPU ID and the ending CPU ID separated by a hyphen (-).

   (Node) Name
            Blank value. Reserved for future use.

   (Node) Node actual
            Actual number of machines of this Node type that are used in
            the running of this job step.

   (Node) Node maximum
            Maximum number of machines of this Node type that can be
            used to run this job step.

   (Node) Node minimum
            Minimum number of machines of this Node type required to run
            this job step.

   (Node) Preferences
            Job step preferences as specified at job submission.

   (Node) Requirements
            Job step requirements as specified at job submission.

   (Node/Master Task) Exec Args
            The arguments passed to the master task executable.

   (Node/Master Task) Executable
            The executable associated with the master task.

   (Node/Master Task) Num Task Inst
            The number of task instances of the master task.

   (Node/Master Task) Task Instance
             
            *  Task instance information has the format: 
               hostname:task ID:adapter usage, ... ,adapter usage

            *  Adapter usage information has the format: 
               adapter name(adapter window ID, network protocol, mode, \
               adapter window memory)
                
               For information on the units used to report window
               memory, see the description of the "Adapter" field in the
               llstatus command in TWS LoadLeveler: Using and
               Administering.

   (Node/Task) Num Task Inst
            The number of task instances.

   (Node/Task) Task Instance
             
            *  Task instance information has the format: 
               hostname:task ID:adapter usage, ... ,adapter usage, \ 
               cpu usage

            *  Adapter usage information has the format: 
               adapter name(adapter window ID, network protocol, mode, \
               adapter window memory)
                
               For information on the units used to report window
               memory, see the description of the "Adapter" field in the
               llstatus command in TWS LoadLeveler: Using and
               Administering.

            *  The CPU usage information has one of the following
               formats: 
               				
               CPU <cpulist> 
               MCMnumber:CPU <cpulist>
                
               The cpulist is a blank-delimited list of individual CPU
               IDs or CPU ranges, or a combination of both CPU IDs and
               CPU ranges. The CPU range is specified as the starting
               CPU ID and the ending CPU ID separated by a hyphen (-).

   node_resources
            Reflects the settings for the node_resources keyword in the
            job command file.

   Node Usage
            A request that a node be shared or not shared or that a
            time-slice is not shared. The user specifies this request
            while submitting the job.

   Notifications
            The notification status for the job step, where: 

            always
               Indicates notification is sent through the mail for the
               complete, error, never, and start notification
               categories.

            complete
               Indicates notification is sent through the mail only when
               the job step completes.

            error
               Indicates notification is sent through the mail only when
               the job step terminates abnormally.

            never
               Indicates notification is never sent.

            start
               Indicates notification is sent through the mail only when
               starting or restarting the job step.

   Notify User
            The user to be notified by mail of a job's status.

   Out      The file to be used for stdout.

   Outbound Schedds
            The list of Schedds that have acted as the outbound Schedd
            for the job. The last Schedd in the list is the current
            outbound Schedd. This field only displays
            multicluster-specific information that was submitted or
            moved to a remote cluster.

   Owner    The user ID that the job will be run under.

   parallel_threads
            Indicates whether the job requests thread binding and the
            number of parallel threads of an OpenMP job.

   Partition ID
            The ID of the Blue Gene partition allocated for the job.
            This field is displayed for Blue Gene jobs only.

   Partition State
            The state of the Blue Gene partition allocated for the job.
            This field is displayed for Blue Gene jobs only.

   Port Number
            The port number for InfiniBand resources used by the running
            job.

   Preempt Wait Count
            Specifies the number of job steps that an idle job step must
            preempt before it can be started.

   Preemptable
            Indicates whether a job step is preemptable (yes or no).

   Preferences
            Job step preferences as specified at job submission.

   previous q_sysprio
            The previous adjusted system priority of the job step. For
            more information, see the discussion of how a job's priority
            affects dispatching order in TWS LoadLeveler: Using and
            Administering.

   q_sysprio
            The adjusted system priority of the job step. For more
            information, see the discussion of how a job's priority
            affects dispatching order in TWS LoadLeveler: Using and
            Administering.

   Queue Date
            The date and time that LoadLeveler received the job.

   Requested Cluster
            The cluster the user specified at job submission.

   Requested Res. ID
            The reservation identifier that a job step is requested to
            be bound to, but has not yet been bound to. This field will
            be set when a job submitted with a request to bind has been
            successfully submitted, but the bind has not yet occurred.
            The bind may never occur if either the owner of the job step
            is not allowed to use the reservation, or if the reservation
            does not exist. 

            If a job command file is used to select nodes to reserve in
            a make or change reservation request and the request fails,
            all steps of the job, if submitted successfully, will have
            MAKERES as their Requested Res. ID and the steps will be in
            the NQ state.

   Requirements
            Job step requirements as specified at job submission.

   Reservation ID
            The reservation identifier that a job step is bound to. If a
            job step is not bound to any reservation, this field will be
            blank.

   Resource The resource being enforced by WLM. This is either CPU or
            Real Memory.

   Resources
            Reflects the settings for the resources keyword in the job
            command file.

   Restart  Restart status (yes or no).

   Restart From Ckpt
            Indicates if a job has been restarted from an existing
            checkpoint (yes or no).

   Restart Same Nodes
            Indicates if a job step should be restarted on the same
            nodes after vacate (yes or no).

   Rotate   Indicates whether the scheduler is free to rotate the
            requested Blue Gene partition shape in order to match an
            available partition (TRUE or FALSE). This field is displayed
            for Blue Gene jobs only.

   RSet     The RSet requirement of the job.

   Rss Hard Limit
            RSS hard limit as specified at job step submission.

   Rss Soft Limit
            RSS soft limit as specified at job step submission.

   Running Host
            For a serial job step, the machine that is running this job
            step. For a parallel job step, the first machine that has
            been allocated for this job step.

   Schedd History
            The list of Schedds that have acted as the Schedd host for
            the job. The last one in the list is the current Schedd
            host. This field only displays multicluster-specific
            information.

   Scheduling Cluster
            The cluster name where the job is to be scheduled. This
            field only displays multicluster-specific information.

   Sending Cluster
            The cluster name that the job was sent from when moved. This
            field only displays multicluster-specific information.

   Shape Allocated
            The allocated shape of the Blue Gene partition for the job.
            This field is defined only for running-like jobs. This field
            is displayed for Blue Gene jobs only.

   Shape Requested
            The requested shape of the Blue Gene partition for the job,
            if defined, in units of base partitions. This field is
            displayed for Blue Gene jobs only.

   Shell    The shell to be used when the job step runs.

   Size Allocated
            The size of the Blue Gene partition for the job in units of
            compute nodes. The size allocated is not always identical to
            the requested size. This field is displayed for Blue Gene
            jobs only.

   Size Requested
            The requested size of the Blue Gene partition for the job in
            units of compute nodes. The size must be equivalent to the
            size of the shape, if such is defined. This field is
            displayed for Blue Gene jobs only.

   SMT requested
            Indicates the required simultaneous multithreading (SMT)
            state, which is defined in the job command file, if the job
            step requires SMT to be turned on or off. Valid values are
            yes or no.

   SMT required
            Indicates the required simultaneous multithreading (SMT)
            state, if the job step requires SMT to be enabled, disabled,
            or kept as is. Valid values are yes, no, or as_is.

   snapshot Current CPU or Real Memory consumption as a percentage of
            the total resources available.

   Stack Hard Limit
            Stack hard limit as specified at job submission.

   Stack Soft Limit
            Stack soft limit as specified at job submission.

   Starter idrss/Step Starter idrss
            An integral value of the amount of unshared memory in the
            data segment of a process (expressed in units of kilobytes *
            seconds-of-execution).

   Starter inblock/Step inblock
            Number of times file system performed input. Cumulative
            total.

   Starter isrss/Step isrss
            Depending on the Operating System, this field may contain
            the integral value of unshared stack size.

   Starter ixrss/Step ixrss
            An integral value indicating the amount of memory used by
            the text segment that was also shared among other processes
            (expressed in units of kilobytes * seconds-of-execution).

   Starter majflt/Step majflt
            Number of page faults (I/O required). Cumulative total.

   Starter maxrss/Step maxrss
            Maximum resident set size utilized. Maximum value.

   Starter minflt/Step minflt
            Number of page faults (reclaimed). Cumulative total.

   Starter msgrcv/Step msgrcv
            Number of IPC messages received. Cumulative total.

   Starter msgsnd/Step msgsnd
            Number of IPC messages sent. Cumulative total.

   Starter nivcsw/Step nivcsw
            Number of involuntary context switches. Cumulative total.

   Starter nsignals/Step nsignals
            Number of signals delivered. Cumulative total.

   Starter nswap/Step nswap
            Number of times swapped out. Cumulative total.

   Starter nvcsw/Step nvcsw
            Number of context switches due to voluntarily giving up
            processor. Cumulative total.

   Starter oublock/Step oublock
            Number of times file system performed output. Cumulative
            total.

   Starter System Time/Step System Time
            CPU system time of Starter/Step processes. Cumulative total.

   Starter Total Time/Step Total Time 
            CPU total time of Starter/Step processes. Cumulative total.

   Starter User Time/Step User Time
            CPU user time of Starter/Step processes. Cumulative total.

   Status   The status (state) of the job. For more information, see the
            "LoadLeveler job states" topic in TWS LoadLeveler: Using and
            Administering.

   Step Adapter Memory
            The total adapter pinned memory for the job step.

   Step Cpu Hard Limit
            Job step CPU hard limit as specified at job submission.

   Step Cpu Soft Limit
            Job step CPU soft limit as specified at job submission.

   Step Cpus
            The total ConsumableCpus for the job step.

   Step Name
            The name of the job step.

   Step rCxt Blocks
            The number of rCxt blocks for High Performance Switch
            adapters.

   Step Real Memory
            The total ConsumableMemory for the job step.

   Step Type
            Type of job step: 
            *  Serial
            *  General parallel
            *  Blue Gene
            *  MPICH parallel

   Step Virtual Memory
            The total ConsumableVirtualMemory for the job step.

   Structure Version
            An internal version identifier.

   Submitting Cluster
            The cluster name where the job was submitted from. This
            field only displays multicluster-specific information.

   Submitting Host
            The name of the machine to which the job is submitted.

   Submitting User
            The user name that the job was submitted under. This field
            only displays multicluster-specific information.

   System Priority
            The overall system priority of the job step, where the value
            is defined by the SYSPRIO expression in the configuration
            file.

   Task Affinity
            The task affinity requirements of the job.

   Task_geometry
            Reflects the settings for the task_geometry keyword in the
            job command file.

   total    Total CPU time consumed in milliseconds. CPU resource only.

   Unix Group
            The effective UNIX group name.

   User Priority
            The priority of the job step, as specified by the user in
            the job command, or changed by the llprio command.

   User Space Windows
            The number of switch adapter windows assigned to the job
            step.

   user_sysprio
            The user system priority of the job step, where the value is
            defined in the administration file.

   Virtual Image Size
            The value of the image_size keyword (if specified) or the
            size of the executable associated with the executable
            keyword (if specified) or the size of the job command file.

   Wall Clk Hard Limit
            Wall clock hard limit as specified at job submission.

   Wall Clk Soft Limit
            Wall clock soft limit as specified at job submission.

   Wiring Allocated
            Allocated type of wiring for the Blue Gene partition. It is
            either TORUS or MESH. This field is displayed for Blue Gene
            jobs only.

   Wiring Requested
            Requested type of wiring for the Blue Gene partition. It is
            TORUS, MESH, or PREFER_TORUS. This field is displayed for
            Blue Gene jobs only.

3. Using the abbreviated form of jobid, this example generates a
   standard listing for all job steps with jobid 12 assigned by the
   local machine: 

   llq 12

4. This example generates a standard listing for all job steps owned by
   either rich or nathan and bound to reservation 6: 

   llq -u rich nathan -R 6

5. This example generates an extended listing for all job steps of class
   batch or class highprio, managed by the Schedd daemon on either
   c94n07 or c94n09: 

   llq -x -c batch highprio -h c94n07 c94n09

6. The following example generates a standard listing for all job steps
   bound to reservation c94n04.2.r: 

   llq -R c94n04.2.r

   You should receive a response similar to the following:   
 
   Id              Owner     Submitted   ST PRI Class      Running On 
   --------------- --------- ----------- -- --- ---------- ---------- 
   c94n04.5.0      zhong     2/8  08:17  I  50  classA                  
   
   1 job step(s) in query, 1 waiting, 0 pending, 0 running, 0 held, 
                           0 preempted

7. The following example generates a customized listing for all job
   steps: 
    
   llq -f %id %o %R 

   You should receive a response similar to the following: 

   Step Id                  Owner       Reservation ID          
   ------------------------ ----------- ------------------------
   c94n04.5.0               zhong       c94n04.2.r              
   c94n04.4.0               zhong                               
   
   2 job step(s) in queue, 1 waiting, 0 pending, 0 running, 1 held, 
                           0 preempted

8. The following is sample output for llq -X cluster2. The output
   representing a cluster is delineated with a cluster header, in this
   example it is cluster2. 

   =================== Cluster cluster2 ================================ 
  
   Id              Owner     Submitted   ST PRI Class      Running On 
   --------------- --------- ----------- -- --- ---------- ---------- 
   c188f2n02.9.0   brownap   10/29 13:54  R 50  april      c188f2n08                  
   
   1 job step(s) in query, 0 waiting, 0 pending, 1 running, 0 held, 
   0 preempted

9. The following is sample output for llq -X all command where there are
   two clusters: 

   =================== Cluster cluster1 ================================
   
   Id              Owner     Submitted   ST PRI Class      Running On 
   --------------- --------- ----------- -- --- ---------- ----------
   c193n13.283.0   rolf      8/4 10:58   R  50  No_Class   c193n13
   c193n13.283.0   rolf      8/4 10:58   R  50  No_Class   c193n13
   c193n13.289.0   rolf      8/4 10:58   R  50  No_Class   c193n13
   c193n13.291.0   rolf      8/4 10:59   R  50  No_Class   c193n13
   c193n13.293.0   rolf      8/4 10:59   R  50  No_Class   c193n13
   c193n13.295.0   rolf      8/4 10:59   R  50  No_Class   c193n13
   c193n13.297.0   rolf      8/4 11:01   R  50  No_Class   c193n13
   c193n13.299.0   brownap   8/4 11:02   R  50  No_Class   c193n13
   
   7 job step(s) in queue, 0 waiting, 0 pending, 7 running, 0 held, 
   0 preempted
   
   =================== Cluster cluster2 ================================
   
   Id              Owner     Submitted   ST PRI Class      Running On 
   --------------- --------- ----------- -- --- ---------- ----------
   c193n13.265.0   llbld     8/2 13:42   R  50  No_Class   c197blade3b14
   c193n13.267.0   llbld     8/2 13:43   R  50  No_Class   c197blade3b14
   c193n13.271.0   llbld     8/2 13:55   I  50  No_Class 
   c193n13.273.0   llbld     8/4 10:53   I  50  No_Class 
   c193n13.275.0   llbld     8/4 10:53   I  50  No_Class 
   c193n13.277.0   llbld     8/4 10:53   I  50  No_Class 
   c193n13.279.0   llbld     8/4 10:58   I  50  No_Class 
   
   7 job step(s) in queue, 5 waiting, 0 pending, 2 running, 0 held, 
   0 preempted

10. The following is sample output for llq -b for a standard Blue Gene
    listing: 

    Id           Owner      Submitted    LL  BG  PT  Partition    Size 
    ------------ ---------- -----------  --- --- --- ------------ -----
    fen01.193.0  jdoe       2/21 22:52   R       C   part031      65536
    fen02.1305.0 jfoe       2/20 02:36   R   R   B   part031       1024
    fen01.194.0  jane       2/21 14:12   I                          512

11. This example generates a customized and formatted standard listing: 

    llq -f %id %c %dq %dd %gl %h

    You should receive output similar to the following: 
      
   
    Step Id    Class    Queue Date  Disp. Date  LL Group Running On
    ---------- -------- ----------- ----------- -------- ---------------
    ll6.2.0    No_Class 04/08 09:19 04/08 09:21 No_Group ll6.pok.ibm.com
    ll6.1.0    No_Class 04/08 09:19 04/08 09:21 No_Group ll6.pok.ibm.com
    ll6.3.0    No_Class 04/08 09:19 04/08 09:21 No_Group ll5.pok.ibm.com
   
    3 job step(s) in queue, 0 waiting, 0 pending, 3 running, 0 held, 
    0 preempted

12. This example generates a customized, unformatted (raw) standard
    listing. Output fields are separated by an exclamation point (!). 

    llq -r %id %c %dq %dd %gl %h

    You should receive output similar to the following: 
     
    ll6.pok.ibm.com.2.0!No_Class!01/16/2008 09:19!01/16/2008 09:21! \
                        No_Group!ll6.pok.ibm.com
    ll6.pok.ibm.com.1.0!No_Class!01/16/2008 09:19!01/16/2008 09:21! \
                        No_Group!ll6.pok.ibm.com
    ll6.pok.ibm.com.3.0!No_Class!10/16/2008 09:19!01/16/2008 09:21! \
                        No_Group!ll5.pok.ibm.com

13. This example generates a WLM CPU and real memory statistics listing
    where c209f1n05.13.0 is a CPU intensive parallel job step currently
    running on the 2 nodes c209f1n05 and c209f1n01: If the LoadLeveler
    interface to AIX Workload Manager (WLM) is enabled, the -w option 
    can be used to obtain CPU and real memory statistics of job steps in
    running state. Note that Large Page memory information is not
    included in the statistics since WLM does not manage Large Page
    memory. 

    llq -w c209f1n05.13.0

    You should receive output similar to the following: 
   
    =============== Job Step c209f1n05.ppd.pok.ibm.com.13.0 ============
      c209f1n05.ppd.pok.ibm.com:
              Resource: CPU
                      snapshot: 99
                      total: 80172
              Resource: Real Memory
                      snapshot: 1
                      high water: 2561
   
      c209f1n01.ppd.pok.ibm.com:
              Resource: CPU
                      snapshot: 100
                      total: 79303
              Resource: Real Memory
                      snapshot: 1
                      high water: 1919

14. The following is sample llq -l output for task instances and
    allocated hosts if the job requested MCM affinity: 

    Allocated Hosts: e189f4rp04.ppd.pok.ibm.com:: \
                       sn1(MPI,IP,-1,Shared,0 rCxt Blks), \
                       sn1(MPI,IP,-1,Shared,0 rCxt Blks), \ 
                       MCM0:CPU< 0-5 >,MCM0:CPU< 0-5 > \ 
                    + e189f4rp03.ppd.pok.ibm.com:: \
                       sn1(MPI,IP,-1,Shared,0 rCxt Blks), \
                       sn1(MPI,IP,-1,Shared,0 rCxt Blks), \
                       MCM1:CPU< 4-5 >,MCM1:CPU< 4-5 > 
   
    Num Task Inst: 4
        Task Instance: e189f4rp04:0:sn1(MPI,IP,-1,Shared,0 rCxt Blks), \
                       MCM0:CPU< 0-5 >
        Task Instance: e189f4rp04:1:sn1(MPI,IP,-1,Shared,0 rCxt Blks), \
                       MCM0:CPU< 0-5 > 
        Task Instance: e189f4rp03:2:sn1(MPI,IP,-1,Shared,0 rCxt Blks), \
                       MCM1:CPU< 4-5 >
        Task Instance: e189f4rp03:3:sn1(MPI,IP,-1,Shared,0 rCxt Blks), \
                       MCM1:CPU< 4-5 >

    Note that the < > notation will be used to list individual CPU IDs
    instead of the CPU count ( ) notation when the RSET_SUPPORT
    configuration file keyword is set to RSET_CONSUMABLE_CPUS or
    RSET_MCM_AFFINITY.

15. The following example shows the Resource Set information in the llq
    -l listing when the	consumable CPUs Resource Set requirement is
    requested: 

    Allocated Hosts : e189f4rp01.ppd.pok.ibm.com:: \
                        sn0(MPI,IP,-1,Shared,0 rCxt Blks), \
                        sn0(MPI,IP,-1,Shared,0 rCxt Blks), \
                        CPU< 0-5 >,CPU< 0-5>
                     + e189f4rp02.ppd.pok.ibm.com:: \
                        sn0(MPI,IP,-1,Shared,0 rCxt Blks), \
                        sn0(MPI,IP,-1,Shared,0 rCxt Blks), \
                        CPU< 0-5 >,CPU< 0-5 >
   
    Num Task Inst: 4
        Task Instance: e189f4rp01:0:sn0(MPI,IP,-1,Shared,0 rCxt Blks), \
                       CPU< 0-5 >
        Task Instance: e189f4rp01:1:sn0(MPI,IP,-1,Shared,0 rCxt Blks), \
                       CPU< 0-5 >
        Task Instance: e189f4rp02:2:sn0(MPI,IP,-1,Shared,0 rCxt Blks), \
                       CPU< 0-5 >
        Task Instance: e189f4rp02:3:sn0(MPI,IP,-1,Shared,0 rCxt Blks), \
                       CPU< 0-5 >

16. The following example shows output for the llq -l command when rCxt
    blocks are present: 
    .
    .
    .
    Adapter Requirement: (sn_single,MPI,US,shared,AVERAGE,instances=1, \
                         rcxtblks=5)
    .
    .
    .
   
    Num Task Inst: 4
         Task Instance: c60f1rp02:0:sn1(MPI,US,10,Shared,5 rCxt Blks),
         Task Instance: c60f1rp02:1:sn0(MPI,US,10,Shared,5 rCxt Blks),
         Task Instance: c60f1rp02:2:sn1(MPI,US,11,Shared,5 rCxt Blks),
         Task Instance: c60f1rp02:3:sn0(MPI,US,11,Shared,5 rCxt Blks),

17. The following example shows output for the llq -l command when SMT
    is requested: 

    =============== Job Step blablahome.clusters.com.22.0 ==============
      Job Step Id: blablahome.clusters.com.22.0
         Job Name: blablahome.clusters.com.22
    .
    .
    .
           Status: Running
    .
    .
    .
        Large Page: N
        Coschedule: no
     SMT requested: yes
    Checkpointable: no
    .
    .
    .

18. The following example shows the port number for the InfiniBand
    resources used by the running job: 

    .
    .
    .
    Task
    ----
   
       Num Task Inst: 2
       Task Instance: c171f6sq08:0:ib0(MPI,US,2,Shared,0 rCxt Blks,1), \
          ib1(MPI,US,66,Shared,0 rCxt Blks,2),
       Task Instance: c171f6sq08:1:ib0(MPI,US,3,Shared,0 rCxt Blks,1), \
          ib1(MPI,US,67,Shared,0 rCxt Blks,2),
    .
    .
    .

Security

LoadLeveler administrators and users can issue this command.
