
llqres - Query a reservation

Purpose

llqres - Returns information about reservations in LoadLeveler.

Syntax

llqres   { -? | -H | -v | -W | [-l | -r] [-s] [[-u user_list] 
         [-g group_list] [-h host_list | -h all] 
         [-B base_partition_list | -B all] [-b begin_time]
         [-e end_time] | -R reservation_list] }

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-W 
   Specifies that the width of columns in tabular output will be
   increased to fit the widest entry.

-l 
   Specifies that a long listing be generated for each reservation to be
   queried.

-r 
   Specifies raw mode for output. Each reservation will occupy one line
   with the output fields separated by an exclamation point (!).

-s 
   Specifies that short host names will be used in the output of machine
   names.

-u user_list
   Specifies a blank-delimited list of users. Reservations to be queried
   are owned by one of these users.

-g group_list
   Specifies a blank-delimited list of LoadLeveler groups. Reservations
   to be queried are owned by one of these groups.

-h all
-h host_list
   Specifies a blank-delimited list of machines or all machines.
   Reservations to be queried use one or more of these machines.

-B all
-B base_partition_list
   Specifies all or a blank-delimited list of base partitions in the
   Blue Gene system. Reservations to be queried use one or more of these
   base partitions.

-b begin_time
   Reservations to be queried are active at or after the specified begin
   time. The -b flag can be used together with the -e flag to query
   reservations expected to be active between the begin and end times.
   The begin_time must be specified using the format [mm/dd[/[cc]yy]]
   HH:MM. Hours must be specified using a 24-hour clock.

-e end_time
   Reservations to be queried are active at or before the specified end
   time. The -e flag can be used together with the -b flag to query
   reservations expected to be active between the begin and end times.
   The end_time must be specified using the format [mm/dd[/[cc]yy]]
   HH:MM. Hours must be specified using a 24-hour clock.

-R reservation_list
   Is a blank-delimited list of reservation identifiers to be queried.
   The format of a full LoadLeveler reservation identifier is
   [host.]rid[.r]. 

   where:
    
   *  host is the name of the machine that assigned the reservation
      identifier.
   *  rid is the number assigned to the reservation when it was created.
      An rid is required.
   *  r indicates that this is a reservation ID (r is optional).
    
   The reservation identifier may be specified in an abbreviated form,
   rid[.r], when the command is invoked on the same machine that
   assigned the reservation identifier. In this case, LoadLeveler will
   use the local machine's host name to construct the full reservation
   identifier.
    
   When -R is specified, -u, -g, and -h are ignored.

Description

All users can issue this command. Reservations satisfying all criteria
specified by -u, -g, -h or -B, -b, and -e will be queried if more than
one of these options are present. The -h and -B flags are mutually
exclusive. No reservation information will be returned if both are
specified at the same time. By default, the llqres command queries all
existing reservations.

This command is for the BACKFILL scheduler only.

Examples

When the BG_ENABLED keyword is set to false in the configuration file,
the following examples apply.

1. When issuing the llqres command, you should receive output similar to
   the following: 

   Id              Owner     ST  Start Time   Duration #Nodes
   -----------     -----     --  -----------  -------- ------
   c94n16.30.r     loadl     A   10/16  14:00    120      3
   c94n16.31.r     dave      W   10/17  02:00    420      4
   c94n16.35.r     carol     W   10/17  13:30    240      2

   When issuing the llqres -l command, you should receive output
   similar to the following: 

   =============== Reservation c94n16.ppd.pok.ibm.com.30.r =============
                  ID: c94n16.ppd.pok.ibm.com.30.r
       Creation Time: Mon Feb 18 08:12:23 EDT 2008
               Owner: loadl
               Group: No_Group
          Start Time: Mon Feb 18 14:00:00 EDT 2008
            Duration: 120 minutes
   Expected End Time: Mon Feb 18 16:00:00 EDT 2008
              SHARED: no
      REMOVE_ON_IDLE: no
              Status: ACTIVE
         Modified By: loadl
   Modification Time: Mon Feb 18 10:21:14 EDT 2008
               Users: 0
              Groups: 1
                      loadlusr
               Nodes: 3
                      c94n01.ppd.pok.ibm.com
                      c94n11.ppd.pok.ibm.com
                      c94n12.ppd.pok.ibm.com
           Job Steps: 0
   
   =============== Reservation c94n16.ppd.pok.ibm.com.31.r =============
                  ID: c94n16.ppd.pok.ibm.com.31.r
       Creation Time: Mon Feb 18 10:55:18 EDT 2008
               Owner: dave
               Group: No_Group
          Start Time: Tue Feb 19 02:00:00 EDT 2008
            Duration: 420 minutes
   Expected End Time: Tue Feb 19 09:00:00 EDT 2008
              SHARED: no
      REMOVE_ON_IDLE: yes
              Status: WAITING
         Modified By: dave
   Modification Time: Tue Feb 19 10:55:18 EDT 2008
               Users: 0
              Groups: 0
               Nodes: 4
                      c94n01.ppd.pok.ibm.com
                      c94n02.ppd.pok.ibm.com
                      c94n12.ppd.pok.ibm.com
                      c94n16.ppd.pok.ibm.com
           Job Steps: 1
                      c94n16.ppd.pok.ibm.com.25.0
   
   =============== Reservation c94n16.ppd.pok.ibm.com.35.r =============
                  ID: c94n16.ppd.pok.ibm.com.35.r
       Creation Time: Mon Feb 18 10:58:19 EDT 2008
               Owner: carol
               Group: No_Group
          Start Time: Tue Feb 19 13:30:00 EDT 2008
            Duration: 240 minutes
   Expected End Time: Tue Feb 19 17:30:00 EDT 2008
              SHARED: no
      REMOVE_ON_IDLE: no
              Status: WAITING
         Modified By: carol
   Modification Time: Mon Feb 18 10:58:19 EDT 2008
               Users: 2
                      jay
                      iris
              Groups: 0
               Nodes: 2
                      c94n01.ppd.pok.ibm.com
                      c94n02.ppd.pok.ibm.com
           Job Steps: 0

2. To determine if any reservations will be active on the machine c94n01
   before performing an hours worth of maintenance beginning at 8:00 on
   02/18/2008, issue the following command: 

   llqres -b 02/18/2008 8:00 -e 02/18/2008 9:00 -h c94n01

   You should receive output similar to the following:
   
   Id              Owner     ST  Start Time   Duration #Nodes
   -----------     -----     --  -----------  -------- ------
   c94n16.31.r     dave      W   02/18  02:00    420      4

3. There are no job steps associated with a reservation in the following
   example. The short form is used for host names: 

   llqres -r -s -R c94n16.30.r              

   You should receive output similar to the following: 
   c94n16.30.r!Mon Feb 18 08:12:23 EDT 2008!loadl!No_Group! \
      Mon Feb 18 14:00:00 EDT
   2008!120!Mon Feb 18 16:00:00 EDT 2008!no!no!ACTIVE!loadl! \
      Mon Feb 18 10:21:14 EDT
   2008!0!!1!loadlusr!3!c94n01,c94n11,c94n12!0!

4. There are job steps associated with a reservation in the following
   example. The short form is used for host names: 

   llqres -r -s -R c94n16.31.r

   You should receive output similar to the following: 

   c94n16.31.r!Mon Feb 18 10:35:18 EDT 2008!dave!No_Group! \
      Mon Feb 18 02:00:00 EDT
   2008!420!Mon Feb 18 09:00:00 EDT 2008!no!yes!WAITING!dave! \
      Mon Feb 18 10:55:18 
   EDT 2008!0!!0!!4!c94n01,c94n02,c94n12,c94n16!1!c94n16.25.0

When the BG_ENABLED keyword is set to true in the configuration file,
the following examples apply. 

1. When issuing the llqres command, you should receive output similar to
   the following: 

   llqres

   ID              Owner      ST  Start Time Duration #Nodes #BG C-nodes
   --------------- ---------- -- ----------- -------- ------ -----------
   bgldd1.62.r     ezhong      W  6/13 18:40        5      1           0
   bgldd1.61.r     ezhong      W  6/13 18:40        5      0         128
   bgldd1.60.r     ezhong      W  6/13 18:30        5      0         512

2. The following example returns reservation information about all
   machines: 

   llqres -h all
  
   You should receive output similar to the following: 

   ID              Owner      ST  Start Time Duration #Nodes #BG C-nodes
   --------------- ---------- -- ----------- -------- ------ -----------
   bgldd1.62.r     ezhong      W  6/13 18:40        5      1           0

3. The following example generates a list of base partitions for R010: 

   llqres -B R010
   
   You should receive output similar to the following: 

   ID              Owner      ST  Start Time Duration #Nodes #BG C-nodes
   --------------- ---------- -- ----------- -------- ------ -----------
   bgldd1.60.r     ezhong      A  6/13 18:30        5      0         512

4. The following example generates a list of all base partitions in the
   Blue Gene system in raw mode: 

   llqres -r -B all
   
   You should receive output similar to the following: 

   bgldd1.rchland.ibm.com.61.r!Wed 13 Feb 2008 06:28:09 PM CDT! \
      ezhong!No_Group!Wed 13 Feb 2008 06:40:00 PM
   CDT!5!Wed 13 Feb 2008 06:45:00 PM CDT!no!no!WAITING!ezhong! \
      Wed 13 Feb 2008 06:28:09 PM
   CDT!0!!0!!0!!1!bgldd1.rchland.ibm.com.200.0!128!MESH!0x0x0!1!R011 \
      (J111;J113;J115;J117)!MYPARTITION
   bgldd1.rchland.ibm.com.60.r!Wed 13 Feb 2008 06:26:36 PM CDT! \
      ezhong!No_Group!Wed 13 Feb 2008 06:30:00 PM
   CDT!5!Wed 13 Feb 2008 06:35:00 PM CDT!no!no!ACTIVE!ezhong! \
      Wed 13 Feb 2008 06:26:36 PM
   CDT!0!!0!!0!!1!bgldd1.rchland.ibm.com.199.0!512!MESH!1x1x1!1!R010!

5. The following example shows a long listing of all reservations in a
   system where Blue Gene support is enabled: 

   llqres -l
   
   You should receive output similar to the following:
   
   =============== Reservation bgldd1.rchland.ibm.com.62.r =============
                    ID: bgldd1.rchland.ibm.com.62.r
         Creation Time: Wed 13 Feb 2008 06:28:25 PM CDT
                 Owner: ezhong
                 Group: No_Group
            Start Time: Wed 13 Feb 2008 06:40:00 PM CDT
              Duration: 5 minutes
      xpected End Time: Wed 13 Feb 2008 06:45:00 PM CDT
                SHARED: no
          MOVE_ON_IDLE: no
                Status: WAITING
           Modified By: ezhong
     Modification Time: Wed 13 Feb 2008 06:28:25 PM CDT
                 Users: 0
                Groups: 0
                 Nodes: 1
                        bgldd1.rchland.ibm.com
             Job Steps: 1
                        bgldd1.rchland.ibm.com.201.0
            BG C-nodes: 0
         BG Connection:
              BG Shape:
                BG BPs: 0
          BG Partition: 
   =============== Reservation bgldd1.rchland.ibm.com.61.r =============
                    ID: bgldd1.rchland.ibm.com.61.r
         Creation Time: Wed 13 Feb 2008 06:28:09 PM CDT
                 Owner: ezhong
                 Group: No_Group
            Start Time: Wed 13 Feb 2008 06:40:00 PM CDT
              Duration: 5 minutes
     Expected End Time: Wed 13 Feb 2008 06:45:00 PM CDT
                SHARED: no
        REMOVE_ON_IDLE: no
                Status: WAITING
           Modified By: ezhong
     Modification Time: Wed 13 Feb 2008 06:28:09 PM CDT
                 Users: 0
                Groups: 0
                 Nodes: 0
             Job Steps: 1
                        bgldd1.rchland.ibm.com.200.0
            BG C-nodes: 128
         BG Connection: MESH
              BG Shape: 0x0x0
                BG BPs: 1
                        R011(J111;J113;J115;J117)
          BG Partition: MYPARTITION
   =============== Reservation bgldd1.rchland.ibm.com.60.r =============
                    ID: bgldd1.rchland.ibm.com.60.r
         Creation Time: Wed 13 Feb 2008 06:26:36 PM CDT
                 Owner: ezhong
                 Group: No_Group
            Start Time: Wed 13 Feb 2008 06:30:00 PM CDT
              Duration: 5 minutes
     Expected End Time: Wed 13 Feb 2008 06:35:00 PM CDT
                SHARED: no
        REMOVE_ON_IDLE: no
                Status: ACTIVE
           Modified By: ezhong
     Modification Time: Wed 13 Feb 2008 06:26:36 PM CDT
                 Users: 0
                Groups: 0
                 Nodes: 0
             Job Steps: 1
                        bgldd1.rchland.ibm.com.199.0
            BG C-nodes: 512
         BG Connection: MESH
              BG Shape: 1x1x1
                BG BPs: 1
                        R010
          BG Partition: 

6. The following example shows reserving resources during the time
   period from 18:35 to 18:45: 

   llqres -b 18:35 -e 18:45
   
   You should receive output similar to the following: 

   ID              Owner      ST  Start Time Duration #Nodes #BG C-nodes
   --------------- ---------- -- ----------- -------- ------ -----------
   bgldd1.62.r     ezhong      W  6/13 18:40        5      1           0
   bgldd1.61.r     ezhong      W  6/13 18:40        5      0         128

7. The following example shows one reservation in raw mode. The short
   form is used for hostnames: 

   llqres -r -s c94n16.30.r
  
   You should receive output similar to the following: 

   c94n16.30.r!Fri Feb 22 08:12:23 EDT 2008!loadl!No_Group! \
      Fri Feb 22 14:00:00 EDT
   2008!120!Fri Feb 22 16:00:00 EDT 2008!no!no!ACTIVE!loadl! \
      Fri Feb 22 10:21:14 EDT
   2008!0!!1!loadlusr!3!c94n01,c94n11,c94n12!0!!0!0x0x0!

8. The following example shows that there are job steps associated with
   the reservation. The short form is used for hostnames: 

   llqres -r -s c94n16.31.r
   
   You should receive output similar to the following: 

   c94n16.31.r!Fri Feb 22 10:35:18 EDT 2008!dave!No_Group! \
      Thu Feb 21 02:00:00 EDT
   2008!420!Thu Feb 21 09:00:00 EDT 2008!no!yes!WAITING!dave! \
      Fri Feb 22 10:55:18 EDT
   2008!0!!0!!4!c94n01,c94n02,c94n12,c94n16!1!c94n16.25.0!0!0x0x0!
