
llstatus - Query machine status

Purpose

llstatus - Returns status information about machines in the LoadLeveler
cluster.

Syntax
 
llstatus [-?] [-H] [-v] [-W] [-R] [-F] [-M] [-l] [-a] [-C] [-b]
         [-B {base_partition_list | all}] [-P {partition_list | all}]
         [-X {cluster_list | all}] [-f category_list] [-r category_list]
         [-h hostlist | hostlist]

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-W 
   Specifies that the width of columns in tabular output will be
   increased to fit the widest entry.

-R 
   Lists the machine consumable resources associated with each machine
   for which status is requested. The total number of RDMA resources for
   High Performance Switch adapters is limited to four and each RDMA job
   running on a node consumes one RDMA resource. Because there is no
   limit on RDMA resources for InfiniBand adapters, RDMA resources are
   not listed in the long listing when there are any InfiniBand adapters
   connected to the system. 

   This option should not be used with any other option.

-F 
   Lists all of the floating consumable resources associated with the
   LoadLeveler cluster. This option should not be used with any other
   option.

-M 
   Lists the Multiple Chip Modules (MCMs) available on a machine, where:
   
   Available CPUs
            Are the CPU IDs of the CPUs available for LoadLeveler on
            this MCM.
   Used CPUs
            Are the CPU IDs of the CPUs used by LoadLeveler jobs on this
            MCM.
   Adapters Are the switch adapters connected to this MCM of the form: 

            [used windows/available windows, used rCxt blocks/available \
               rCxtBlocks]
             
            where:
            
            used windows
                     Is the number of windows used.
            available windows
                     Is the total number of windows on the adapter.
            used rCxt blocks
                     Is the number of rCxt blocks used.
            available rCxt blocks
                     Is the total number of rCxt blocks on the adapter.
   Total Tasks
            Is the total number of tasks that are running using CPUs of
            this MCM.
    
            Note that the < > notation will be used to list individual  
            CPU IDs instead of the CPU count ( ) notation when the 
            RSET_SUPPORT configuration file keyword is set to 
            RSET_CONSUMABLE_CPUS or RSET_MCM_AFFINITY.

-l 
   Specifies that a long listing be generated for each machine for which
   status is requested. If -l is not specified, the standard list is
   generated.

-a 
   Displays information for each virtual adapter followed by information
   for each physical adapter it manages. This flag also displays the
   port number on each InfiniBand adapter port.

-C 
   Displays cluster stanza information defined in the administration
   file. Only fields that contain data are displayed. If -C is specified
   without the -X flag, cluster stanza information will be reported from
   one outbound local Schedd. If the -X and -C flags are specified,
   cluster stanza information will be reported from an inbound Schedd in
   each available remote cluster specified with the -X flag. If the -h
   flag is specified, cluster stanza information will only be reported
   from the specified hosts.

-b 
   Displays Blue Gene system information. It is valid only when
   specified as a single option or in combination with the -l flag. When
   used as single option, llstatus displays a short listing of
   information on the Blue Gene system. When used the -l flag, llstatus
   displays a detailed listing of the components of the Blue Gene
   system.

-P {partition_list | all}
   Displays Blue Gene partition information. It is valid only when
   specified as a single option. When this flag is specified, llstatus
   displays information on all Blue Gene partitions in the
   partition_list. 

   partition_list
            Is a blank-delimited list of Blue Gene partitions.

   all      Is the reserved word indicating that the command is to
            return information for all partitions.

-B {base_partition_list | all}
   Displays Blue Gene base partition information. It is valid only when
   specified as a single option. When this flag is specified, llstatus
   displays information about all Blue Gene base partitions in the
   base_partition_list. 

   base_partition_list
            Is a blank-delimited list of Blue Gene base partitions.

   all      Is the reserved word indicating that the command is to
            return information for all base partitions.

-X {cluster_list | all}
   Indicates that you can specify the -X flag with either: 

   cluster_list
            Specifies a blank-delimited list of clusters for which
            status is requested.

   all      Is a reserved word which specifies that status is requested
            for all accessible clusters.

-f category_list
   Is a blank-delimited list of categories you want to query. Each
   category you specify must be preceded by a percent sign. The
   category_list cannot contain duplicate entries. This flag allows you
   to create a customized version of the standard llstatus listing. The
   output fields produced by this flag all have a fixed length. The
   output is displayed in the order in which you specify the categories.
   category_list can be one or more of the following: 

   %a       Hardware architecture

   %act     Number of job steps dispatched by the Schedd daemon on this
            machine

   %cm      Custom Metric value

   %cpu     Number of CPUs on this machine

   %d       Available disk space in the LoadLeveler execute directory

   %i       Number of seconds since last keyboard or mouse activity

   %inq     Number of job steps in the job queue of this Schedd machine

   %l       Berkeley one-minute load average

   %m       Physical memory on this machine

   %mt      Maximum number of initiators that can be used simultaneously
            on this machine

   %n       Machine name

   %o       Operating system on this machine

   %r       Number of initiators used by the startd daemon on this
            machine

   %sca     Availability of the Schedd daemon

   %scs     State of the Schedd daemon

   %sta     Availability of the startd daemon

   %sts     State of the startd daemon

   %v       Available swap space (free paging space) of this machine

   %X       Local cluster name

-r category_list
   Is a blank-delimited list of categories you want to query. Each
   category you specify must be preceded by a percent sign. The
   category_list cannot contain duplicate entries. This flag allows you
   to create a customized version of the standard llstatus listing. The
   output produced by this flag is considered raw, in that the fields
   can be variable in length. The output is displayed in the order in
   which you specify the formats. Output fields are separated by an
   exclamation point (!). category_list can be one or more of the
   categories listed under the -f flag.

-h hostlist
hostlist
   Is a blank-delimited list of machines for which status is requested. 

   If the -X flag is specified in combination with a hostlist, the -h
   flag must be specified. For example: 

   llstatus -X my_cluster1 my_cluster2 -h c94n13 c94n14

Description

If you have more than a few machines configured for LoadLeveler,
consider redirecting the output to a file when using the -l flag.

Each machine periodically updates the central manager with a snapshot of
its situation. Since the information returned by using llstatus is a
collection of such snapshots, all taken at varying times, the total
picture may not be completely consistent.

In most cases, if a hostlist is not specified, all machines are queried.
However, if the -X and -C flags are specified without a hostlist, the
command will run on one inbound Schedd in the remote cluster. In this
case, the Schedd version information from the inbound Schedd in the
remote cluster will be displayed.

Certain resources such as remote direct-memory access (RDMA) have their
available value always calculated by startd. Available ConsumableCpus
resources are calculated by startd if the value is specified as all in
the administration file. When the value of a resource is calculated by
startd, the llstatus command appends a plus (+) sign to the resource
name in the output reports. Resources that are automatically created,
such as RDMA, have a less than (<) sign appended to them.

Examples

1. This example generates the standard listing where there are two nodes
   in the cluster. The standard listing is generated when you do not
   specify the -l option with the llstatus command. 

   llstatus 
  
   You should receive output similar to the following:
   
   Name                   Schedd InQ Act Startd Run LdAvg Idle Arch  OpSys
   k10n09.ppd.pok.ibm.com Avail   3   1  Run      1 2.72     0 R6000 AIX53
   k10n12.ppd.pok.ibm.com Avail   0   0  Idle     0 0.00   365 R6000 AIX53
   
   R6000/AIX53            2 machines   3 jobs   1 running tasks
   Total Machines         2 machines   3 jobs   1 running tasks
    
   The Central Manager is defined on k10n09.ppd.pok.ibm.com
   
   The BACKFILL scheduler is in use
   
   Cluster name is cluster2
   
   All machines on the machine_list are present. 
    
   The standard listing includes the following fields:
    
   Act      Number of job steps dispatched by the Schedd daemon on this
            machine.

   Arch     The hardware architecture of the machine as listed in the
            configuration file.

   Idle     The number of seconds since keyboard or mouse activity in a
            login session was detected. Highest number displayed is
            9999.

   InQ      Number of job steps in the job queue of this Schedd machine.

   LdAvg    Berkeley one-minute load average on this machine.

   Name     Hostname of the machine.

   OpSys    The operating system on this machine.

   Run      The number of initiators used by the startd daemon to run
            LoadLeveler jobs on this machine. One initiator is used for
            each serial job step and one initiator is used for each task
            of a parallel job step.

   Schedd   State of the Schedd daemon, which can be one of the
            following: 
            *  Down
            *  Drned (Drained)
            *  Drning (Draining)
            *  Avail (Available)
             
            For more information, see the description of the Schedd
            daemon in TWS LoadLeveler: Using and Administering.

   Startd   State of the startd daemon, which can be: 
            *  Busy
            *  Down
            *  Drned (Drained)
            *  Drning (Draining)
            *  Flush
            *  Idle
            *  None
            *  Run (Running)
            *  Suspnd (Suspend)
             
            For more information, see the description of the startd
            daemon in TWS LoadLeveler: Using and Administering.

   Total Machines
            The standard listing includes the following summary fields: 

            jobs     The number of job steps in LoadLeveler job queues.

            machines The number of machines in the cluster that have
                     made a status report to the Central Manager.

            running tasks
                     The number of initiators used by all the startd
                     daemons in the LoadLeveler cluster. One initiator
                     is used for each serial job step. One initiator is
                     used for each task of a parallel job step.
    
   The standard listing also contains summary information for the
   cluster such as the type of scheduler and the cluster name.

2. This example generates the long listing. The long listing is
   generated when you specify the -l flag with the llstatus command. See
   the "Sample command output" topic for sample output of long listings
   in TWS LoadLeveler: Using and Administering. 

   llstatus -l c271f2rp02
   
   The long listing includes the following fields:
    
   Adapter  Network adapter information associated with this machine. 

            *  For a switch adapter, the information format is: 

               adapter_name(network_type, interface_name, 
               interface_address, multilink_address, 
               switch_node_number or adapter_logical_id, \
	       available_adapter_windows/total_adapter_windows, \ 
	       unused rCxt blocks/total rCxt blocks, 
	       adapter_fabric_connectivity, adapter_state)
                
               For example:
                
               Adapter = networks(striped, \ 
	       c60f1rp01ml0.ppd.pok.ibm.com,10.10.10.1,,-1, \
	       32/32,1596/1596 rCxt Blks,1,READY) \ 
	       en0(ethernet,c60f1rp01.ppd.pok.ibm.com,9.114.88.65,) \ 
               network1(aggregate,,,10.10.10.1,-1,32/32,1596/1596 \ 
               rCxt Blks,1,READY)ml0(multilink, \
	       c60f1rp01ml0.ppd.pok.ibm.com,10.10.10.1,)
                
               Possible values for adapter_state are:
                
               ErrAdapter 
                        The adapter information is incorrect. More
                        information might be available in the network
                        table API log.

               ErrDown  The adapter has been reported as down.

               ErrInternal
                        An error occurred while accessing the adapter.
                        More information might be available in the
                        network table API log and if the D_FULLDEBUG and
                        D_ADAPTER flags are specified for STARTD_DEBUG.

               ErrNotConnected
                        The adapter is not connected to the network.

               ErrNotInitialized
                        An error occurred initializing access to the
                        adapter. More information might be available if
                        the D_FULLDEBUG and D_ADAPTER flags are
                        specified for  STARTD_DEBUG.

               ErrNTBL  An error occurred while accessing the network
                        table API. More information might be available
                        if the D_FULLDEBUG and D_ADAPTER flags are
                        specified for  STARTD_DEBUG.

               ErrNTBLVersion
                        The version of the available network table API
                        is not compatible with the version required by
                        LoadLeveler.

               ErrPerm  The network table API reported that LoadLeveler
                        does not have permission to access the adapter.
                        More information might be available in the
                        network table API log.

               ErrPNSD  An error occurred in the network table API. More
                        information might be available in the network
                        table API log.

               ErrType  The network table API reported that the adapter
                        is not a switch adapter. Check the adapter
                        configuration.

               MachineDown
                        The machine to which the adapter is attached
                        could not be reached by LoadLeveler to query
                        status.

               NOT READY
                        An unspecified problem occurred when accessing
                        the adapter state. More information might be
                        available if the D_FULLDEBUG and D_ADAPTER flags
                        are specified for  STARTD_DEBUG.

               READY    The adapter can be used for communication.

            *  For non-switch adapters, the format is: 

               adapter_name(network_type, interface_name, 
               interface_address, multilink_address)

               Arch     Hardware architecture of this machine.

               AvailableClasses
                        List of available classes and the associated 
		        number of available initiators on this machine.

               Completed
                        The number of job steps in this state on this 
		        Schedd machine.

               Config Time Stamp
                        Date and time of last configuration or 
			reconfiguration.

               ConfiguredClasses
                        List of configured classes and the associated 
			number of configured initiators on this machine.

               ConsumableResources
                        List of consumable resources associated with 
			this machine. Each element of this list has the 
			format: resource_name(available, total). 

                        Note: The individual CPU ID < > notation will be 
			      used to list individual CPU IDs instead of 
			      the CPU count ( ) notation for machines 
			      where the RSET_SUPPORT configuration file 
			      keyword is set to RSET_MCM_AFFINITY or 
			      RSET_CONSUMABLE_CPUS. The CPU count ( ) 
			      notation will be used when the 
			      RSET_SUPPORT configuration file keyword is 
			      set to RSET_USER_DEFINED or RSET_NONE, or
                              if this keyword is not specified in the 
			      configuration file.


               CONTINUE 
                        The expression, defined following C conventions 
			in the configuration file, that evaluates to 
			true or false (T or F). This determines whether 
			suspended jobs are continued on this machine.

               Cpus     Number of CPUs on this machine.

               CustomMetric
                        This value can be the number assigned to the 
			CUSTOM_METRIC keyword or the exit code of the 
			executable associated with the 
			CUSTOM_METRIC_COMMAND keyword or the default 
			value of 1.

               Disk     Available space, in kilobytes (less 512KB) in 
	                LoadLeveler's execute directory on this machine.

               DrainedClasses
                        List of classes which have been drained. If a 
			job step is in a class named on this list, that
			job step will not start on this machine.

               DrainingClasses
                        List of classes which are currently being 
			drained on this machine. If a job step is in a 
			class named on this list, that job step will not
			start on this machine.

               Entered Current State
                        Date and time when machine state was set.

               FabricConnectivity
                        Represents the current state of connectivity 
			between the machine and the switch through the 
			switch adapters. The format of the field is: 
			network_id: connectivity, network_id: 
			connectivity... where connectivity is either 1
                        or 0. A value of 1 indicates an active 
			connection from the machine to a given 
			network_id through one of the switch adapters. 

                        If a machine does not have switch adapters, the
                        FabricConnectivity field has no meaning and 
			should be ignored by the user.

               Feature  Set of all features on this machine.

               FreeLargePageMemory
                        Free Large Page memory. 

                        In LoadLeveler for Linux, the FreeLargePageMemory 
			field has no meaning and should be ignored by the 
			user.

               FreeRealMemory
                        Free real memory, in megabytes, on this machine. 
			This value should track closely with the "fre" 
			value of the vmstat command and the "free" value 
			of the svmon -G command whose units are 4KB 
			blocks.

               Held     The number of job steps in this state on this 
	                Schedd machine.

               Idle     The number of job steps in this state on this 
	                Schedd machine.

               Keyboard Idle
                        Number of seconds since last keyboard or mouse 
			activity.

               KILL     The expression, defined following C conventions 
	                in the configuration file, that evaluates to 
			true or false (T or F). This determines whether 
			jobs running on this machine should be sent the 
			SIGKILL signal.

               LargePageMemory
                        Configured Large Page physical memory. 

                        In LoadLeveler for Linux, the LargePageMemory 
			field has no meaning and should be ignored by 
			the user.

               LargePageSize
                        The size of a Large Page memory block. 

                        In LoadLeveler for Linux, the LargePageSize 
			field has no meaning and should be ignored by 
			the user.

               LoadAvg  Berkely one-minute load average on machine.

               Machine  Fully qualified name of the machine.

               Machine Mode
                        The type of job this machine can run. This can 
			be: batch, interactive, or general.

               MACHPRIO 
                        Actual expression that determines machine 
			priority, defined in the configuration file.

               MasterMachPriority
                        The machine priority for the parallel master 
			node.

               Max_Starters
                        Maximum number of initiators that can be used 
			simultaneously on this machine.

               Mcms     The MCMs information associated with this 
	                machine has the format: 

                        mcm_info ... mcm_info
            
                        The format of mcm_info is:            

                        MCMnumber Available Cpus: <cpulist> (Total Cpus)  
                        Used Cpus: < cpulist > (Total Cpus)  
                        Adapters: adapater_info .... adapter_info 
                        Total Tasks: (Tasks) 
           
                        where:
            
                        Available Cpus
                             Are the CPUs available for LoadLeveler on 
			     this MCM.

                        Used Cpus
                              Are the CPUs used by LoadLeveler jobs from 
			      this MCM.

                        Adapters 
                              Are the switch adapters connected to this 
			      MCM.

                        Total tasks
                              Is the total number of tasks that are 
			      running using CPUs of this MCM. 

                              where number is the MCM sequence number:
                    
                              cpulist  Is a blank-delimited list of 
			               individual CPU IDs or CPU ranges, 
				       or a combination of both CPU IDs 
				       and CPU ranges associated with
                                       the MCM.

                              adapter_info
                                       Has the format: 

                                       [used windows/available windows, \ 
				       used memory/available memory]                               
                         
                                       where:                           

                                       used windows
                                           Is the total number of 
					   windows used.

                                       available windows
                                           Is the total number of 
					   available windows.

                                       used memory
                                           Is the total memory used. It 
					   is the number of rCxt blocks 
					   for the High Performance 
					   Switch adapter.

                                       available memory
                                           Is the total available memory. 
					   It is the number of rCxt 
					   blocks for the High 
					   Performance Switch adapter.

                        Tasks 
			      Is the total number of tasks that are
                              running using the CPUs of this MCM.

               Memory   Regular physical memory, in megabytes, on this 
	                machine.

               Name     Hostname of the machine.

               OpSys    Operating system on this machine.

               PagesFreed
                        Pages freed per second. This value corresponds 
			to the "fr" value of the vmstat command output. 

                        In LoadLeveler for Linux, the PagesFreed field 
			has no meaning and should be ignored by the 
			user.
  
               PagesPaged In
                        Pages paged in from paging space per second. 
			This value corresponds to the "pi" value of the 
			vmstat command output. 

                        In LoadLeveler for Linux, the PagesPagedIn field
			has no meaning and should be ignored by the user.

               PagesPagedOut
                        Pages paged out to paging space per second. This 
			value corresponds to the "po" value of the 
			vmstat command output. 

                        In LoadLeveler for Linux, the PagesPagedOut 
			field has no meaning and should be ignored by 
			the user.

               PagesScanned
                        Pages scanned by the page-replacement algorithm 
			per second. This value corresponds to the "sr" 
			value of the vmstat command output. 

                        In LoadLeveler for Linux, the PagesScanned field 
			has no meaning and should be ignored by the user.

               Pending  The number of job steps in this state on this 
	                Schedd machine.

               Pool     The identifier of the pool where this startd 
	                machine is located.

               Prestarted_Starters
                        The maximum number of Prestarted Starters that 
			can be started on this machine at any time.

               Remove Pending
                        The number of job steps in this state on this 
			Schedd machine.

               ReservationPermitted
                        Indicates whether or not the node can be 
			reserved. It is displayed as T or F (true or 
			false).

               Reservations
                        The IDs of reservations that will use the node 
			now or in the future.

               RSetSupportType
                        Indicates the type of RSet support set up on a 
			machine. Possible values are: 

                        RSET_CONSUMABLE_CPUS
                              Creates and attaches RSets for tasks with 
			      the number of CPUs derived from 
			      ConsumableCPUs.
                        RSET_MCM_AFFINITY
                              Creates and attaches RSets for tasks to 
			      satisfy memory and affinity requests.
                        RSET_NONE
                              Indicates that LoadLeveler RSet support is 
			      not available.
                        RSET_USER_DEFINED
                              Attaches user-created RSets to Tasks.

               Running Tasks
                        The number of initiators used by the startd 
			daemon to run LoadLeveler jobs. One initiator is 
			used for each serial job step. One initiator is 
			used for each task of a parallel job step.

               Running steps
                        The list of job steps currently running on this 
			machine.

               ScheddAvail
                        Flag indicating if machine is running a Schedd 
			daemon (0=no, 1=yes).

               ScheddRunning
                        The number of job steps submitted to this 
			machine that are running somewhere in the 
			LoadLeveler cluster.

               ScheddState
                        The state of the Schedd daemon on this machine, 
			which can be one of the following: 
                        *  Down
                        *  Drned (Drained)
                        *  Drning (Draining)
                        *  Avail (Available)

               Speed    Speed associated with the machine.

               SMT      Indicates whether the simultaneous 
	                multithreading (SMT) function is turned on, 
			off, or is not supported in the running machine. 
			Valid values are Enabled, Disabled, or Not
                        Supported.

               START    The expression, defined following C conventions 
	                in the configuration file, that evaluates to 
			true or false (T or F). This determines whether 
			jobs can be started on this machine.

               StartdAvail
                        Flag indicating if machine is running a startd 
			daemon (0=no, 1=yes).

               Starting The number of job steps in this state on this 
	                Schedd machine.

               State    State of the startd daemon, which can be: 
                        *  Busy
                        *  Down
                        *  Drained
                        *  Draining
                        *  Flush
                        *  Idle
                        *  None
                        *  Running
                        *  Suspend
            
                        For more information, see the description of the 
			startd daemon in TWS LoadLeveler: Using and 
			Administering.

               Subnet   The TCP/IP subnet that this machine resides on.

               SUSPEND  The expression, defined following C conventions 
	                in the configuration file, that evaluates to 
			true or false (T or F). This determines whether 
			running jobs should be suspended on this machine.

               SYSPRIO  Actual expression that determines overall system 
	                priority of a job step. Defined in the 
			configuration file.

               TimeStamp
                        The date and time the central manager last 
			received a status update from this Schedd 
			machine.

               Tmp      Available space, in kilobytes (less than 512 KB) 
	                in the /tmp directory on this machine.

               Total Jobs
                        The number of total job steps submitted to this 
			Schedd machine.

               TotalMemory
                        The sum of configured regular and Large Page 
			memory.

               Unexpanded
                        The number of job steps in this state on this 
			Schedd machine.

               VACATE   The expression, defined following C conventions 
	                in the configuration file, that evaluates to 
			true or false (T or F). This determines whether 
			suspended jobs are vacated on this machine.

               Virtual Memory
                        Available swap space (free paging space) in 
			kilobytes, on this machine.

3. This example generates a listing of cluster information defined in
   the administration file and Schedd version for cluster2. Only fields
   with data are displayed. 

   llstatus -X cluster2 -C
    
   The output representing a cluster is delineated with a cluster header
   and Schedd version information from a remote cluster similar to the
   following:    

   =================== Cluster cluster2 ================================
   llstatus: Sending request to Schedd "c188f2n08.ppd.pok.ibm.com" in 
             cluster "cluster2"
   
   cluster2: type = cluster
           Local = True
           inbound_schedd_port = 9605
           secure_schedd_port = 9607
           multicluster_security = NOT_SET
           ssl_cipher_list = ALL:eNULL:!aNULL
           inbound_hosts = c188f2n08.ppd.pok.ibm.com
           outbound_hosts = c188f2n08.ppd.pok.ibm.com
           exclude_classes = badtesters(cluster3) OKtesters(cluster1)
   cluster1: type = cluster
           Local = False
           inbound_schedd_port = 9605
           secure_schedd_port = 9607
           multicluster_security = NOT_SET
           ssl_cipher_list = ALL:eNULL:!aNULL
           inbound_hosts = c188f2n02.ppd.pok.ibm.com
           outbound_hosts = c188f2n02.ppd.pok.ibm.com
           exclude_users = loadl(cluster2)
           exclude_groups = april(cluster3)
           include_classes = No_Class
   cluster3: type = cluster
           Local = False
           inbound_schedd_port = 1966
           secure_schedd_port = 9607
           multicluster_security = NOT_SET
           ssl_cipher_list = ALL:eNULL:!aNULL
           inbound_hosts = c94n02.ppd.pok.ibm.com
           outbound_hosts = c94n02.ppd.pok.ibm.com(cluster1)
                            c94n06.ppd.pok.ibm.com(cluster2)
   
           clusterB schedd gateway Version:
           c188f2n08.ppd.pok.ibm.com   3.3.2.5  rmer  2008/01/25 \     
                RHEL  4.0  132

4. This example generates a listing of all of the consumable resources
   associated with all of the machines in the LoadLeveler cluster. 

   llstatus -R
    
   You should receive output similar to the following:
   
   Machine                       Consumable Resource(Available, Total)
   -------------------------     -------------------------------------
   c209f1n01.ppd.pok.ibm.com     ConsumableCpus(4,4)+ ConsumableMemory \
                                  (1.000 gb,1.000 gb) n01_res(123,500)
   c209f1n02.ppd.pok.ibm.com     ConsumableCpus< 0 1 2 3 4>< 0 1 2 3 4 > \ 
                                  n02_res(123,500) Frame5(10,10)
   c209f1n05.ppd.pok.ibm.com     ConsumableCpus(4,4)+ ConsumableMemory \
                                  (1.000 gb,1.000 gb) spice2g6(250,360)
   
   Resources with "+" appended to their names have the Total value 
   reported from Startd.

   Note: The individual CPU ID < > notation will be used to list
         individual CPU IDs instead of the CPU count ( ) notation for
         machines where the RSET_SUPPORT configuration file keyword is
         set to RSET_MCM_AFFINITY or RSET_CONSUMABLE_CPUS. The CPU count
         ( ) notation will be used when the RSET_SUPPORT configuration
         file keyword is set to RSET_USER_DEFINED or RSET_NONE, or if
         this keyword is not specified in the configuration file.

5. This example generates a listing of information related to MCMs of
   machines in the LoadLeveler cluster. 
      
   llstatus -M
    
   You should receive output similar to the following:
    
   Machine               MCM details 
   --------------------- -----------------------------------------------
   c61f2sq01.ppd.pok.ibm.com
                MCM0
                   Available Cpus :< 0-15 >(16)
                   Used Cpus      :< >(0)
                   Adapters       :
                   Total Tasks    :(0)
                MCM1
                   Available Cpus :< 16-29 >(14)
                   Used Cpus      :< 16-27 >(12)
                   Adapters       :sn1[16/16,798/798 rCxt Blks]
                                   sn0[12/16,790/798 rCxt Blks]
                   Total Tasks    :(4)
               
   c61f2sq02.ppd.pok.ibm.com
                MCM0
                   Available Cpus :< 0-1 >(2)
                   Used Cpus      :< >(0)
                   Adapters       :
                   Total Tasks    :(0)
                MCM1
                   Available Cpus :< 2-3 >(2)
                   Used Cpus      :< >(0)
                   Adapters       :
                   Total Tasks    :(0)
     

   Note: The -M option will list the MCM information only when the
         RSET_SUPPORT configuration file keyword is set to
         RSET_MCM_AFFINITY.

6. This example generates a listing of all of the floating consumable
   resources associated with all of the machines in the LoadLeveler
   cluster. This option should not be specified with any other option.
   
   llstatus -F
    
   You should receive output similar to the following:
    
   Floating Resource              Available     Total          
   ------------------------------ ------------- ---------------
   EDA_licenses                   20            29           
   Frame5                         15            20           
   WorkBench6                     5             7            
   XYZ_software                   6             6            

7. This example generates a customized and formatted standard listing.    

   llstatus -f %n %scs %inq %m %v %sts %l %o
    
   You should receive output similar to the following:
   
   Name             Schedd  InQ  Memory  FreeVMemory Startd LdAvg  OpSys
   ll5.pok.ibm.com  Avail   0    128     22708       Run    0.23   AIX53
   ll6.pok.ibm.com  Avail   3    224     16732       Run    0.51   AIX53
   
   R6000/AIX53             2 machines      3  jobs      3  running tasks
   Total Machines          2 machines      3  jobs      3  running tasks
   
   The Central Manager is defined on ll5.pok.ibm.com
   
   The BACKFILL scheduler is in use
   
   All machines on the machine_list are present.

8. This example generates a customized and unformatted (raw) standard
   listing. 

   Customized, Unformatted Standard Listing: A customized Output fields
   are separated by an exclamation point (!).
    
   llstatus -r %n %scs %inq %m %v %sts %l %o
    
   You should receive output similar to the following:
    
   ll5.pok.ibm.com!Avail!0!128!22688!Running!0.14!AIX53
   ll6.pok.ibm.com!Avail!3!224!16668!Running!0.37!AIX53

9. This example generates a listing containing information about the
   status of adapters associated with all of the machines in the
   LoadLeveler cluster: 

   llstatus -a
   
   You should receive output similar to the following:
    
   c271f2rp02.ppd.pok.ibm.com
   ml0(multilink,c271f2san02.ppd.pok.ibm.com,10.10.10.6,)
   networks(striped,c271f2san02.ppd.pok.ibm.com,10.10.10.6,,-1, \
            500/512,1474/1596 rCxt Blks,1,READY)
   network1(aggregate,,,10.10.10.6,-1,500/512,500M/512M,1,READY)
     sn0(switch,c271f2s0n02.ppd.pok.ibm.com,192.168.0.6,10.10.10.6,2, \
         250/256,737/798 rCxt Blks,1,READY,MCM0)
     sn1(switch,c271f2s1n02.ppd.pok.ibm.com,192.168.1.6,10.10.10.6,0, \
         250/256,737/798 rCxt Blks,1,READY,MCM0)
   en0(ethernet,c271f2rp02.ppd.pok.ibm.com,9.114.175.82,)
    
   *  For a switch adapter, the information format is: 

      adapter_name(network_type, interface_name, interface_address, 
      multilink_address, switch_node_number or adapter_logical_id, 
      available_adapter_windows/total_adapter_windows, 
      unused rCxt blocks/total rCxt blocks, adapter_fabric_connectivity, 
      adapter_state[,adapter mcm id])

   *  For non-switch adapters, the format is: 

      adapter_name(network_type, interface_name, interface_address, 
      multilink_address)

   *  For InfiniBand, this example displays the port number on each
      InfiniBand adapter. The llstatus command does not show port
      information for adapters that are not InfiniBand adapters: 

      llstatus -a
       
      You should receive output similar to the following:
       
      ==================================================================
      c171f6sq08.ppd.pok.ibm.com
      ehca0(InfiniBand,,,,-1,0/0,0/0 rCxt Blks,101,READY)
      eth0(ethernet,c171f6sq08.ppd.pok.ibm.com,9.114.136.59,)
      network1833865768265265971s(striped,,,,-1,64/64,0/0 \ 
         rCxt Blks,101,READY)
      network18338657682652659714(aggregate,,,,-1,64/64,0/0 \ 
         rCxt Blks,1,READY)
      ib1(InfiniBand,192.168.9.59,192.168.9.59,,2,64/64,0/0 \ 
         rCxt Blks,1,READY,2)
      network18338657682652659712(aggregate,,,,-1,64/64,0/0 \ 
         rCxt Blks,1,READY)
      ib0(InfiniBand,192.168.8.59,192.168.8.59,,2,64/64,0/0 \ 
         rCxt Blks,1,READY,1)
      
      ==================================================================
      c171f6sq07.ppd.pok.ibm.com
      ehca0(InfiniBand,,,,-1,0/0,0/0 rCxt Blks,101,READY)
      eth0(ethernet,c171f6sq07.ppd.pok.ibm.com,9.114.136.58,)
      network1833865768265265971s(striped,,,,-1,64/64,0/0 \ 
         rCxt Blks,101,READY)
      network18338657682652659714(aggregate,,,,-1,64/64,0/0 \ 
         rCxt Blks,1,READY)
      ib1(InfiniBand,192.168.9.58,192.168.9.58,,1,64/64,0/0 \
         rCxt Blks,1,READY,2)
      network18338657682652659712(aggregate,,,,-1,64/64,0/0 \ 
         rCxt Blks,1,READY)
      ib0(InfiniBand,192.168.8.58,192.168.8.58,,1,64/64,0/0 \ 
         rCxt Blks,1,READY,1)
    
   Note: The adapter MCM ID will be printed only for High Performance
         Switch adapters and only when the RSET_SUPPORT configuration
         file keyword is set to RSET_MCM_AFFINITY. A value of MCM-1 for
         this field means that none of the CPUs from the physical MCM,
         where that adapter is connected to, is part of the machine's
         partition.

10. This example generates a listing containing information about the
    status of the Blue Gene/L system in the LoadLeveler cluster. 

    llstatus -b
    
    You should receive output similar to the following:
    
    Name          Base Partitions  c-nodes    InQ    Run
    BGL           1x2x4            8x16x32    4      1

11. This example generates information for base Blue Gene/L partition
    R010: 

    llstatus -B R010
    
    You should receive output similar to the following:
    
    Base Partition Id: R010
      Base Partition State: UP
      Location: (0,1,0)
      C-node Memory: 1024 mb
      Number of IONodes: 64
      Sub Divided Busy: False
      PartitionState=READY Partition=GPFS_R010

12. This example generates information for Blue Gene/L partition
    GPFS_R010: 

    llstatus -P GPFS_R010
    
    You should receive output similar to the following:
    
    Partition Id: GPFS_R010
      Partition State: READY
      Description: Generated via BlockBuilder
      Owner: apeters
      Users: 
      Connection: TORUS
      Size: 512
      Shape: 1x1x1
      Number of IONodes: 64
      Mode: VIRTUAL_NODE
      MloaderImage: /bgl/BlueLight/ppcfloor/bglsys/bin/mmcs-mloader.rts
      BlrtsImage: /bgl/BlueLight/ppcfloor/bglsys/bin/rts_hw.rts
      LinuxImage: /bgl/BlueLight/ppcfloor/bglsys/bin/zImage.elf
      RamDiskImage: /bgl/BlueLight/ppcfloor/bglsys/bin/ramdisk.elf
      Small Partitions: False
      Base Partition List: R010 
      Switch ID: X_R010
        Switch State: UP
        Base Partition: R010
        Switch Dimension: X
        Switch Connections:
          FromPort=PORT_S0 ToPort=PORT_S1 PartitionState=READY \
	     Partition=GPFS_R010
      Switch ID: Y_R010
        Switch State: UP
        Base Partition: R010
        Switch Dimension: Y
        Switch Connections:
          FromPort=PORT_S0 ToPort=PORT_S1 PartitionState=READY \
	     Partition=GPFS_R010
      Switch ID: Z_R010
        Switch State: UP
        Base Partition: R010
        Switch Dimension: Z
        Switch Connections:
          FromPort=PORT_S0 ToPort=PORT_S1 PartitionState=READY \
	     Partition=GPFS_R010

13. The following example shows output for the llstatus -l command that
    displays the SMT state for the machine: 

    ===================================================================
         Name = devf1n01.clusters.com
      Machine = devf1n01.clusters.com
         Arch = ppc64
        OpSys = Linux2
    .
    .
    .
      Feature = SMT
    .
    .
          SMT = Enabled | Disabled | Not Supported
    TimeStamp = Fri 25 Jan 2008 04:44:06 PM CST
    .
    .
    .  

14. This example generates a listing containing information about the
    status of the Blue Gene/P system in the LoadLeveler cluster. 

    llstatus -b
    
    You should receive output similar to the following:
    
    Name          Base Partitions  c-nodes    InQ    Run
    BGP           4x1x2            32x8x16    0      0

15. This example generates information for base Blue Gene/P partition
    R001: 

    llstatus -B R001
    
    You should receive output similar to the following:
    
    Base Partition Id: R00-M0
      Base Partition State: UP
      Location: (0,0,0)
      C-node Memory: 2048 mb
      Number of IONodes: 32
      Sub Divided Busy: True
      Node Card List:
        NodeCardId=N00      NodeCardState=UP    Quarter=Q1 \
	   PartitionState=NONE Partition=NONE
        NodeCardId=N01      NodeCardState=UP    Quarter=Q1 \ 
	   PartitionState=READY Partition=R00-M0-N01
        NodeCardId=N02      NodeCardState=UP    Quarter=Q1 \ 
	   SubDividedBusy=True 
          IONodeId=J00      IPAddress=172.16.103.5 \    
	     PartitionState=READY Partition=R00-M0-N02-J00 
          IONodeId=J01      IPAddress=172.16.103.6 \    
	     PartitionState=READY Partition=R00-M0-N02-J01 
        NodeCardId=N03      NodeCardState=UP    Quarter=Q1 \ 
	   SubDividedBusy=True 
          IONodeId=J00      IPAddress=172.16.103.7 \    
	     PartitionState=NONE Partition=NONE 
          IONodeId=J01      IPAddress=172.16.103.8 \    
	     PartitionState=READY Partition=R00-M0-N03-J01
        NodeCardId=N04      NodeCardState=UP    Quarter=Q2 \ 
	   SubDividedBusy=True
          IONodeId=J00      IPAddress=172.16.103.9 \    
	     PartitionState=READY Partition=R00-M0-N04-J00
          IONodeId=J01      IPAddress=172.16.103.10 \   
	     PartitionState=NONE Partition=NONE
        NodeCardId=N05      NodeCardState=UP    Quarter=Q2 \ 
	   PartitionState=NONE Partition=NONE
        NodeCardId=N06      NodeCardState=UP    Quarter=Q2 \ 
	   SubDividedBusy=True
          IONodeId=J00      IPAddress=172.16.103.13 \   
	     PartitionState=READY Partition=R00-M0-N06-J00
          IONodeId=J01      IPAddress=172.16.103.14 \   
	     PartitionState=NONE Partition=NONE
        NodeCardId=N07      NodeCardState=UP    Quarter=Q2 \ 
	   PartitionState=NONE Partition=NONE
        NodeCardId=N08      NodeCardState=UP    Quarter=Q3 \ 
	   PartitionState=READY Partition=R00-M0-N08-32
        NodeCardId=N09      NodeCardState=UP    Quarter=Q3 \ 
	   PartitionState=READY Partition=R00-M0-N09
        NodeCardId=N10      NodeCardState=UP    Quarter=Q3 \
	   SubDividedBusy=True
          IONodeId=J00      IPAddress=172.16.103.21 \   
	     PartitionState=READY Partition=R00-M0-N10-J00
          IONodeId=J01      IPAddress=172.16.103.22 \   
	     PartitionState=READY Partition=R00-M0-N10-J01
        NodeCardId=N11      NodeCardState=UP    Quarter=Q3 \ 
	   PartitionState=NONE Partition=NONE
        NodeCardId=N12      NodeCardState=UP    Quarter=Q4 \ 
	   SubDividedBusy=True
          IONodeId=J00      IPAddress=172.16.103.25 \   
	     PartitionState=READY Partition=R00-M0-N12-J00
          IONodeId=J01      IPAddress=172.16.103.26 \   
	     PartitionState=READY Partition=R00-M0-N12-J01
        NodeCardId=N13      NodeCardState=UP    Quarter=Q4 \ 
	   PartitionState=READY Partition=R00-M0-N13
        NodeCardId=N14      NodeCardState=UP    Quarter=Q4 \ 
	   PartitionState=NONE Partition=NONE
        NodeCardId=N15      NodeCardState=UP    Quarter=Q4 \ 
	   SubDividedBusy=True
          IONodeId=J00      IPAddress=172.16.103.31 \   
	     PartitionState=READY Partition=R00-M0-N15-J00
          IONodeId=J01      IPAddress=172.16.103.32 \   
	     PartitionState=NONE Partition=NONE

16. This example generates information for Blue Gene/P partition
    R00-M0-N08-32: 

    llstatus -P R00-M0-N08-32
    
    You should receive output similar to the following:
    
    Partition Id: R00-M0-N08-32
      Partition State: READY
      Description: Generated via BlockBuilder
      Owner: mmundy
      Users: 
      Connection: MESH
      Size: 32
      Shape: 0x0x0
      Number of IONodes: 2
      IONodes / Base Partition: N08-J00 N08-J01 
      MloaderImage: /bgsys/drivers/ppcfloor/boot/uloader
      CnLoadImage: /bgsys/drivers/ppcfloor/boot/cns,/bgsys/drivers \
         /ppcfloor/boot/cnk
      IoLoadImage: /bgsys/drivers/ppcfloor/boot/cns,/bgsys/drivers \
         /ppcfloor/boot/linux,/bgsys/drivers/ppcfloor/boot/ramdisk 
      Small Partitions: True
      Base Partition List: R00-M0 
      Node Card List: N08 

Security

LoadLeveler administrators and users can issue this command.
