
llsubmit - Submit a job

Purpose

llsubmit - Submits a job to LoadLeveler to be dispatched based upon job
requirements in the job command file.

Syntax

llsubmit [-H] [-?] [-v] [-q] [-X {cluster_list | any}] [cmdfile | - ]

Flags

-? 
   Provides a short usage message.

-H 
   Provides extended help information.

-v 
   Displays the name of the command, release number, service level,
   service level date, and lowest level of the operating system to run
   this release.

-q 
   Specifies quiet mode: print no messages other than error messages.

-X {cluster_list | any}
   Is a blank-delimited list of cluster names or the reserved word any
   where: 
   *  A single cluster name indicates that the job is to be submitted to
      that cluster.
   *  A list of multiple cluster names indicates that the job is to be
      submitted to one of the clusters as determined by the installation
      exit CLUSTER_METRIC.
   *  The reserved word any indicates the job is to be submitted to any
      cluster defined by the installation exit CLUSTER_METRIC.
    
   If a cluster_list is specified with the -X option on the llsubmit
   command, the specified cluster_list takes precedence over any
   cluster_list statements already specified in the job command file.

cmdfile
   Is the name of the job command file containing LoadLeveler commands.

-  Specifies that LoadLeveler commands that would normally be in the job
   command file are read from stdin. When entry is complete, press
   Ctrl-D to end the input.

Description

*  Users with uid or gid equal to 0 are not allowed to issue the
   llsubmit command.

*  When a LoadLeveler job ends, you may receive UNIX mail notification
   indicating the job exit status. For example, you could get the
   following mail message: 

   Your LoadLeveler job
   myjob1
   exited with status 139.
   
   The return code 139 is from the user's job, and is not a LoadLeveler
   return code.

*  For information on writing a program to filter job scripts, see the
   "Filtering a job script" topic in TWS LoadLeveler: Using and
   Administering.

*  The llsubmit command will display an error and fail to submit the job
   if the resources keyword in the job command file does not match the
   resources to be enforced and LoadLeveler is set to check for the
   resources specification. For more information, see the "Defining
   usage policies for consumable resources" topic in TWS LoadLeveler:
   Using and Administering.

*  If the LL_RES_ID environment variable is set, the llsubmit command
   will set the requested reservation ID of the submitted job steps
   using the value of the LL_RES_ID environment variable. When the
   central manager receives the job steps from the Schedd, it will bind
   the job steps to a specified reservation. If the job steps cannot be
   bound to the reservation, they will be placed in the NotQueued state
   and the requested reservation ID will keep the same value. If the
   value of LL_RES_ID is set to blank, it will be treated as if it were
   unset. The value for the ll_res_id job command file keyword overrides
   the value for the LL_RES_ID environment variable.

*  If you want to submit a job to run on a specific type of machine (for
   example, one with Arch = i386 and OpSys= Linux2), you must specify a
   requirements statement that includes the Arch and OpSys requirements.

*  In a multicluster environment, job identifiers are assigned by the
   local cluster and are retained by the job regardless of what cluster
   the job runs in. 

   If the job was submitted as a remote job in a multicluster
   environment, the host represented in host.jobid.stepid, is the name
   of the local Schedd machine that assigned the jobid. To determine the
   managing Schedd machine, issue the llq -l command to obtain the
   Schedd Host field.
  
   If the administrator has not defined a CLUSTER_METRIC for the local
   cluster, the llsubmit command will display an error and fail to
   submit the job if the user specifies the -X flag with a cluster_list
   or the reserved word any. The llsubmit command will also display an
   error and fail to submit the job if the user specifies the -X
   cluster_name in the following instances:
    
   *  The local cluster is not in the multicluster environment
   *  The specified cluster name is not configured
   *  The specified cluster name does not have inbound_hosts specified

Examples

1. This example shows a job command file named qtrlyrun.cmd is
   submitted: 

   llsubmit qtrlyrun.cmd

2. This example shows a job being submitted to a remote cluster: 

   llsubmit -X cluster1 jcf.cmd 

Results

1. The following shows the results of the llsubmit qtrlyrun.cmd command
   issued from the machine earth: 

   llsubmit: The job "earth.505" has been submitted.
    
   Note that 505 is the job ID generated by LoadLeveler.

2. The following shows the results from a remote submit: 

   Job c188f2n08.ppd.pok.ibm.com.21 assigned to local outbound \
                              Schedd c188f2n08.ppd.pok.ibm.com.
   Job c188f2n08.ppd.pok.ibm.com.21 assigned to remote inbound \
                              Schedd c188f2n02.ppd.pok.ibm.com.
   Job c188f2n08.ppd.pok.ibm.com.21 has been submitted to cluster \ 
      "cluster1"
   llsubmit: The job "c188f2n08.ppd.pok.ibm.com.21" has been submitted.

Related Information

Subroutines: llsubmit

Security

LoadLeveler administrators and users can issue this command.
