#!/bin/ksh
#
# this is an example of a self-checkpointing shell script.  It assumes your
# computation can be broken into a series of steps.  At the end of each step
# the results achieved so far are saved and a "mark" is made to indicate how
# far we have gone so far.
# 
# a job like this can be evicted any number of times by LoadLeveler 
# with only small amounts of work actually wasted.
#
# stdout messages will be in job2.output.
# stderr messages will be in job2.output.

#    Note that this particular job writes is "real" output to the file
# job2.results
#
# You must edit the next line to run this command file
#
# @ initialdir = /u/changeme/tests
# @ error 	 = job2.error
# @ output 	 = job2.output
# @ queue

outputfile=job2.results
checkpointfile=job2.checkpoint
integer currentstep=1 currentsubstep=6
integer number_of_steps=2
integer number_of_substeps=6	

#
# if the checkpoint file exists this is a restart. otherwise init the checkpoint
# file with "1" for "first step"
#
if [ ! -f $checkpointfile ] 
then
	echo "1 1" > $checkpointfile
	let currentstep=1
	let currentsubstep=1
	rm $outputfile				
else
	restart="true"
	set `cat $checkpointfile`
	currentstep=$1 
	currentsubstep=$2
fi

#
# extract current step from the checkpoint file
#

while (( currentstep <= number_of_steps ))
do
	if [ "$restart" = "true" ]
	then

		echo `date` `hostname`
		echo "restarting step $currentstep substep $currentsubstep" >> $outputfile
	else
		echo `date` `hostname`
		echo "starting step $currentstep substep $currentsubstep" >> $outputfile
	fi
	unset restart

	case $currentstep in
		1) 
			while (( currentsubstep <= number_of_substeps ))
			do 
				echo step $currentstep, substep $currentsubstep >> $outputfile
				sleep 5
				currentsubstep=currentsubstep+1
				echo $currentstep $currentsubstep > $checkpointfile
			done 
			currentstep=currentstep+1
			echo $currentstep $currentsubstep > $checkpointfile
			echo "-------------- completed major checkpoint 1 " >> $outputfile
			currentsubstep=1
			;;
		*)
			while (( currentsubstep <= number_of_substeps ))
			do
				echo step $currentstep, substep $currentsubstep >> $outputfile
				sleep 5
				currentsubstep=currentsubstep+1
				echo $currentstep $currentsubstep > $checkpointfile
			done
			currentstep=currentstep+1
			echo $currentstep > $checkpointfile
			echo "------------- completed major checkpoint 2 " >> $outputfile
			;;
	esac
done

#
# if we get here all is ok and the checkpoint file dies
#
rm $checkpointfile
