/*
 * ----------------------------------------------------------------------------
 * This sample program shows how LoadLeveler's Data Access API can be used
 * to create a cluster metric that returns the best cluster based on the 
 * number of jobs in a certain class.
 * ----------------------------------------------------------------------------
 */
/*@(#) filename, component, release, file version, date changed */
static char sccsid[] = "@(#) src/ll/samples/llcluster/cluster_metric_jobs_in_class.c, ll.api, ll_rjup, rjup0809b 1.2 12/2/04";

#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include <values.h>
#include "llapi.h"

main(int argc, char *argv[])
{
	LL_element *job=NULL, *step=NULL;
	LL_element *queryObject=NULL, *mcluster=NULL;
	LL_element *errObj=NULL;
	LL_cluster_param cluster;
	char **class_list = NULL;
	char **job_list = NULL;
	char *job_id = NULL;
	char *chosen_cluster = NULL;
	char *cluster_name = NULL;
	char *job_class = NULL;
	char *job_class2 = NULL;
	char **cluster_list = NULL;
	int number_of_cluster_params = 0;
	int search_any = 0; 	
	int min_class_jobs = MAXINT;
	int num_of_class_jobs = 0;
	int valid_query = 0;
	int rc = 0, num = 0, err = 0;
	int i = 0, j = 0;

	/* Get the hostname of this machine */
	char hname[256];
        gethostname(hname,256);

	/* Process cluster metric arguments from LoadLeveler */

	/* Job id to be processed */
	job_id = strdup(argv[1]);

	/* Number of clusters passed in as parameters */
	number_of_cluster_params = atoi(argv[2]);

	/* Get the cluster list to use for metric selection */
	cluster_list=(char **)calloc(number_of_cluster_params,sizeof(char *));	
	j = 0;
	for (i=3; i <= number_of_cluster_params+2; i++) {
		cluster_list[j] = strdup(argv[i]);
		if(!strcmp(cluster_list[j],"any")) {
			search_any = 1;
		}
		j++;
	}

	/* if the reserved word "any" was indicated, go and obtain the
	   remote clusters that are configured for the local cluster */
	if ( search_any ) {
		/* Free existing cluster list */
		for(i=0; i < number_of_cluster_params; i++) {
			free(cluster_list[i]);
		}
		free(cluster_list);

		/* Initialize the query for MClusters */
        	queryObject = ll_query(MCLUSTERS);

        	rc = ll_set_request(queryObject,QUERY_ALL,NULL,ALL_DATA);

        	/* Request the objects from the Schedd daemon */
        	mcluster = ll_get_objs(queryObject,LL_SCHEDD,NULL,&num,&err);

		/* Malloc cluster_list according to the number of mclusters */
		cluster_list=(char **)calloc(num,sizeof(char *));	
		i = 0;

        	/* Did we get a list of objects ? */
        	if (mcluster == NULL) {
			fprintf(stderr,"cluster_metric_job_class: Unable to obtain cluster objects for metric request of \"any\".\n");
			free(job_id);
			free(cluster_list);
			exit(-1);
        	} else {
                	/* Loop through the list and process */
			while(mcluster) {
                        	if (ll_get_data(mcluster, LL_MClusterName, &cluster_name)==0) {
                                	if (cluster_name) {
                                        	cluster_list[i++] = strdup(cluster_name);
                                        	free(cluster_name);
                                        	cluster_name=NULL;
                                	}
                        	}
     				mcluster = ll_next_obj(queryObject);
                	}
        	}

        	/* free objects obtained from Negotiator */
        	rc = ll_free_objs(queryObject);

        	/* free query element */
        	rc = ll_deallocate(queryObject);

		number_of_cluster_params = i;
	}

	/* Get the job class for the specified job */
	job_list=(char **)calloc(2,sizeof(char *));	

	job_list[0] = job_id;
	job_list[1] = NULL;

	queryObject = ll_query(JOBS);

   	rc = ll_set_request(queryObject,QUERY_JOBID,job_list,ALL_DATA);

	job = ll_get_objs(queryObject, LL_SCHEDD, hname, &num, &err);
   	if (job) {
      		ll_get_data(job, LL_JobGetFirstStep, &step);
      		if (step) {
         		rc = ll_get_data(step, LL_StepJobClass, &job_class);
		}
   	}
	else {
		fprintf(stderr, "cluster_metric_job_class: Could not obtain job %s from Schedd.\n",job_id);
		/* Free existing cluster list */
		for(i=0; i < number_of_cluster_params; i++) {
			free(cluster_list[i]);
		}
		free(cluster_list);
		free(job_list);
		free(job_id);
		exit(-1);
	}
   	ll_free_objs(queryObject);
   	ll_deallocate(queryObject);

	class_list=(char **)calloc(2,sizeof(char *));	

	class_list[0] = job_class;
	class_list[1] = NULL;
	
	/* Query each cluster to get the number of jobs in job_class */
	cluster.cluster_list = (char **)calloc(2,sizeof(char *));

	if(cluster_list[0]) {
		/* default chosen_cluster to first in the list */
		chosen_cluster = cluster_list[0];
	}

	for (i=0; i<number_of_cluster_params; i++) {
		cluster.cluster_list[0] = cluster_list[i];
        	cluster.cluster_list[1] = NULL;
        	cluster.action = CLUSTER_SET;

		rc = ll_cluster(LL_API_VERSION,&errObj,&cluster);

		queryObject = ll_query(JOBS);

   		rc = ll_set_request(queryObject,QUERY_CLASS,class_list,ALL_DATA);

		job = ll_get_objs(queryObject, LL_CM, NULL, &num, &err);
		if ( err == 0 || err == -6 ) {
			valid_query = 1;
		}
	
   		while(job) {
      			ll_get_data(job, LL_JobGetFirstStep, &step);
      			while(step) {
         			rc = ll_get_data(step, LL_StepJobClass, &job_class2);
         			if (!rc) {
            				if (!strcmp(job_class,job_class2)) {
						num_of_class_jobs++;
						
            				}
				}
         			ll_get_data(job, LL_JobGetNextStep, &step);
      			}
      			job = ll_next_obj(queryObject);
   		}
   		ll_free_objs(queryObject);
   		ll_deallocate(queryObject);

		cluster.action = CLUSTER_UNSET;
		rc = ll_cluster(LL_API_VERSION,&errObj,&cluster);

		if (valid_query) {
			if (num_of_class_jobs < min_class_jobs) {
				min_class_jobs = num_of_class_jobs;
				chosen_cluster = cluster_list[i];
			}
			num_of_class_jobs = 0;
		}
		valid_query = 0;
	}
	fprintf(stdout,"%s", chosen_cluster);

	/* Free cluster list */
	for(i=0; i < number_of_cluster_params; i++) {
		free(cluster_list[i]);
	}
	free(cluster_list);
	/* Free job list */
	for(i=0; i < 2; i++) {
		free(job_list[i]);
	}
	free(job_list);
	/* Free class list */
	for(i=0; i < 2; i++) {
		free(class_list[i]);
	}
	free(class_list);
	free(job_id);
	exit(0);
}

