/*
 * ---------------------------------------------------------------------------------
 * This sample program shows how LoadLeveler's Data Access API can be used
 * to obtain accounting information stored in a LoadLeveler "history" file.
 *
 * Note: The file name /tmp/test1/history used in this program must be replaced
 *       by the name of your history file.
 * ---------------------------------------------------------------------------------
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "llapi.h"
#define  STR_NULL(ptr) (ptr ? ptr : "")

main(int argc, char *argv[])
{
	LL_element *queryObject, *job = NULL, *step = NULL;
	LL_element *mach_usage = NULL, *disp_usage = NULL, *event_usage = NULL;
	int64_t int64_data;
	int rc, obj_count, err_code, job_count, step_count, int_data;
	char *str_data;
	char *start_dates[] = { "06/23/2001", "07/25/2005", NULL };
	char *end_dates[]   = { "06/23/2001", "07/25/2005", NULL };
	int mach_usage_count, disp_usage_count, event_usage_count;

	/* Initialize the query: Job query  */
	queryObject = ll_query(JOBS);
	if (!queryObject) { printf("Query JOBS: ll_query() returns NULL.\n"); exit(1); }

	/* Request information of job steps started/ended between certain dates. */
	rc = ll_set_request(queryObject, QUERY_STARTDATE, start_dates, ALL_DATA);
	if (rc) { printf("ll_set_request() - QUERY_STARTDATE -  RC = %d\n", rc); exit(1); }
	rc = ll_set_request(queryObject, QUERY_ENDDATE, end_dates, ALL_DATA);
	if (rc) { printf("ll_set_request() - QUERY_ENDDATE -  RC = %d\n", rc); exit(1); }

	/* Get the requested job objects from the specified history file. */
	job = ll_get_objs(queryObject, LL_HISTORY_FILE,
		"/tmp/test1/history", &obj_count, &err_code);
	if (!job) { printf("ll_get_objs() returns NULL. Error code = %d\n", err_code); exit(1); }

	printf("*************************************************\n");
	printf("Number of job objects returned = %d\n", obj_count);
	printf("*************************************************\n");

	/* Loop through the job objects. */
	job_count = 0;
	while (job) {
		job_count++;
		printf("===========================================================\n");
		printf("Job number = %d\n", job_count);

		/* Loop through the job step objects. */
		ll_get_data(job, LL_JobGetFirstStep, &step);
		step_count = 0;
		while (step) {
			step_count++;
			printf("     ======================================================\n");
			printf("     Step number = %d\n", step_count);
			ll_get_data(step, LL_StepID, &str_data);
			printf("     LL_StepID                  = %s\n", STR_NULL(str_data));
			ll_get_data(step, LL_StepImageSize, &int_data);
			printf("     LL_StepImageSize           = %d\n", int_data);
			ll_get_data(step, LL_StepImageSize64, &int64_data);
			printf("     LL_StepImageSize64         = %lld\n", int64_data);

			/* CPU limit */
			ll_get_data(step, LL_StepCpuLimitHard, &int_data);
			printf("     LL_StepCpuLimitHard        = %d\n", int_data);
			ll_get_data(step, LL_StepCpuLimitHard64, &int64_data);
			printf("     LL_StepCpuLimitHard64      = %lld\n", int64_data);
			ll_get_data(step, LL_StepCpuLimitSoft, &int_data);
			printf("     LL_StepCpuLimitSoft        = %d\n", int_data);
			ll_get_data(step, LL_StepCpuLimitSoft64, &int64_data);
			printf("     LL_StepCpuLimitSoft64      = %lld\n", int64_data);

			/* Job Step CPU limit */
			ll_get_data(step, LL_StepCpuStepLimitHard64, &int64_data);
			printf("     LL_StepCpuStepLimitHard64  = %lld\n", int64_data);
			ll_get_data(step, LL_StepCpuStepLimitSoft64, &int64_data);
			printf("     LL_StepCpuStepLimitSoft64  = %lld\n", int64_data);

			/* Data Limit */
			ll_get_data(step, LL_StepDataLimitHard64, &int64_data);
			printf("     LL_StepDataLimitHard64     = %lld\n", int64_data);
			ll_get_data(step, LL_StepDataLimitSoft64, &int64_data);
			printf("     LL_StepDataLimitSoft64     = %lld\n", int64_data);

			/* As Limit */
			ll_get_data(step, LL_StepAsLimitHard64, &int64_data);
			printf("     LL_StepAsLimitHard64     = %lld\n", int64_data);
			ll_get_data(step, LL_StepAsLimitSoft64, &int64_data);
			printf("     LL_StepAsLimitSoft64     = %lld\n", int64_data);

			/* Nproc Limit */
			ll_get_data(step, LL_StepNprocLimitHard64, &int64_data);
			printf("     LL_StepNprocLimitHard64  = %lld\n", int64_data);
			ll_get_data(step, LL_StepNprocLimitSoft64, &int64_data);
			printf("     LL_StepNprocLimitSoft64  = %lld\n", int64_data);
	
			/* Memlock Limit */
			ll_get_data(step, LL_StepMemlockLimitHard64, &int64_data);
			printf("     LL_StepMemlockLimitHard64     = %lld\n", int64_data);
			ll_get_data(step, LL_StepMemlockLimitSoft64, &int64_data);
			printf("     LL_StepMemlockLimitSoft64     = %lld\n", int64_data);

			/* Locks Limit */
			ll_get_data(step, LL_StepLocksLimitHard64, &int64_data);
			printf("     LL_StepLocksLimitHard64     = %lld\n", int64_data);
			ll_get_data(step, LL_StepLocksLimitSoft64, &int64_data);
			printf("     LL_StepLocksLimitSoft64     = %lld\n", int64_data);
			
			/* Nofile Limit */
			ll_get_data(step, LL_StepNofileLimitHard64, &int64_data);
			printf("     LL_StepNofileLimitHard64     = %lld\n", int64_data);
			ll_get_data(step, LL_StepNofileLimitSoft64, &int64_data);
			printf("     LL_StepNofileLimitSoft64     = %lld\n", int64_data);

			/* CPU time used by the job step. */
			ll_get_data(step, LL_StepStepUserTime64, &int64_data);
			printf("     LL_StepStepUserTime64      = %lld (microsecs)\n", int64_data);
			ll_get_data(step, LL_StepStepSystemTime64, &int64_data);
			printf("     LL_StepStepSystemTime64    = %lld (microsecs)\n", int64_data);

			/* Loop through the machine usage objects. */
			/* A parallel job step run on 3 machines typically has 3 machine usage objects. */
			mach_usage_count = 0;
			rc = ll_get_data(step, LL_StepGetFirstMachUsage, &mach_usage);
			while (mach_usage) {
				mach_usage_count++;
				printf("     ------------------------------------------------------\n");
				printf("     Machine Usage number       = %d\n", mach_usage_count);
				ll_get_data(mach_usage, LL_MachUsageMachineName, &str_data);
				printf("     Machine name               = %s\n", STR_NULL(str_data));

				/* Loop through the dispatch usage objects. */
				/* Unless the job is restarted, there is usually 1 dispatch usage object. */
				disp_usage_count = 0;
				ll_get_data(mach_usage, LL_MachUsageGetFirstDispUsage, &disp_usage);
				while (disp_usage) {
					disp_usage_count++;
					printf("        ---------------------------------------------------\n");
					printf("        Dispatch Usage number        = %d\n", disp_usage_count);

					ll_get_data(disp_usage, LL_DispUsageStepUserTime64, &int64_data);
					printf("        LL_DispUsageStepUserTime64   = %lld (microsecs)\n", int64_data);
					ll_get_data(disp_usage, LL_DispUsageStepSystemTime64, &int64_data);
					printf("        LL_DispUsageStepSystemTime64 = %lld (microsecs)\n", int64_data);

					/* Loop through the event usage objects. */
					/* Each dispatch typically has 2 events: "started" and "completed". */
					/* There may be other events if the LL administrator executes the command */
					/* "llctl -g capture <user event name>" while the job is running.         */
					event_usage_count = 0;
					ll_get_data(disp_usage, LL_DispUsageGetFirstEventUsage, &event_usage);
					while (event_usage) {
						event_usage_count++;
						printf("           ------------------------------------------------\n");
						printf("           Event Usage number            = %d\n", event_usage_count);
						ll_get_data(event_usage, LL_EventUsageEventName, &str_data);
						printf("           LL_EventUsageEventName        = %s\n", STR_NULL(str_data));
						ll_get_data(event_usage, LL_EventUsageStepUserTime64, &int64_data);
						printf("           LL_EventUsageStepUserTime64   = %lld (microsecs)\n", int64_data);
						ll_get_data(event_usage, LL_EventUsageStepSystemTime64, &int64_data);
						printf("           LL_EventUsageStepSystemTime64 = %lld (microsecs)\n", int64_data);
						event_usage = NULL;
						ll_get_data(disp_usage, LL_DispUsageGetNextEventUsage, &event_usage);
					}
					disp_usage = NULL;
					ll_get_data(mach_usage, LL_MachUsageGetNextDispUsage, &disp_usage);
				}
				mach_usage = NULL;
				rc = ll_get_data(step, LL_StepGetNextMachUsage, &mach_usage);
			}
			step = NULL;
			ll_get_data(job, LL_JobGetNextStep, &step);
		}
		job = ll_next_obj(queryObject);
	}
	exit(0);
}

