/*======================================================================*/
/*                                                                      */
/* Module Name: topdog.c                                                */
/*                                                                      */
/*----------------------------------------------------------------------*/
/*                                                                      */
/* Description: This sample program uses the Data Access API to         */
/* obtain information about top dog steps in the cluster.               */
/*                                                                      */
/*======================================================================*/
static char topdog_sccsid[] = "@(#) src/ll/samples/lldata_access/topdog.c, ll.api, ll_rjup, rjup0809b 1.2 6/22/07";

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include "llapi.h"

main(int argc, char *argv[])
{
   LL_element *queryObject;
   LL_element *job, *step, *credential;
   int rc=0, obj_count=0, err_code=0, value=0;
   char *name, *step_id;
   int q_sysprio = 0;
   time_t considered_at;
   time_t start_time;
   int is_top_dog;

   /* Initialize the query: Job query  */
   queryObject = ll_query(JOBS);
   if (!queryObject) {
      printf("Query JOBS: ll_query() returns NULL.\n");
      exit(1);
   }

   /* Query all job steps which are top dogs in the cluster at the present time */
   rc = ll_set_request(queryObject, QUERY_TOP_DOG, NULL, ALL_DATA);
   if (rc) {printf("Query JOBS: ll_set_request() return code is non-zero.\n"); exit(1);}

   /* Get the requested job objects from the Central Manager */
   job = ll_get_objs(queryObject, LL_CM, NULL, &obj_count, &err_code);
   if (job == NULL || obj_count == 0) {
      printf("There are no top dogs at this time.\n");
      exit(0);
   }

   /*  Process the job objects and display selected information of each job step.
    *
    *  Notes:
    *    1. Since LL_element is defined as "void" in llapi.h, when using
    *       ll_get_data it is important that a valid "specification" parameter
    *       be used for a given "element" argument.
    *    2. Checking of return code is not always made in the following loop to
    *       minimize the length of the listing.
    */

   printf("Step                               Owner      q_sysprio  Estimated Start Time\n");
   printf("---------------------------------- ---------- ---------- ------------------------\n");
   while(job) {

      rc = ll_get_data(job, LL_JobCredential, &credential);
      if (!rc) {
         rc = ll_get_data(credential, LL_CredentialUserName, &name);
      }
      step = NULL;
      ll_get_data(job, LL_JobGetFirstStep, &step);
      while(step) {
         rc = ll_get_data(step, LL_StepID, &step_id);
         rc = ll_get_data(step, LL_StepQueueSystemPriority, &q_sysprio);
         rc = ll_get_data(step, LL_StepConsideredAt, &considered_at);
         rc = ll_get_data(step, LL_StepEstimatedStartTime, &start_time);
         rc = ll_get_data(step, LL_StepIsTopDog, &is_top_dog);
         if (!is_top_dog) {
            printf("The step %s is not a top dog? Unbelivable! is_top_dog=%d\n", step_id, is_top_dog);
         }
         printf("%-34s %-10s %-10d %s", step_id, name, q_sysprio, ctime(&start_time));
	 
         free(step_id);
         step = NULL;
         ll_get_data(job, LL_JobGetNextStep, &step);
      }
      free(name);
      job = ll_next_obj(queryObject);
   }
   printf("========= The top dogs were considered for scheduling at %s", ctime(&considered_at));
   ll_free_objs(queryObject);
   ll_deallocate(queryObject);
}
