/*======================================================================*/
/*                                                                      */
/* Module Name: movespool.c                                             */
/*                                                                      */
/*----------------------------------------------------------------------*/
/*                                                                      */
/* Description: This sample program uses the ll_move_spool API to       */
/* move job spool records from a LoadLeveler spool directory for which  */
/* no Schedd is available.                                              */
/*                                                                      */
/*======================================================================*/
static char *movespool_sccsid = "%Z %W %I %G";

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include "llapi.h"

extern char *optarg;

/* movespool:

  -? ==> print usage 
  -d ==> directory where job queue to be transferred resides
  -h ==> hostname where schedd to receive jobs resides

 Exits:  0 - upon success
         1 - upon failure
*/

char *cmdName = "movespool";

int ll_print_job_status(char *,int, LL_element **);

void usage(void) {
	printf("Usage: movespool [-d spool_directory] -h schedd_host\n");
}

main(int argc, char *argv[] ) {
	int opt;
	int rc=0;
	LL_element *errObj = NULL;
	LL_move_spool_param movespool_param;
	LL_move_spool_param *param_list[2];
	int (*func)(char *, int, LL_element **) = ll_print_job_status;

	/* Initialize LL_move_spool_param data members */
	movespool_param.spool_directory = NULL;
	movespool_param.schedd_host = NULL;
	movespool_param.data = (SpoolData_t) -1;

	/* Parsing command line arguments */
	while ( (opt = getopt(argc, argv, "?d:h:")) != EOF) {
		switch (opt) {
		case '?':
			usage();
			exit(0);
		case 'd':     /* spool directory */
			movespool_param.spool_directory = optarg;
			break;
		case 'h':	/* target schedd host */
			movespool_param.schedd_host = (char **)calloc(2,sizeof(char *));
			movespool_param.schedd_host[0] = optarg;
			movespool_param.schedd_host[1] = NULL;
			break;
		default:
			usage();
			exit(1);
		}
	}

	/* check that target schedd was specified */
	if ((movespool_param.schedd_host == NULL) || 
	    (movespool_param.schedd_host[0] == NULL)) {
		fprintf(stderr,"movespool: No schedd hostname was specified.\n");
		usage();
		exit(1);
	}

	/* Default to transferring jobs */
	movespool_param.data = LL_MOVE_SPOOL_JOBS;

	param_list[0] = &movespool_param;
	param_list[1] = NULL;

	rc = ll_move_spool(LL_API_VERSION, param_list, func, &errObj);

	if (rc != API_OK) {
		ll_error(&errObj,1); /* print any message from the API */
	} else {
		fprintf(stdout, "The transfer is complete.\n");
	}

	if (movespool_param.schedd_host != NULL) {
		free(movespool_param.schedd_host);
	}

	if (rc == API_OK) {
		exit(0);
	} else  {
		exit(1);
	}
}

/* This call back function is called by the ll_move_spool API after each 
job is processed. This allows the caller to receive status for each job */
int ll_print_job_status(char *jobid,int rc, LL_element **messageObj) {

	char *msg = NULL;

	if (rc == API_OK) {
		msg = ll_error(messageObj,1);
	} else {
		msg = ll_error(messageObj,2);
	}
	if (msg != NULL) free(msg);

}

