
/* ---------------------------------------------------------------------- */
/* Licensed Materials - Property of IBM                                   */
/*                                                                        */
/* (C) COPYRIGHT International Business Machines Corp. 1993,2004          */
/* All Rights Reserved                                                    */
/*                                                                        */
/* US Government Users Restricted Rights - Use, duplication or            */
/* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      */
/* ---------------------------------------------------------------------- */

#include <stdio.h>
#include <sys/utsname.h>
#include <mpi.h>

main(int argc, char *argv[])
{

/* Structure for returning the task node name */
struct utsname host;
/* Information about our task identity */
int number_of_tasks;
int my_task_number;
int receiver;
int sender = 0;
int msgtype = 0;
int msgid;
int msgrc;
char sending_text[] = {"IVP Message Passing Text"};
int msg_len = strlen(sending_text)+1;  /* include the null */
char receiving_buffer[80];
MPI_Request request;
MPI_Status status;

        MPI_Init(&argc,&argv);  /* initialize MPI environment */
        MPI_Comm_rank(MPI_COMM_WORLD, &my_task_number);
        MPI_Comm_size(MPI_COMM_WORLD, &number_of_tasks);

/* Get the host name */
/* host -> nodename will contain the node name running 
	the task */

	if (uname(&host) < 0) {
		perror("IVP: error in uname\n");
		exit(1);
		}

	printf("IVP: running as task %d on node %s\n",
			my_task_number,host.nodename);
	if (my_task_number == 0) {
		printf("IVP: there are %d tasks running\n", 
				number_of_tasks);
		}

/* Test if we can send messages */

	if (number_of_tasks > 1) {
		if (my_task_number == 0) { /* I'm the sender */
			for (receiver = 1; receiver < number_of_tasks;
					receiver++) {
				msgrc = MPI_Isend(sending_text,msg_len,MPI_CHAR,receiver,
					msgtype,MPI_COMM_WORLD,&request);
				if (msgrc != 0) {
					printf("IVP: MPI_Send failed to task %d\n",
						receiver);
                                        MPI_Abort(MPI_COMM_WORLD, -1);
					}
				}
			printf("IVP: all messages sent\n");
			}
		else { /* I'm the receiver */
			msgrc = MPI_Recv(receiving_buffer,sizeof(receiving_buffer),
				MPI_CHAR,sender,msgtype,MPI_COMM_WORLD,&status);
			printf("IVP: task %3d received <%s>\n",
				my_task_number, receiving_buffer);
			}
		}

/* End of test */

        MPI_Finalize();
	exit(0);
	}
