/*
 * Sample program using the llsubmit interface to submit a job to LoadLeveler.
 *
 * Note: "tracker" must be modified to point to your tracker binary.
 *       The source code of a sample tracker program (tracker.c) 
 *       can be found in the /usr/lpp/LoadL/full/samples/llsub directory
 *       or the /opt/ibmll/LoadL/full/samples/llsub directory.
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "llapi.h"

void display_job_steps(LL_job *);
#define  STR_NULL(ptr) (ptr ? ptr : "NULL")
 
main()
{
	char *job_cmd_file;
	char *tracker;
	char *tracker_arg;
	LL_job job_info;
	int rc;

	/*
	 *	Full path name of the job command file to be submitted
	 */

#if defined(__linux__)
        job_cmd_file = "/opt/ibmll/LoadL/full/samples/job1.cmd";
#else
        job_cmd_file = "/usr/lpp/LoadL/full/samples/job1.cmd";
#endif

	/*
	 *	Full path name of the installation provided tracking program
	 *  which LoadLeveler will invoke when the job changes state
	 *  (e.g. JOB_STARTED, JOB_COMPLETED).
	 */

	tracker = "/tmp/lltest/tracker";

	/*
	 *	Installation defined argument which will be passed to the
	 *  the tracking program
	 */
	tracker_arg = "String to be passed to tracker";

	/*
	 *	Submit the job
	 */
	rc = llsubmit(job_cmd_file, tracker, tracker_arg, &job_info,
								LL_JOB_VERSION);

	printf("Return code of llsubmit, rc = %d\n",rc);

	if (rc != 0) {
		return(rc);
	}

	display_job_steps(&job_info);

	/*
	 *  Free up the space allocated by llsubmit
	 */
	llfree_job_info(&job_info,LL_JOB_VERSION);
}

void display_job_steps(LL_job *jobp)
{
	int i;

	printf("Job name = %s\n",STR_NULL(jobp->job_name));
	printf("Owner = %s\n",STR_NULL(jobp->owner));
	printf("UID = %d\n",jobp->uid);
	printf("GID = %d\n",jobp->gid);
	printf("Job steps = %d.\n",jobp->steps);
	for (i=0; i<jobp->steps; i++) {
		printf("\nJob ID = %s.%d.%d\n",
			jobp->step_list[i]->id.from_host,
			jobp->step_list[i]->id.cluster, 
			jobp->step_list[i]->id.proc);

		printf("Step name = %s\n", STR_NULL(jobp->step_list[i]->step_name));
		printf("Stdin = %s\n", STR_NULL(jobp->step_list[i]->in));
		printf("Stdout = %s\n", STR_NULL(jobp->step_list[i]->out));
		printf("Stderr = %s\n", STR_NULL(jobp->step_list[i]->err));
		printf("Tracker = %s\n", STR_NULL(jobp->step_list[i]->tracker));
		printf("Tracker Arg = %s\n", STR_NULL(jobp->step_list[i]->tracker_arg));
		printf("Class = %s\n", STR_NULL(jobp->step_list[i]->stepclass));

		printf("Hard Limits:\n");
		printf("\tCPU      = %d\n",jobp->step_list[i]->limits.cpu_hard_limit);
		printf("\tCPU_64   = %lld\n",jobp->step_list[i]->limits64.cpu_hard_limit);
		printf("\tData     = %d\n",jobp->step_list[i]->limits.data_hard_limit);
		printf("\tData_64  = %lld\n",jobp->step_list[i]->limits64.data_hard_limit);
		printf("\tAs_64    = %lld\n",jobp->step_list[i]->limits64.as_hard_limit);
		printf("\tNproc_64 = %lld\n",jobp->step_list[i]->limits64.nproc_hard_limit);
		printf("\tMemlock_64 = %lld\n",jobp->step_list[i]->limits64.memlock_hard_limit);
		printf("\tLocks_64 = %lld\n",jobp->step_list[i]->limits64.locks_hard_limit);
		printf("\tNofile_64  = %lld\n",jobp->step_list[i]->limits64.nofile_hard_limit);
		printf("\tCore     = %d\n",jobp->step_list[i]->limits.core_hard_limit);
		printf("\tCore_64  = %lld\n",jobp->step_list[i]->limits64.core_hard_limit);
		printf("\tFile     = %d\n",jobp->step_list[i]->limits.file_hard_limit);
		printf("\tFile_64  = %lld\n",jobp->step_list[i]->limits64.file_hard_limit);
		printf("\tRSS      = %d\n",jobp->step_list[i]->limits.rss_hard_limit);
		printf("\tRSS_64   = %lld\n",jobp->step_list[i]->limits64.rss_hard_limit);
		printf("\tStack    = %d\n",jobp->step_list[i]->limits.stack_hard_limit);
		printf("\tStack_64 = %lld\n",jobp->step_list[i]->limits64.stack_hard_limit);

		printf("Soft Limits:\n");
		printf("\tCPU      = %d\n",jobp->step_list[i]->limits.cpu_soft_limit);
		printf("\tCPU_64   = %lld\n",jobp->step_list[i]->limits64.cpu_soft_limit);
		printf("\tData     = %d\n",jobp->step_list[i]->limits.data_soft_limit);
		printf("\tData_64  = %lld\n",jobp->step_list[i]->limits64.data_soft_limit);
		printf("\tAs_64    = %lld\n",jobp->step_list[i]->limits64.as_soft_limit);
		printf("\tNproc_64 = %lld\n",jobp->step_list[i]->limits64.nproc_soft_limit);
                printf("\tMemlock_64 = %lld\n",jobp->step_list[i]->limits64.memlock_soft_limit);
                printf("\tLocks_64 = %lld\n",jobp->step_list[i]->limits64.locks_soft_limit);
                printf("\tNofile_64  = %lld\n",jobp->step_list[i]->limits64.nofile_soft_limit);
		printf("\tCore     = %d\n",jobp->step_list[i]->limits.core_soft_limit);
		printf("\tCore_64  = %lld\n",jobp->step_list[i]->limits64.core_soft_limit);
		printf("\tFile     = %d\n",jobp->step_list[i]->limits.file_soft_limit);
		printf("\tFile_64  = %lld\n",jobp->step_list[i]->limits64.file_soft_limit);
		printf("\tRSS      = %d\n",jobp->step_list[i]->limits.rss_soft_limit);
		printf("\tRSS_64   = %lld\n",jobp->step_list[i]->limits64.rss_soft_limit);
		printf("\tStack    = %d\n",jobp->step_list[i]->limits.stack_soft_limit);
		printf("\tStack_64 = %lld\n",jobp->step_list[i]->limits64.stack_soft_limit);
	}
}
