/*
 *  Program used in conjunction with subapi.c to track a job submitted to LoadLeveler.
 */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <fcntl.h>
#include <unistd.h>
#include <time.h>
#include <sys/wait.h>

main(int argc, char *argv[])
{
  FILE *fp;
  int i, n;
  int status;
  time_t clock;
  struct tm *time_date;
  int exit_status;

  /*
   * Open file to write information
   */
  if ((fp = fopen("/tmp/api.test","a")) == NULL) {
    exit(-1);
  }


  /*
   * Write out date and time
   */
  time(&clock);
  time_date = localtime(&clock);
  fprintf(fp,"\n%02d/%02d %02d:%02d:%02d\n",time_date->tm_mon+1,
         time_date->tm_mday,time_date->tm_hour,
         time_date->tm_min,time_date->tm_sec);

  /*
   * Write out user and group ids
   */
  fprintf(fp,"USER:\n");
  fprintf(fp,"\tEffective = %d\n",geteuid());
  fprintf(fp,"\tREAL      = %d\n",getuid());

  fprintf(fp,"GROUP:\n");
  fprintf(fp,"\tEffective = %d\n",getegid());
  fprintf(fp,"\tREAL      = %d\n",getgid());

  /*
   * Write out the arguments
   */
  fprintf(fp,"Number of arguments = %d.\n",argc);
  fprintf(fp,"Tracker = %s.\n",argv[0]);
  fprintf(fp,"Job ID = %s.\n",argv[1]);
  fprintf(fp,"Tracker Arg = %s.\n",argv[2]);
  fprintf(fp,"State = %s.\n",argv[3]);
  fprintf(fp,"Status = %s.\n",argv[4]);

  /* 
   * Write out exit status or terminating signal
   */
  if (strcmp(argv[3],"JOB_COMPLETED") == 0) {
    sscanf(argv[4],"%d",&exit_status);
    if (WIFEXITED(exit_status)) {
      fprintf(fp,"Job terminated with exit status %d\n",
      WEXITSTATUS(exit_status));
    }
    else {
      if (WIFSIGNALED(exit_status)) {
        fprintf(fp,"Job terminated with signal %d\n",
        WTERMSIG(exit_status));
      }
    }
  }

  fclose(fp);
}
